#[repr(transparent)]pub struct AutoLayout(pub Bool);Expand description
Component: Whether the viewport layout is determined automatically.
⚠️ This type is unstable and may change significantly in a way that the data won’t be backwards compatible.
Tuple Fields
0: BoolTrait Implementations
Sourceimpl Borrow<Bool> for AutoLayout
impl Borrow<Bool> for AutoLayout
Sourceimpl Clone for AutoLayout
impl Clone for AutoLayout
Sourcefn clone(&self) -> AutoLayout
fn clone(&self) -> AutoLayout
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutoLayout
impl Debug for AutoLayout
Sourceimpl Default for AutoLayout
impl Default for AutoLayout
Sourcefn default() -> AutoLayout
fn default() -> AutoLayout
Returns the “default value” for a type. Read more
Sourceimpl Deref for AutoLayout
impl Deref for AutoLayout
Sourceimpl DerefMut for AutoLayout
impl DerefMut for AutoLayout
Sourceimpl<'a> From<&'a AutoLayout> for Cow<'a, AutoLayout>
impl<'a> From<&'a AutoLayout> for Cow<'a, AutoLayout>
Sourcefn from(value: &'a AutoLayout) -> Cow<'a, AutoLayout>
fn from(value: &'a AutoLayout) -> Cow<'a, AutoLayout>
Converts to this type from the input type.
Sourceimpl<'a> From<AutoLayout> for Cow<'a, AutoLayout>
impl<'a> From<AutoLayout> for Cow<'a, AutoLayout>
Sourcefn from(value: AutoLayout) -> Cow<'a, AutoLayout>
fn from(value: AutoLayout) -> Cow<'a, AutoLayout>
Converts to this type from the input type.
Sourceimpl<T> From<T> for AutoLayout
impl<T> From<T> for AutoLayout
Sourcefn from(v: T) -> AutoLayout
fn from(v: T) -> AutoLayout
Converts to this type from the input type.
Sourceimpl SizeBytes for AutoLayout
impl SizeBytes for AutoLayout
Sourcefn heap_size_bytes(&self) -> u64
fn heap_size_bytes(&self) -> u64
Returns how many bytes
self uses on the heap. Read moreSourcefn total_size_bytes(&self) -> u64
fn total_size_bytes(&self) -> u64
Returns the total size of
self in bytes, accounting for both stack and heap space.Sourcefn stack_size_bytes(&self) -> u64
fn stack_size_bytes(&self) -> u64
Returns the total size of
self on the stack, in bytes. Read moreSourceimpl WrapperComponent for AutoLayout
impl WrapperComponent for AutoLayout
Sourcefn name() -> ComponentType
fn name() -> ComponentType
The fully-qualified type of this component, e.g.
rerun.components.Position2D.Sourcefn into_inner(self) -> <AutoLayout as WrapperComponent>::Datatype
fn into_inner(self) -> <AutoLayout as WrapperComponent>::Datatype
Unwraps the component into its underlying datatype.
impl Copy for AutoLayout