pub struct GridSpacing(pub Float32);Expand description
Component: Space between grid lines of one line to the next in scene units.
⚠️ This type is unstable and may change significantly in a way that the data won’t be backwards compatible.
Tuple Fields
0: Float32Space between grid lines of one line to the next in scene units.
Methods from Deref<Target = f32>
pub const RADIX: u32 = 2
pub const BITS: u32 = 32
pub const MANTISSA_DIGITS: u32 = 24
pub const DIGITS: u32 = 6
pub const EPSILON: f32 = 1.19209290e-07_f32
pub const MIN: f32 = -3.40282347e+38_f32
pub const MIN_POSITIVE: f32 = 1.17549435e-38_f32
pub const MAX: f32 = 3.40282347e+38_f32
pub const MIN_EXP: i32 = -125
pub const MAX_EXP: i32 = 128
pub const MIN_10_EXP: i32 = -37
pub const MAX_10_EXP: i32 = 38
pub const NAN: f32
pub const INFINITY: f32
pub const NEG_INFINITY: f32
pub const MAX_EXACT_INTEGER: i32
pub const MIN_EXACT_INTEGER: i32
1.62.0 · Sourcepub fn total_cmp(&self, other: &f32) -> Ordering
pub fn total_cmp(&self, other: &f32) -> Ordering
Returns the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f32. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f32,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f32::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f32::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));
// `f32::NAN` could be positive or negative, which will affect the sort order.
if f32::NAN.is_sign_negative() {
assert!(bois.into_iter().map(|b| b.weight)
.zip([f32::NAN, -5.0, 0.1, 10.0, 99.0, f32::INFINITY].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
} else {
assert!(bois.into_iter().map(|b| b.weight)
.zip([-5.0, 0.1, 10.0, 99.0, f32::INFINITY, f32::NAN].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
}Trait Implementations
Sourceimpl Borrow<Float32> for GridSpacing
impl Borrow<Float32> for GridSpacing
Sourceimpl Clone for GridSpacing
impl Clone for GridSpacing
Sourcefn clone(&self) -> GridSpacing
fn clone(&self) -> GridSpacing
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GridSpacing
impl Debug for GridSpacing
Sourceimpl Default for GridSpacing
impl Default for GridSpacing
Sourcefn default() -> GridSpacing
fn default() -> GridSpacing
Sourceimpl Deref for GridSpacing
impl Deref for GridSpacing
Sourceimpl DerefMut for GridSpacing
impl DerefMut for GridSpacing
Sourceimpl<'a> From<&'a GridSpacing> for Cow<'a, GridSpacing>
impl<'a> From<&'a GridSpacing> for Cow<'a, GridSpacing>
Sourcefn from(value: &'a GridSpacing) -> Cow<'a, GridSpacing>
fn from(value: &'a GridSpacing) -> Cow<'a, GridSpacing>
Sourceimpl<'a> From<GridSpacing> for Cow<'a, GridSpacing>
impl<'a> From<GridSpacing> for Cow<'a, GridSpacing>
Sourcefn from(value: GridSpacing) -> Cow<'a, GridSpacing>
fn from(value: GridSpacing) -> Cow<'a, GridSpacing>
Sourceimpl<T> From<T> for GridSpacing
impl<T> From<T> for GridSpacing
Sourcefn from(v: T) -> GridSpacing
fn from(v: T) -> GridSpacing
Sourceimpl SizeBytes for GridSpacing
impl SizeBytes for GridSpacing
Sourcefn heap_size_bytes(&self) -> u64
fn heap_size_bytes(&self) -> u64
self uses on the heap. Read moreSourcefn total_size_bytes(&self) -> u64
fn total_size_bytes(&self) -> u64
self in bytes, accounting for both stack and heap space.Sourcefn stack_size_bytes(&self) -> u64
fn stack_size_bytes(&self) -> u64
self on the stack, in bytes. Read moreSourceimpl WrapperComponent for GridSpacing
impl WrapperComponent for GridSpacing
Sourcefn name() -> ComponentType
fn name() -> ComponentType
rerun.components.Position2D.Sourcefn into_inner(self) -> <GridSpacing as WrapperComponent>::Datatype
fn into_inner(self) -> <GridSpacing as WrapperComponent>::Datatype