#[repr(transparent)]pub struct VisibleTimeRange(pub VisibleTimeRange);Expand description
Component: The range of values on a given timeline that will be included in a view’s query.
Refer to VisibleTimeRanges archetype for more information.
⚠️ This type is unstable and may change significantly in a way that the data won’t be backwards compatible.
Tuple Fields
0: VisibleTimeRangeTrait Implementations
Sourceimpl Borrow<VisibleTimeRange> for VisibleTimeRange
impl Borrow<VisibleTimeRange> for VisibleTimeRange
Sourcefn borrow(&self) -> &VisibleTimeRange
fn borrow(&self) -> &VisibleTimeRange
Immutably borrows from an owned value. Read more
Sourceimpl Clone for VisibleTimeRange
impl Clone for VisibleTimeRange
Sourcefn clone(&self) -> VisibleTimeRange
fn clone(&self) -> VisibleTimeRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VisibleTimeRange
impl Debug for VisibleTimeRange
Sourceimpl Default for VisibleTimeRange
impl Default for VisibleTimeRange
Sourcefn default() -> VisibleTimeRange
fn default() -> VisibleTimeRange
Returns the “default value” for a type. Read more
Sourceimpl Deref for VisibleTimeRange
impl Deref for VisibleTimeRange
Sourcetype Target = VisibleTimeRange
type Target = VisibleTimeRange
The resulting type after dereferencing.
Sourcefn deref(&self) -> &VisibleTimeRange
fn deref(&self) -> &VisibleTimeRange
Dereferences the value.
Sourceimpl DerefMut for VisibleTimeRange
impl DerefMut for VisibleTimeRange
Sourcefn deref_mut(&mut self) -> &mut VisibleTimeRange
fn deref_mut(&mut self) -> &mut VisibleTimeRange
Mutably dereferences the value.
Sourceimpl<'a> From<&'a VisibleTimeRange> for Cow<'a, VisibleTimeRange>
impl<'a> From<&'a VisibleTimeRange> for Cow<'a, VisibleTimeRange>
Sourcefn from(value: &'a VisibleTimeRange) -> Cow<'a, VisibleTimeRange>
fn from(value: &'a VisibleTimeRange) -> Cow<'a, VisibleTimeRange>
Converts to this type from the input type.
Sourceimpl<T> From<T> for VisibleTimeRangewhere
T: Into<VisibleTimeRange>,
impl<T> From<T> for VisibleTimeRangewhere
T: Into<VisibleTimeRange>,
Sourcefn from(v: T) -> VisibleTimeRange
fn from(v: T) -> VisibleTimeRange
Converts to this type from the input type.
Sourceimpl<'a> From<VisibleTimeRange> for Cow<'a, VisibleTimeRange>
impl<'a> From<VisibleTimeRange> for Cow<'a, VisibleTimeRange>
Sourcefn from(value: VisibleTimeRange) -> Cow<'a, VisibleTimeRange>
fn from(value: VisibleTimeRange) -> Cow<'a, VisibleTimeRange>
Converts to this type from the input type.
Sourceimpl PartialEq for VisibleTimeRange
impl PartialEq for VisibleTimeRange
Sourcefn eq(&self, other: &VisibleTimeRange) -> bool
fn eq(&self, other: &VisibleTimeRange) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SizeBytes for VisibleTimeRange
impl SizeBytes for VisibleTimeRange
Sourcefn heap_size_bytes(&self) -> u64
fn heap_size_bytes(&self) -> u64
Returns how many bytes
self uses on the heap. Read moreSourcefn total_size_bytes(&self) -> u64
fn total_size_bytes(&self) -> u64
Returns the total size of
self in bytes, accounting for both stack and heap space.Sourcefn stack_size_bytes(&self) -> u64
fn stack_size_bytes(&self) -> u64
Returns the total size of
self on the stack, in bytes. Read moreSourceimpl WrapperComponent for VisibleTimeRange
impl WrapperComponent for VisibleTimeRange
Sourcetype Datatype = VisibleTimeRange
type Datatype = VisibleTimeRange
The underlying
Loggable datatype for this component.Sourcefn name() -> ComponentType
fn name() -> ComponentType
The fully-qualified type of this component, e.g.
rerun.components.Position2D.Sourcefn into_inner(self) -> <VisibleTimeRange as WrapperComponent>::Datatype
fn into_inner(self) -> <VisibleTimeRange as WrapperComponent>::Datatype
Unwraps the component into its underlying datatype.
impl Eq for VisibleTimeRange
impl StructuralPartialEq for VisibleTimeRange