#[repr(transparent)]pub struct VisualizerInstructionId(pub Uuid);Expand description
Component: ID for a visualizer instruction.
IDs are only guaranteed to be unique in the scope of a view.
For details see archetypes::ActiveVisualizers.
⚠️ This type is unstable and may change significantly in a way that the data won’t be backwards compatible.
Tuple Fields
0: UuidIDs of a single visualizer instruction.
Implementations
Sourceimpl VisualizerInstructionId
impl VisualizerInstructionId
Sourcepub fn invalid() -> VisualizerInstructionId
pub fn invalid() -> VisualizerInstructionId
Create an invalid visualizer instruction ID (nil UUID).
Sourcepub fn new_random() -> VisualizerInstructionId
pub fn new_random() -> VisualizerInstructionId
Generate a new random visualizer instruction ID.
Sourcepub fn new_deterministic(hash: u64, index: usize) -> VisualizerInstructionId
pub fn new_deterministic(hash: u64, index: usize) -> VisualizerInstructionId
Create a deterministic visualizer instruction ID from a hash and index.
This is used internally for generating stable IDs for heuristically created visualizers.