Module clap

Module clap 

Integration with integration with the clap command line argument parser.

Structs

RerunArgs
This struct implements a clap::Parser that defines all the arguments that a typical Rerun application might use, and provides helpers to evaluate those arguments and behave consequently.