Colormap

Enum Colormap 

#[repr(u8)]
pub enum Colormap { Grayscale = 1, Inferno = 2, Magma = 3, Plasma = 4, Turbo = 5, Viridis = 6, CyanToYellow = 7, Spectral = 8, Twilight = 9, RvizMap = 10, RvizCostmap = 11, Costmap = 12, }
Component: Colormap for mapping scalar values within a given range to a color.

This provides a number of popular pre-defined colormaps. In the future, the Rerun Viewer will allow users to define their own colormaps, but currently the Viewer is limited to the types defined here.

Variants



Grayscale = 1

A simple black to white gradient.

This is a sRGB gray gradient which is perceptually uniform.



Inferno = 2

The Inferno colormap from Matplotlib.

This is a perceptually uniform colormap. It interpolates from black to red to bright yellow.



Magma = 3

The Magma colormap from Matplotlib.

This is a perceptually uniform colormap. It interpolates from black to purple to white.



Plasma = 4

The Plasma colormap from Matplotlib.

This is a perceptually uniform colormap. It interpolates from dark blue to purple to yellow.



Turbo = 5

Google’s Turbo colormap map.

This is a perceptually non-uniform rainbow colormap addressing many issues of more traditional rainbow colormaps like Jet. It is more perceptually uniform without sharp transitions and is more colorblind-friendly. Details: https://research.google/blog/turbo-an-improved-rainbow-colormap-for-visualization/



Viridis = 6

The Viridis colormap from Matplotlib

This is a perceptually uniform colormap which is robust to color blindness. It interpolates from dark purple to green to yellow.



CyanToYellow = 7

Rasmusgo’s Cyan to Yellow colormap

This is a perceptually uniform colormap which is robust to color blindness. It is especially suited for visualizing signed values. It interpolates from cyan to blue to dark gray to brass to yellow.



Spectral = 8

The Spectral colormap from Matplotlib.

This is a diverging colormap, often used to visualize data with a meaningful center point, where deviations from that center are important to highlight. It interpolates from red to orange to yellow to green to blue to violet.



Twilight = 9

The Twilight colormap from Matplotlib.

This is a perceptually uniform cyclic colormap from Matplotlib, it is useful for visualizing periodic or cyclic data.

It interpolates from white to blue to purple to red to orange and back to white.



RvizMap = 10

The classic RViz “Map” grid-map colormap intended for occupancy-style SLAM grid maps.

Known values are mapped to a grayscale ramp from white (free) to black (occupied), unknown values are in a green-blue color. Special / illegal values have highlight colors.



RvizCostmap = 11

The classic RViz “Costmap” grid-map colormap for robot navigation cost maps.

Cost values are mapped to blue to red spectrum, and special cost values (e.g. lethal obstacles) have highlight colors. Zero values are fully transparent.



Costmap = 12

A grid-map colormap for robot navigation cost maps.

Semantically equivalent to the RViz cost map but with a more pleasing color palette.

Cost values are mapped to a green to yellow spectrum, and special cost values (e.g. lethal obstacles) have highlight colors. Zero values are fully transparent.

Implementations

Source

impl Colormap

pub fn category(&self) -> ColormapCategory

Returns the ColormapCategory classification for this colormap.