#[repr(u8)]pub enum MeshFaceRendering {
DoubleSided = 1,
Front = 2,
Back = 3,
}Expand description
Component: Determines which faces of a mesh are rendered.
For this purpose, we assume that the winding order of vertices in a mesh is consistent and that front faces are defined as those with vertices in counter clockwise order.
Variants
DoubleSided = 1
Show both back and front faces.
Front = 2
Only front faces are shown.
Front faces are assumed to have a counter clockwise vertex winding order on screen.
Back = 3
Only back faces are shown.
Back faces are assumed to have a clockwise vertex winding order on screen.