#[repr(transparent)]pub struct AxisLength(pub Float32);Expand description
Component: The length of an axis in local units of the space.
Tuple Fields
0: Float32Methods from Deref<Target = f32>
pub const RADIX: u32 = 2
pub const BITS: u32 = 32
pub const MANTISSA_DIGITS: u32 = 24
pub const DIGITS: u32 = 6
pub const EPSILON: f32 = 1.19209290e-07_f32
pub const MIN: f32 = -3.40282347e+38_f32
pub const MIN_POSITIVE: f32 = 1.17549435e-38_f32
pub const MAX: f32 = 3.40282347e+38_f32
pub const MIN_EXP: i32 = -125
pub const MAX_EXP: i32 = 128
pub const MIN_10_EXP: i32 = -37
pub const MAX_10_EXP: i32 = 38
pub const NAN: f32
pub const INFINITY: f32
pub const NEG_INFINITY: f32
pub const MAX_EXACT_INTEGER: i32
pub const MIN_EXACT_INTEGER: i32
1.62.0 · Sourcepub fn total_cmp(&self, other: &f32) -> Ordering
pub fn total_cmp(&self, other: &f32) -> Ordering
Returns the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f32. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f32,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f32::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f32::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));
// `f32::NAN` could be positive or negative, which will affect the sort order.
if f32::NAN.is_sign_negative() {
assert!(bois.into_iter().map(|b| b.weight)
.zip([f32::NAN, -5.0, 0.1, 10.0, 99.0, f32::INFINITY].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
} else {
assert!(bois.into_iter().map(|b| b.weight)
.zip([-5.0, 0.1, 10.0, 99.0, f32::INFINITY, f32::NAN].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
}Trait Implementations
Sourceimpl Borrow<Float32> for AxisLength
impl Borrow<Float32> for AxisLength
Sourceimpl Clone for AxisLength
impl Clone for AxisLength
Sourcefn clone(&self) -> AxisLength
fn clone(&self) -> AxisLength
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AxisLength
impl Debug for AxisLength
Sourceimpl Default for AxisLength
impl Default for AxisLength
Sourcefn default() -> AxisLength
fn default() -> AxisLength
Sourceimpl Deref for AxisLength
impl Deref for AxisLength
Sourceimpl DerefMut for AxisLength
impl DerefMut for AxisLength
Sourceimpl<'a> From<&'a AxisLength> for Cow<'a, AxisLength>
impl<'a> From<&'a AxisLength> for Cow<'a, AxisLength>
Sourcefn from(value: &'a AxisLength) -> Cow<'a, AxisLength>
fn from(value: &'a AxisLength) -> Cow<'a, AxisLength>
Sourceimpl<'a> From<AxisLength> for Cow<'a, AxisLength>
impl<'a> From<AxisLength> for Cow<'a, AxisLength>
Sourcefn from(value: AxisLength) -> Cow<'a, AxisLength>
fn from(value: AxisLength) -> Cow<'a, AxisLength>
Sourceimpl From<AxisLength> for f32
impl From<AxisLength> for f32
Sourcefn from(val: AxisLength) -> f32
fn from(val: AxisLength) -> f32
Sourceimpl<T> From<T> for AxisLength
impl<T> From<T> for AxisLength
Sourcefn from(v: T) -> AxisLength
fn from(v: T) -> AxisLength
Sourceimpl PartialEq for AxisLength
impl PartialEq for AxisLength
Sourceimpl PartialOrd for AxisLength
impl PartialOrd for AxisLength
Sourceimpl SizeBytes for AxisLength
impl SizeBytes for AxisLength
Sourcefn heap_size_bytes(&self) -> u64
fn heap_size_bytes(&self) -> u64
self uses on the heap. Read moreSourcefn total_size_bytes(&self) -> u64
fn total_size_bytes(&self) -> u64
self in bytes, accounting for both stack and heap space.Sourcefn stack_size_bytes(&self) -> u64
fn stack_size_bytes(&self) -> u64
self on the stack, in bytes. Read moreSourceimpl WrapperComponent for AxisLength
impl WrapperComponent for AxisLength
Sourcefn name() -> ComponentType
fn name() -> ComponentType
rerun.components.Position2D.Sourcefn into_inner(self) -> <AxisLength as WrapperComponent>::Datatype
fn into_inner(self) -> <AxisLength as WrapperComponent>::Datatype
impl Copy for AxisLength
impl StructuralPartialEq for AxisLength