pub struct ChannelMessageCounts(pub Vec<ChannelCountPair>);Expand description
Component: A mapping of channel IDs to their respective message counts.
Used in MCAP statistics to track how many messages were recorded per channel.
⚠️ This type is unstable and may change significantly in a way that the data won’t be backwards compatible.
Tuple Fields
0: Vec<ChannelCountPair>The channel ID to message count pairs.