#[repr(transparent)]pub struct DrawOrder(pub Float32);Expand description
Component: Draw order of 2D elements. Higher values are drawn on top of lower values.
An entity can have only a single draw order component. Within an entity draw order is governed by the order of the components.
Draw order for entities with the same draw order is generally undefined.
Tuple Fields
0: Float32Implementations
Sourceimpl DrawOrder
impl DrawOrder
Sourcepub const DEFAULT_DEPTH_IMAGE: DrawOrder
pub const DEFAULT_DEPTH_IMAGE: DrawOrder
Draw order used for depth image when they’re not shown as a 3D point cloud and no draw order was specified.
Sourcepub const DEFAULT_VIDEO: DrawOrder
pub const DEFAULT_VIDEO: DrawOrder
Draw order used for videos (both streams and assets) if no draw order was specified.
Sourcepub const DEFAULT_IMAGE: DrawOrder
pub const DEFAULT_IMAGE: DrawOrder
Draw order used for images if no draw order was specified.
Sourcepub const DEFAULT_SEGMENTATION_IMAGE: DrawOrder
pub const DEFAULT_SEGMENTATION_IMAGE: DrawOrder
Draw order used for segmentation images if no draw order was specified.
Sourcepub const DEFAULT_SHAPE_2D: DrawOrder
pub const DEFAULT_SHAPE_2D: DrawOrder
Draw order used for 2D shapes (boxes, ellipses) if no draw order was specified.
Sourcepub const DEFAULT_LINES2D: DrawOrder
pub const DEFAULT_LINES2D: DrawOrder
Draw order used for 2D lines if no draw order was specified.
Sourcepub const DEFAULT_POINTS2D: DrawOrder
pub const DEFAULT_POINTS2D: DrawOrder
Draw order used for 2D points if no draw order was specified.
Methods from Deref<Target = f32>
pub const RADIX: u32 = 2
pub const BITS: u32 = 32
pub const MANTISSA_DIGITS: u32 = 24
pub const DIGITS: u32 = 6
pub const EPSILON: f32 = 1.19209290e-07_f32
pub const MIN: f32 = -3.40282347e+38_f32
pub const MIN_POSITIVE: f32 = 1.17549435e-38_f32
pub const MAX: f32 = 3.40282347e+38_f32
pub const MIN_EXP: i32 = -125
pub const MAX_EXP: i32 = 128
pub const MIN_10_EXP: i32 = -37
pub const MAX_10_EXP: i32 = 38
pub const NAN: f32
pub const INFINITY: f32
pub const NEG_INFINITY: f32
pub const MAX_EXACT_INTEGER: i32
pub const MIN_EXACT_INTEGER: i32
pub const SIGN_MASK: u32 = 0x8000_0000
pub const EXPONENT_MASK: u32 = 0x7f80_0000
pub const MANTISSA_MASK: u32 = 0x007f_ffff
1.62.0 · Sourcepub fn total_cmp(&self, other: &f32) -> Ordering
pub fn total_cmp(&self, other: &f32) -> Ordering
Returns the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f32. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f32,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f32::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f32::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));
// `f32::NAN` could be positive or negative, which will affect the sort order.
if f32::NAN.is_sign_negative() {
assert!(bois.into_iter().map(|b| b.weight)
.zip([f32::NAN, -5.0, 0.1, 10.0, 99.0, f32::INFINITY].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
} else {
assert!(bois.into_iter().map(|b| b.weight)
.zip([-5.0, 0.1, 10.0, 99.0, f32::INFINITY, f32::NAN].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
}Trait Implementations
Sourceimpl Ord for DrawOrder
impl Ord for DrawOrder
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialOrd for DrawOrder
impl PartialOrd for DrawOrder
Sourceimpl SizeBytes for DrawOrder
impl SizeBytes for DrawOrder
Sourcefn heap_size_bytes(&self) -> u64
fn heap_size_bytes(&self) -> u64
self uses on the heap. Read moreSourcefn total_size_bytes(&self) -> u64
fn total_size_bytes(&self) -> u64
self in bytes, accounting for both stack and heap space.Sourcefn stack_size_bytes(&self) -> u64
fn stack_size_bytes(&self) -> u64
self on the stack, in bytes. Read moreSourceimpl WrapperComponent for DrawOrder
impl WrapperComponent for DrawOrder
Sourcefn name() -> ComponentType
fn name() -> ComponentType
rerun.components.Position2D.Sourcefn into_inner(self) -> <DrawOrder as WrapperComponent>::Datatype
fn into_inner(self) -> <DrawOrder as WrapperComponent>::Datatype
impl Copy for DrawOrder
impl Eq for DrawOrder