RotationQuat

Struct RotationQuat 

#[repr(transparent)]
pub struct RotationQuat(pub Quaternion);
Component: A 3D rotation expressed as a quaternion.

Note: although the x,y,z,w components of the quaternion will be passed through to the datastore as provided, when used in the Viewer, quaternions will always be normalized. If normalization fails the rotation is treated as an invalid transform.

Tuple Fields

0: Quaternion

Implementations

Source

impl RotationQuat

pub const IDENTITY: RotationQuat

The identity rotation, representing no rotation.

Keep in mind that logging an identity rotation is different from logging no rotation at all in thus far that it will write data to the store.

pub const INVALID: RotationQuat

A rotation that represents an invalid transform.

Methods from Deref<Target = Quaternion>

pub const IDENTITY: Quaternion

pub const INVALID: Quaternion

pub fn xyzw(&self) -> [f32; 4]

The components of the quaternion in X,Y,Z,W order.