pub struct WriterBuilder { /* private fields */ }Expand description
A CSV writer builder
Implementations
Sourceimpl WriterBuilder
impl WriterBuilder
Sourcepub fn new() -> WriterBuilder
pub fn new() -> WriterBuilder
Create a new builder for configuring CSV Writer options.
To convert a builder into a writer, call WriterBuilder::build. See
the module documentation for more examples.
Example
fn example() -> Writer<File> {
let file = File::create("target/out.csv").unwrap();
// create a builder that doesn't write headers
let builder = WriterBuilder::new().with_header(false);
let writer = builder.build(file);
writer
}Sourcepub fn with_header(self, header: bool) -> WriterBuilder
pub fn with_header(self, header: bool) -> WriterBuilder
Set whether to write the CSV file with a header
Sourcepub fn with_delimiter(self, delimiter: u8) -> WriterBuilder
pub fn with_delimiter(self, delimiter: u8) -> WriterBuilder
Set the CSV file’s column delimiter as a byte character
Sourcepub fn with_quote(self, quote: u8) -> WriterBuilder
pub fn with_quote(self, quote: u8) -> WriterBuilder
Set the CSV file’s quote character as a byte character
Sourcepub fn with_escape(self, escape: u8) -> WriterBuilder
pub fn with_escape(self, escape: u8) -> WriterBuilder
Set the CSV file’s escape character as a byte character
In some variants of CSV, quotes are escaped using a special escape
character like \ (instead of escaping quotes by doubling them).
By default, writing these idiosyncratic escapes is disabled, and is
only used when double_quote is disabled.
Sourcepub fn with_double_quote(self, double_quote: bool) -> WriterBuilder
pub fn with_double_quote(self, double_quote: bool) -> WriterBuilder
Set whether to enable double quote escapes
When enabled (which is the default), quotes are escaped by doubling
them. e.g., " escapes to "".
When disabled, quotes are escaped with the escape character (which
is \\ by default).
Sourcepub fn double_quote(&self) -> bool
pub fn double_quote(&self) -> bool
Get whether double quote escapes are enabled
Sourcepub fn with_date_format(self, format: String) -> WriterBuilder
pub fn with_date_format(self, format: String) -> WriterBuilder
Set the CSV file’s date format
Sourcepub fn date_format(&self) -> Option<&str>
pub fn date_format(&self) -> Option<&str>
Get the CSV file’s date format if set, defaults to RFC3339
Sourcepub fn with_datetime_format(self, format: String) -> WriterBuilder
pub fn with_datetime_format(self, format: String) -> WriterBuilder
Set the CSV file’s datetime format
Sourcepub fn datetime_format(&self) -> Option<&str>
pub fn datetime_format(&self) -> Option<&str>
Get the CSV file’s datetime format if set, defaults to RFC3339
Sourcepub fn with_time_format(self, format: String) -> WriterBuilder
pub fn with_time_format(self, format: String) -> WriterBuilder
Set the CSV file’s time format
Sourcepub fn time_format(&self) -> Option<&str>
pub fn time_format(&self) -> Option<&str>
Get the CSV file’s datetime time if set, defaults to RFC3339
Sourcepub fn with_timestamp_format(self, format: String) -> WriterBuilder
pub fn with_timestamp_format(self, format: String) -> WriterBuilder
Set the CSV file’s timestamp format
Sourcepub fn timestamp_format(&self) -> Option<&str>
pub fn timestamp_format(&self) -> Option<&str>
Get the CSV file’s timestamp format if set, defaults to RFC3339
Sourcepub fn with_timestamp_tz_format(self, tz_format: String) -> WriterBuilder
pub fn with_timestamp_tz_format(self, tz_format: String) -> WriterBuilder
Set the CSV file’s timestamp tz format
Sourcepub fn timestamp_tz_format(&self) -> Option<&str>
pub fn timestamp_tz_format(&self) -> Option<&str>
Get the CSV file’s timestamp tz format if set, defaults to RFC3339
Sourcepub fn with_null(self, null_value: String) -> WriterBuilder
pub fn with_null(self, null_value: String) -> WriterBuilder
Set the value to represent null in output
Sourcepub fn with_ignore_leading_whitespace(self, ignore: bool) -> WriterBuilder
pub fn with_ignore_leading_whitespace(self, ignore: bool) -> WriterBuilder
Set whether to ignore leading whitespace in string values For example, a string value such as “ foo“ will be written as “foo”
Sourcepub fn ignore_leading_whitespace(&self) -> bool
pub fn ignore_leading_whitespace(&self) -> bool
Get whether to ignore leading whitespace in string values
Sourcepub fn with_ignore_trailing_whitespace(self, ignore: bool) -> WriterBuilder
pub fn with_ignore_trailing_whitespace(self, ignore: bool) -> WriterBuilder
Set whether to ignore trailing whitespace in string values For example, a string value such as “foo “ will be written as “foo”
Sourcepub fn ignore_trailing_whitespace(&self) -> bool
pub fn ignore_trailing_whitespace(&self) -> bool
Get whether to ignore trailing whitespace in string values
Sourcepub fn with_quote_style(self, quote_style: QuoteStyle) -> WriterBuilder
pub fn with_quote_style(self, quote_style: QuoteStyle) -> WriterBuilder
Set the quoting style for writing CSV files
Example
use arrow_csv::{WriterBuilder, QuoteStyle};
// Quote all fields (equivalent to Spark's quoteAll=true)
let builder = WriterBuilder::new()
.with_quote_style(QuoteStyle::Always);
// Only quote when necessary (default)
let builder = WriterBuilder::new()
.with_quote_style(QuoteStyle::Necessary);Sourcepub fn quote_style(&self) -> QuoteStyle
pub fn quote_style(&self) -> QuoteStyle
Get the configured quoting style