pub struct ChunkBuilder { /* private fields */ }Expand description
Helper to incrementally build a Chunk.
Can be created using Chunk::builder.
Implementations
Sourceimpl ChunkBuilder
impl ChunkBuilder
Sourcepub fn new(id: ChunkId, entity_path: EntityPath) -> ChunkBuilder
pub fn new(id: ChunkId, entity_path: EntityPath) -> ChunkBuilder
Initializes a new ChunkBuilder.
See also Chunk::builder.
Sourcepub fn with_sparse_row(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
components: impl IntoIterator<Item = (ComponentDescriptor, Option<Arc<dyn Array>>)>,
) -> ChunkBuilder
pub fn with_sparse_row( self, row_id: RowId, timepoint: impl Into<TimePoint>, components: impl IntoIterator<Item = (ComponentDescriptor, Option<Arc<dyn Array>>)>, ) -> ChunkBuilder
Add a row’s worth of data using the given sparse component data.
Sourcepub fn with_row(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
components: impl IntoIterator<Item = (ComponentDescriptor, Arc<dyn Array>)>,
) -> ChunkBuilder
pub fn with_row( self, row_id: RowId, timepoint: impl Into<TimePoint>, components: impl IntoIterator<Item = (ComponentDescriptor, Arc<dyn Array>)>, ) -> ChunkBuilder
Add a row’s worth of data using the given component data.
Sourcepub fn with_archetype(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
as_components: &dyn AsComponents,
) -> ChunkBuilder
pub fn with_archetype( self, row_id: RowId, timepoint: impl Into<TimePoint>, as_components: &dyn AsComponents, ) -> ChunkBuilder
Add a row’s worth of data by destructuring an archetype into component columns.
Sourcepub fn with_archetype_auto_row(
self,
timepoint: impl Into<TimePoint>,
as_components: &dyn AsComponents,
) -> ChunkBuilder
pub fn with_archetype_auto_row( self, timepoint: impl Into<TimePoint>, as_components: &dyn AsComponents, ) -> ChunkBuilder
Add a row’s worth of data by destructuring an archetype into component columns, using an automatically generated row ID.
Sourcepub fn with_component<Component>(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
component_descr: ComponentDescriptor,
value: &Component,
) -> Result<ChunkBuilder, SerializationError>where
Component: Component,
pub fn with_component<Component>(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
component_descr: ComponentDescriptor,
value: &Component,
) -> Result<ChunkBuilder, SerializationError>where
Component: Component,
Add the serialized value of a single component to the chunk.
Sourcepub fn with_component_batch(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
component_batch: (ComponentDescriptor, &dyn ComponentBatch),
) -> ChunkBuilder
pub fn with_component_batch( self, row_id: RowId, timepoint: impl Into<TimePoint>, component_batch: (ComponentDescriptor, &dyn ComponentBatch), ) -> ChunkBuilder
Add a row’s worth of data by serializing a single ComponentBatch.
Sourcepub fn with_component_batches<'a>(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
component_batches: impl IntoIterator<Item = (ComponentDescriptor, &'a dyn ComponentBatch)>,
) -> ChunkBuilder
pub fn with_component_batches<'a>( self, row_id: RowId, timepoint: impl Into<TimePoint>, component_batches: impl IntoIterator<Item = (ComponentDescriptor, &'a dyn ComponentBatch)>, ) -> ChunkBuilder
Add a row’s worth of data by serializing many ComponentBatches.
Sourcepub fn with_sparse_component_batches<'a>(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
component_batches: impl IntoIterator<Item = (ComponentDescriptor, Option<&'a dyn ComponentBatch>)>,
) -> ChunkBuilder
pub fn with_sparse_component_batches<'a>( self, row_id: RowId, timepoint: impl Into<TimePoint>, component_batches: impl IntoIterator<Item = (ComponentDescriptor, Option<&'a dyn ComponentBatch>)>, ) -> ChunkBuilder
Add a row’s worth of data by serializing many sparse ComponentBatches.
Sourcepub fn with_serialized_batch(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
component_batch: SerializedComponentBatch,
) -> ChunkBuilder
pub fn with_serialized_batch( self, row_id: RowId, timepoint: impl Into<TimePoint>, component_batch: SerializedComponentBatch, ) -> ChunkBuilder
Add a row’s worth of data by serializing a single ComponentBatch.
Sourcepub fn with_serialized_batches(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
component_batches: impl IntoIterator<Item = SerializedComponentBatch>,
) -> ChunkBuilder
pub fn with_serialized_batches( self, row_id: RowId, timepoint: impl Into<TimePoint>, component_batches: impl IntoIterator<Item = SerializedComponentBatch>, ) -> ChunkBuilder
Add a row’s worth of data by serializing many ComponentBatches.
Sourcepub fn with_sparse_serialized_batches(
self,
row_id: RowId,
timepoint: impl Into<TimePoint>,
component_batches: impl IntoIterator<Item = (ComponentDescriptor, Option<SerializedComponentBatch>)>,
) -> ChunkBuilder
pub fn with_sparse_serialized_batches( self, row_id: RowId, timepoint: impl Into<TimePoint>, component_batches: impl IntoIterator<Item = (ComponentDescriptor, Option<SerializedComponentBatch>)>, ) -> ChunkBuilder
Add a row’s worth of data by serializing many sparse ComponentBatches.
Sourcepub fn build(self) -> Result<Chunk, ChunkError>
pub fn build(self) -> Result<Chunk, ChunkError>
Builds and returns the final Chunk.
The arrow datatype of each individual column will be guessed by inspecting the data.
If any component column turns out to be fully sparse (i.e. only null values), that column will be stripped out (how could we guess its datatype without any single value to inspect)?
This is generally the desired behavior but, if you want to make sure to keep fully sparse
columns (can be useful e.g. for testing purposes), see ChunkBuilder::build_with_datatypes
instead.
This returns an error if the chunk fails to sanity_check.
Sourcepub fn build_with_datatypes(
self,
datatypes: &HashMap<ComponentDescriptor, DataType, BuildHasherDefault<NoHashHasher<ComponentDescriptor>>>,
) -> Result<Chunk, ChunkError>
pub fn build_with_datatypes( self, datatypes: &HashMap<ComponentDescriptor, DataType, BuildHasherDefault<NoHashHasher<ComponentDescriptor>>>, ) -> Result<Chunk, ChunkError>
Builds and returns the final Chunk.
The arrow datatype of each individual column will be guessed by inspecting the data.
If any component column turns out to be fully sparse (i.e. only null values), datatypes
will be used as a fallback.
If any component column turns out to be fully sparse (i.e. only null values) and doesn’t have an explicit datatype passed in, that column will be stripped out (how could we guess its datatype without any single value to inspect)?
You should rarely want to keep fully sparse columns around outside of testing scenarios.
See Self::build.
This returns an error if the chunk fails to sanity_check.