QueryResults

Struct QueryResults 

pub struct QueryResults {
    pub chunks: Vec<Arc<Chunk>>,
    pub missing_virtual: Vec<ChunkId>,
}
The results of a latest-at and/or range relevancy query.

Since the introduction of virtual/offloaded chunks, it is possible for a query to detect that it is missing some data in order to compute accurate results. This lack of data is communicated using a non-empty QueryResults::missing_virtual field.

Fields

chunks: Vec<Arc<Chunk>>

The relevant physical chunks that were found for this query.

If Self::missing_virtual is non-empty, then these chunks are not enough to compute accurate query results.

missing_virtual: Vec<ChunkId>

The relevant virtual chunks that were found for this query.

Until these chunks have been fetched and inserted into the appropriate ChunkStore, the results of this query cannot accurately be computed.

Note, these are NOT necessarily root chunks. Use ChunkStore::find_root_chunks to get those.

Implementations

Source

impl QueryResults

pub fn is_partial(&self) -> bool

Returns true if these are partial results.

Partial results happen when some of the chunks required to accurately compute the query are currently missing/offloaded. It is then the responsibility of the caller to look into the missing chunk IDs, fetch them, load them, and then try the query again.

pub fn is_empty(&self) -> bool

Returns true if the results are completely empty.

I.e. neither physical/loaded nor virtual/offloaded chunks could be found.

pub fn to_iter(&self) -> Option<impl Iterator<Item = &Arc<Chunk>>>

Attempts to iterate over the returned chunks.

If the results contain partial data, returns None. It is then the responsibility of the caller to look into the missing chunk IDs, fetch them, load them, and then try the query again.

pub fn into_iter_verbose(self) -> impl Iterator<Item = Arc<Chunk>>

Attempts to iterate over the returned chunks.

If the results contain partial data:

  • prints a debug log in release builds.
  • prints a warning in debug builds.

It is the responsibility of the caller to look into the missing chunk IDs, fetch them, load them, and then try the query again.