Module datatypes

Module datatypes 

The low-level datatypes that components are built from.

They all implement the Loggable trait.

Structs

AbsoluteTimeRange
Datatype: Two datatypes::TimeInt describing a range of time.
Angle
Datatype: Angle in radians.
AnnotationInfo
Datatype: Annotation info annotating a class id or key-point id.
Blob
Datatype: A binary blob of data.
Bool
Datatype: A single boolean.
ChannelCountPair
Datatype: A pair representing a channel ID and its associated message count.
ClassDescription
Datatype: The description of a semantic Class.
ClassDescriptionMapElem
Datatype: A helper type for mapping datatypes::ClassIds to class descriptions.
ClassId
Datatype: A 16-bit ID representing a type of semantic class.
DVec2D
Datatype: A double-precision vector in 2D space.
EntityPath
Datatype: A path to an entity in the ChunkStore.
Float32
Datatype: A single-precision 32-bit IEEE 754 floating point number.
Float64
Datatype: A double-precision 64-bit IEEE 754 floating point number.
ImageFormat
Datatype: The metadata describing the contents of a components::ImageBuffer.
KeypointId
Datatype: A 16-bit ID representing a type of semantic keypoint within a class.
KeypointPair
Datatype: A connection between two datatypes::KeypointIds.
Mat3x3
Datatype: A 3x3 Matrix.
Mat4x4
Datatype: A 4x4 Matrix.
Plane3D
Datatype: An infinite 3D plane represented by a unit normal vector and a distance.
Quaternion
Datatype: A Quaternion represented by 4 real numbers.
Range1D
Datatype: A 1D range, specifying a lower and upper bound.
Range2D
Datatype: An Axis-Aligned Bounding Box in 2D space, implemented as the minimum and maximum corners.
Rgba32
Datatype: An RGBA color with unmultiplied/separate alpha, in sRGB gamma space with linear alpha.
RotationAxisAngle
Datatype: 3D rotation represented by a rotation around a given axis.
TensorData
Datatype: An N-dimensional array of numbers.
TensorDimensionIndexSelection
Datatype: Indexing a specific tensor dimension.
TensorDimensionSelection
Datatype: Selection of a single tensor dimension.
TimeInt
Datatype: A 64-bit number describing either nanoseconds OR sequence numbers.
TimeRange
Datatype: Visible time range bounds for a specific timeline.
UInt16
Datatype: A 16bit unsigned integer.
UInt32
Datatype: A 32bit unsigned integer.
UInt64
Datatype: A 64bit unsigned integer.
UVec2D
Datatype: A uint32 vector in 2D space.
UVec3D
Datatype: A uint32 vector in 3D space.
UVec4D
Datatype: A uint vector in 4D space.
Utf8
Datatype: A string of text, encoded as UTF-8.
Utf8Pair
Datatype: Stores a tuple of UTF-8 strings.
Uuid
Datatype: A 16-byte UUID.
Vec2D
Datatype: A vector in 2D space.
Vec3D
Datatype: A vector in 3D space.
Vec4D
Datatype: A vector in 4D space.
VideoTimestamp
Datatype: Presentation timestamp within a archetypes::AssetVideo.
ViewCoordinates
Datatype: How we interpret the coordinate system of an entity/space.
VisibleTimeRange
Datatype: Visible time range bounds for a specific timeline.

Enums

ChannelDatatype
Datatype: The innermost datatype of an image.
ColorModel
Datatype: Specified what color components are present in an archetypes::Image.
PixelFormat
Datatype: Specifieds a particular format of an archetypes::Image.
TensorBuffer
Datatype: The underlying storage for archetypes::Tensor.
TimeRangeBoundary
Datatype: Left or right boundary of a time range.