pub enum ChunkStoreDiff {
Addition(ChunkStoreDiffAddition),
VirtualAddition(ChunkStoreDiffVirtualAddition),
Deletion(ChunkStoreDiffDeletion),
}Expand description
Everything needed to build custom ChunkStoreSubscribers.
Describes an atomic change in the Rerun ChunkStore:
- a physical chunk has been added or deleted.
- a virtual manifest has been added.
From a query model standpoint, the ChunkStore always operates one chunk at a time:
- The contents of a chunk (i.e. its columns) are immutable past insertion, by virtue of
ChunkIds being unique and non-reusable. - Similarly, garbage collection always removes all the data associated with a chunk in one go: there cannot be orphaned columns. When a chunk is gone, all data associated with it is gone too.
Refer to field-level documentation for more information.
Variants
Addition(ChunkStoreDiffAddition)
VirtualAddition(ChunkStoreDiffVirtualAddition)
Deletion(ChunkStoreDiffDeletion)
Implementations
Sourceimpl ChunkStoreDiff
impl ChunkStoreDiff
pub fn addition( chunk_before_processing: Arc<Chunk>, chunk_after_processing: Arc<Chunk>, direct_lineage: ChunkDirectLineageReport, ) -> ChunkStoreDiff
pub fn virtual_addition(rrd_manifest: Arc<RrdManifest>) -> ChunkStoreDiff
pub fn deletion(chunk: Arc<Chunk>) -> ChunkStoreDiff
pub fn is_addition(&self) -> bool
pub fn is_virtual_addition(&self) -> bool
pub fn is_deletion(&self) -> bool
pub fn into_addition(self) -> Option<ChunkStoreDiffAddition>
pub fn into_virtual_addition(self) -> Option<ChunkStoreDiffVirtualAddition>
pub fn into_deletion(self) -> Option<ChunkStoreDiffDeletion>
pub fn to_addition(&self) -> Option<&ChunkStoreDiffAddition>
pub fn to_virtual_addition(&self) -> Option<&ChunkStoreDiffVirtualAddition>
pub fn to_deletion(&self) -> Option<&ChunkStoreDiffDeletion>
Sourcepub fn delta_chunk(&self) -> Option<&Arc<Chunk>>
pub fn delta_chunk(&self) -> Option<&Arc<Chunk>>
This always returns a chunk that only contains never-seen-before data.
For a physical addition:
- In case of a compaction event, this corresponds to the original chunk before compaction, which only contains the newly added data.
- In case of a split event, this corresponds to the individual splits, so the original data does not get accounted for more than once.
For a physical deletion, it returns the deleted chunk as-is.
For a virtual addition, it returns None.