pub struct NullArray { /* private fields */ }Expand description
An array of null values
A NullArray is a simplified array where all values are null.
Example: Create an array
use arrow_array::{Array, NullArray};
let array = NullArray::new(10);
assert!(array.is_nullable());
assert_eq!(array.len(), 10);
assert_eq!(array.null_count(), 0);
assert_eq!(array.logical_null_count(), 10);
assert_eq!(array.logical_nulls().unwrap().null_count(), 10);Implementations
Sourceimpl NullArray
impl NullArray
Sourcepub fn new(length: usize) -> NullArray
pub fn new(length: usize) -> NullArray
Create a new NullArray of the specified length
Note: Use crate::array::new_null_array if you need an array of some
other DataType.
Sourcepub fn slice(&self, offset: usize, len: usize) -> NullArray
pub fn slice(&self, offset: usize, len: usize) -> NullArray
Returns a zero-copy slice of this array with the indicated offset and length.
Sourcepub fn builder(_capacity: usize) -> NullBuilder
pub fn builder(_capacity: usize) -> NullBuilder
Returns a new null array builder
Note that the capacity parameter to this function is deprecated. It
now does nothing, and will be removed in a future version.