pub struct PrimitiveRunBuilder<R, V>where
R: RunEndIndexType,
V: ArrowPrimitiveType,{ /* private fields */ }Expand description
Builder for RunArray of PrimitiveArray
Example:
let mut builder =
PrimitiveRunBuilder::<Int16Type, UInt32Type>::new();
builder.append_value(1234);
builder.append_value(1234);
builder.append_value(1234);
builder.append_null();
builder.append_value(5678);
builder.append_value(5678);
let array = builder.finish();
assert_eq!(array.run_ends().values(), &[3, 4, 6]);
let av = array.values();
assert!(!av.is_null(0));
assert!(av.is_null(1));
assert!(!av.is_null(2));
// Values are polymorphic and so require a downcast.
let ava: &UInt32Array = av.as_primitive::<UInt32Type>();
assert_eq!(ava, &UInt32Array::from(vec![Some(1234), None, Some(5678)]));Implementations
Sourceimpl<R, V> PrimitiveRunBuilder<R, V>where
R: RunEndIndexType,
V: ArrowPrimitiveType,
impl<R, V> PrimitiveRunBuilder<R, V>where
R: RunEndIndexType,
V: ArrowPrimitiveType,
Sourcepub fn new() -> PrimitiveRunBuilder<R, V>
pub fn new() -> PrimitiveRunBuilder<R, V>
Creates a new PrimitiveRunBuilder
Sourcepub fn with_capacity(capacity: usize) -> PrimitiveRunBuilder<R, V>
pub fn with_capacity(capacity: usize) -> PrimitiveRunBuilder<R, V>
Creates a new PrimitiveRunBuilder with the provided capacity
capacity: the expected number of run-end encoded values.
Sourceimpl<R, V> PrimitiveRunBuilder<R, V>where
R: RunEndIndexType,
V: ArrowPrimitiveType,
impl<R, V> PrimitiveRunBuilder<R, V>where
R: RunEndIndexType,
V: ArrowPrimitiveType,
Sourcepub fn append_option(
&mut self,
value: Option<<V as ArrowPrimitiveType>::Native>,
)
pub fn append_option( &mut self, value: Option<<V as ArrowPrimitiveType>::Native>, )
Appends optional value to the logical array encoded by the RunArray.
Sourcepub fn append_value(&mut self, value: <V as ArrowPrimitiveType>::Native)
pub fn append_value(&mut self, value: <V as ArrowPrimitiveType>::Native)
Appends value to the logical array encoded by the run-ends array.
Sourcepub fn append_null(&mut self)
pub fn append_null(&mut self)
Appends null to the logical array encoded by the run-ends array.
Sourcepub fn finish(&mut self) -> RunArray<R>
pub fn finish(&mut self) -> RunArray<R>
Creates the RunArray and resets the builder. Panics if RunArray cannot be built.
Sourcepub fn finish_cloned(&self) -> RunArray<R>
pub fn finish_cloned(&self) -> RunArray<R>
Creates the RunArray and without resetting the builder. Panics if RunArray cannot be built.