pub struct SortOptions {
pub descending: bool,
pub nulls_first: bool,
}Expand description
Options that define the sort order of a given column
The default sorts equivalently to of ASC NULLS FIRST in SQL (i.e.
ascending order with nulls sorting before any other values).
Example creation
// configure using explicit initialization
let options = SortOptions {
descending: false,
nulls_first: true,
};
// Default is ASC NULLs First
assert_eq!(options, SortOptions::default());
assert_eq!(options.to_string(), "ASC NULLS FIRST");
// Configure using builder APIs
let options = SortOptions::default()
.desc()
.nulls_first();
assert_eq!(options.to_string(), "DESC NULLS FIRST");
// configure using explicit field values
let options = SortOptions::default()
.with_descending(false)
.with_nulls_first(false);
assert_eq!(options.to_string(), "ASC NULLS LAST");Example operations
It is also possible to negate the sort options using the ! operator.
use arrow_schema::SortOptions;
let options = !SortOptions::default();
assert_eq!(options.to_string(), "DESC NULLS LAST");Fields
descending: boolWhether to sort in descending order
nulls_first: boolWhether to sort nulls first
Implementations
Sourceimpl SortOptions
impl SortOptions
Sourcepub fn new(descending: bool, nulls_first: bool) -> SortOptions
pub fn new(descending: bool, nulls_first: bool) -> SortOptions
Create a new SortOptions struct
Sourcepub fn desc(self) -> SortOptions
pub fn desc(self) -> SortOptions
Set this sort options to sort in descending order
See Self::with_descending to explicitly set the underlying field
Sourcepub fn asc(self) -> SortOptions
pub fn asc(self) -> SortOptions
Set this sort options to sort in ascending order
See Self::with_descending to explicitly set the underlying field
Sourcepub fn nulls_first(self) -> SortOptions
pub fn nulls_first(self) -> SortOptions
Set this sort options to sort nulls first
See Self::with_nulls_first to explicitly set the underlying field
Sourcepub fn nulls_last(self) -> SortOptions
pub fn nulls_last(self) -> SortOptions
Set this sort options to sort nulls last
See Self::with_nulls_first to explicitly set the underlying field
Sourcepub fn with_descending(self, descending: bool) -> SortOptions
pub fn with_descending(self, descending: bool) -> SortOptions
Set this sort options to sort descending if argument is true
Sourcepub fn with_nulls_first(self, nulls_first: bool) -> SortOptions
pub fn with_nulls_first(self, nulls_first: bool) -> SortOptions
Set this sort options to sort nulls first if argument is true