pub struct StreamReader<R> { /* private fields */ }Expand description
Arrow Stream Reader
Reads Arrow RecordBatches from bytes in the IPC Streaming Format.
See Also
FileReaderfor random access.
Example
let projection = None; // read all columns
let mut reader = StreamReader::try_new(stream, projection).unwrap();
// read batches from the reader using the Iterator trait
let mut num_rows = 0;
for batch in reader {
let batch = batch.unwrap();
num_rows += batch.num_rows();
}
assert_eq!(num_rows, 3);Implementations
Sourceimpl<R> StreamReader<BufReader<R>>where
R: Read,
impl<R> StreamReader<BufReader<R>>where
R: Read,
Sourcepub fn try_new_buffered(
reader: R,
projection: Option<Vec<usize>>,
) -> Result<StreamReader<BufReader<R>>, ArrowError>
pub fn try_new_buffered( reader: R, projection: Option<Vec<usize>>, ) -> Result<StreamReader<BufReader<R>>, ArrowError>
Try to create a new stream reader with the reader wrapped in a BufReader.
See StreamReader::try_new for an unbuffered version.
Sourceimpl<R> StreamReader<R>where
R: Read,
impl<R> StreamReader<R>where
R: Read,
Sourcepub fn try_new(
reader: R,
projection: Option<Vec<usize>>,
) -> Result<StreamReader<R>, ArrowError>
pub fn try_new( reader: R, projection: Option<Vec<usize>>, ) -> Result<StreamReader<R>, ArrowError>
Try to create a new stream reader.
To check if the reader is done, use is_finished(self).
There is no internal buffering. If buffered reads are needed you likely want to use
StreamReader::try_new_buffered instead.
Errors
An ‘Err’ may be returned if the reader does not encounter a schema as the first message in the stream.
Sourcepub fn try_new_unbuffered(
reader: R,
projection: Option<Vec<usize>>,
) -> Result<StreamReader<R>, ArrowError>
👎Deprecated since 53.0.0: use try_new instead
pub fn try_new_unbuffered( reader: R, projection: Option<Vec<usize>>, ) -> Result<StreamReader<R>, ArrowError>
use try_new instead
Deprecated, use StreamReader::try_new instead.
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Check if the stream is finished
Sourcepub fn get_ref(&self) -> &R
pub fn get_ref(&self) -> &R
Gets a reference to the underlying reader.
It is inadvisable to directly read from the underlying reader.
Sourcepub fn get_mut(&mut self) -> &mut R
pub fn get_mut(&mut self) -> &mut R
Gets a mutable reference to the underlying reader.
It is inadvisable to directly read from the underlying reader.
Sourcepub unsafe fn with_skip_validation(
self,
skip_validation: bool,
) -> StreamReader<R> ⓘ
pub unsafe fn with_skip_validation( self, skip_validation: bool, ) -> StreamReader<R> ⓘ
Specifies if validation should be skipped when reading data (defaults to false)
Safety