FormatOptions

Struct FormatOptions 

pub struct FormatOptions<'a> { /* private fields */ }
Options for formatting arrays

By default nulls are formatted as "" and temporal types formatted according to RFC3339

Equality

Most fields in FormatOptions are compared by value, except formatter_factory. As the trait does not require an Eq and Hash implementation, this struct only compares the pointer of the factories.

Implementations

Source

impl<'a> FormatOptions<'a>

pub const fn new() -> FormatOptions<'a>

Creates a new set of format options

pub const fn with_display_error(self, safe: bool) -> FormatOptions<'a>

If set to true any formatting errors will be written to the output instead of being converted into a std::fmt::Error

pub const fn with_null(self, null: &'a str) -> FormatOptions<'a>

Overrides the string used to represent a null

Defaults to ""

pub const fn with_date_format( self, date_format: Option<&'a str>, ) -> FormatOptions<'a>

Overrides the format used for DataType::Date32 columns

pub const fn with_datetime_format( self, datetime_format: Option<&'a str>, ) -> FormatOptions<'a>

Overrides the format used for DataType::Date64 columns

pub const fn with_timestamp_format( self, timestamp_format: Option<&'a str>, ) -> FormatOptions<'a>

Overrides the format used for DataType::Timestamp columns without a timezone

pub const fn with_timestamp_tz_format( self, timestamp_tz_format: Option<&'a str>, ) -> FormatOptions<'a>

Overrides the format used for DataType::Timestamp columns with a timezone

pub const fn with_time_format( self, time_format: Option<&'a str>, ) -> FormatOptions<'a>

Overrides the format used for DataType::Time32 and DataType::Time64 columns

pub const fn with_duration_format( self, duration_format: DurationFormat, ) -> FormatOptions<'a>

Overrides the format used for duration columns

Defaults to DurationFormat::ISO8601

pub const fn with_types_info(self, types_info: bool) -> FormatOptions<'a>

Overrides if types should be shown

Defaults to false

pub const fn with_formatter_factory( self, formatter_factory: Option<&'a dyn ArrayFormatterFactory>, ) -> FormatOptions<'a>

Overrides the ArrayFormatterFactory used to instantiate custom ArrayFormatters.

Using None causes pretty-printers to use the default ArrayFormatters.

pub const fn safe(&self) -> bool

Returns whether formatting errors should be written to the output instead of being converted into a std::fmt::Error.

pub const fn null(&self) -> &'a str

Returns the string used for displaying nulls.

pub const fn date_format(&self) -> Option<&'a str>

Returns the format used for DataType::Date32 columns.

pub const fn datetime_format(&self) -> Option<&'a str>

Returns the format used for DataType::Date64 columns.

pub const fn timestamp_format(&self) -> Option<&'a str>

Returns the format used for DataType::Timestamp columns without a timezone.

pub const fn timestamp_tz_format(&self) -> Option<&'a str>

Returns the format used for DataType::Timestamp columns with a timezone.

pub const fn time_format(&self) -> Option<&'a str>

Returns the format used for DataType::Time32 and DataType::Time64 columns.

pub const fn duration_format(&self) -> DurationFormat

Returns the DurationFormat used for duration columns.

pub const fn types_info(&self) -> bool

Returns true if type info should be included in a visual representation of batches.

pub const fn formatter_factory(&self) -> Option<&'a dyn ArrayFormatterFactory>

Returns the ArrayFormatterFactory used to instantiate custom ArrayFormatters.