pub struct TextFormat {
pub font_id: FontId,
pub extra_letter_spacing: f32,
pub line_height: Option<f32>,
pub color: Color32,
pub background: Color32,
pub expand_bg: f32,
pub coords: VariationCoords,
pub italics: bool,
pub underline: Stroke,
pub strikethrough: Stroke,
pub valign: Align,
}Expand description
Formatting option for a section of text.
Fields
font_id: FontIdextra_letter_spacing: f32Extra spacing between letters, in points.
Default: 0.0.
line_height: Option<f32>Explicit line height of the text in points.
This is the distance between the bottom row of two subsequent lines of text.
If None (the default), the line height is determined by the font.
For even text it is recommended you round this to an even number of pixels.
color: Color32Text color
background: Color32expand_bg: f32Amount to expand background fill by.
Default: 1.0
coords: VariationCoordsitalics: boolunderline: Strokestrikethrough: Strokevalign: AlignIf you use a small font and Align::TOP you
can get the effect of raised text.
If you use a small font and Align::BOTTOM
you get the effect of a subscript.
If you use Align::Center, you get text that is centered
around a common center-line, which is nice when mixining emojis
and normal text in e.g. a button.
Implementations
Sourceimpl TextFormat
impl TextFormat
pub fn simple(font_id: FontId, color: Color32) -> TextFormat