AsId

Trait AsId 

pub trait AsId: Hash + Debug { }
Types that can be converted to an Id.

This is all types implementing Hash and Debug, which includes things like string, integers, tuples of those, etc.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> AsId for T
where T: Hash + Debug,