pub enum GlFenceBehavior {
Normal,
AutoFinish,
}Expand description
Dictate the behavior of fences in OpenGL.
Variants
Normal
Fences in OpenGL behave normally. If you don’t know what to pick, this is what you want.
AutoFinish
Fences in OpenGL are short-circuited to always return true immediately.
This solves a very specific issue that arose due to a bug in wgpu-core that made
many WebGL programs work when they “shouldn’t” have. If you have code that is trying
to call device.poll(wgpu::PollType::Wait) on WebGL, you need to enable this option
for the “Wait” to behave how you would expect.
Previously all poll(Wait) acted like the OpenGL fences were signalled even if they weren’t.
See https://github.com/gfx-rs/wgpu/issues/4589 for more information.
When this is set Queue::on_completed_work_done will always return the next time the device
is maintained, not when the work is actually done on the GPU.
Implementations
Sourceimpl GlFenceBehavior
impl GlFenceBehavior
Sourcepub fn is_auto_finish(&self) -> bool
pub fn is_auto_finish(&self) -> bool
Returns true if the fence behavior is AutoFinish.
Sourcepub fn from_env() -> Option<GlFenceBehavior>
pub fn from_env() -> Option<GlFenceBehavior>
Choose which minor OpenGL ES version to use from the environment variable WGPU_GL_FENCE_BEHAVIOR.
Possible values are Normal or AutoFinish. Case insensitive.
Use with unwrap_or_default() to get the default value if the environment variable is not set.
Sourcepub fn with_env(self) -> GlFenceBehavior
pub fn with_env(self) -> GlFenceBehavior
Takes the given compiler, modifies it based on the WGPU_GL_FENCE_BEHAVIOR environment variable, and returns the result.
See from_env for more information.