pub struct Frame { /* private fields */ }Expand description
Represents the surroundings of your app.
It provides methods to inspect the surroundings (are we on the web?), access to persistent storage, and access to the rendering backend.
Implementations
Sourceimpl Frame
impl Frame
Sourcepub fn is_web(&self) -> bool
pub fn is_web(&self) -> bool
True if you are in a web environment.
Equivalent to cfg!(target_arch = "wasm32")
Sourcepub fn info(&self) -> &IntegrationInfo
pub fn info(&self) -> &IntegrationInfo
Information about the integration.
Sourcepub fn storage(&self) -> Option<&dyn Storage>
pub fn storage(&self) -> Option<&dyn Storage>
A place where you can store custom data in a way that persists when you restart the app.
Sourcepub fn storage_mut(&mut self) -> Option<&mut (dyn Storage + 'static)>
pub fn storage_mut(&mut self) -> Option<&mut (dyn Storage + 'static)>
A place where you can store custom data in a way that persists when you restart the app.
Sourcepub fn wgpu_render_state(&self) -> Option<&RenderState>
pub fn wgpu_render_state(&self) -> Option<&RenderState>
The underlying WGPU render state.
Only available when compiling with the wgpu feature and using Renderer::Wgpu.
Can be used to manage GPU resources for custom rendering with WGPU using egui::PaintCallbacks.