pub struct PngEncoder<W>where
W: Write,{ /* private fields */ }Expand description
PNG encoder
Implementations
Sourceimpl<W> PngEncoder<W>where
W: Write,
impl<W> PngEncoder<W>where
W: Write,
Sourcepub fn new(w: W) -> PngEncoder<W>
pub fn new(w: W) -> PngEncoder<W>
Create a new encoder that writes its output to w
Sourcepub fn new_with_quality(
w: W,
compression: CompressionType,
filter: FilterType,
) -> PngEncoder<W>
pub fn new_with_quality( w: W, compression: CompressionType, filter: FilterType, ) -> PngEncoder<W>
Create a new encoder that writes its output to w with CompressionType compression and
FilterType filter.
It is best to view the options as a hint to the implementation on the smallest or fastest option for encoding a particular image. That is, using options that map directly to a PNG image parameter will use this parameter where possible. But variants that have no direct mapping may be interpreted differently in minor versions. The exact output is expressly not part of the SemVer stability guarantee.
Note that it is not optimal to use a single filter type, so an adaptive filter type is selected as the default. The filter which best minimizes file size may change with the type of compression used.