pub enum ImageError {
Decoding(DecodingError),
Encoding(EncodingError),
Parameter(ParameterError),
Limits(LimitError),
Unsupported(UnsupportedError),
IoError(Error),
}Expand description
The generic error type for image operations.
This high level enum allows, by variant matching, a rough separation of concerns between
underlying IO, the caller, format specifications, and the image implementation.
Variants
Decoding(DecodingError)
An error was encountered while decoding.
This means that the input data did not conform to the specification of some image format, or that no format could be determined, or that it did not match format specific requirements set by the caller.
Encoding(EncodingError)
An error was encountered while encoding.
The input image can not be encoded with the chosen format, for example because the specification has no representation for its color space or because a necessary conversion is ambiguous. In some cases it might also happen that the dimensions can not be used with the format.
Parameter(ParameterError)
An error was encountered in input arguments.
This is a catch-all case for strictly internal operations such as scaling, conversions, etc. that involve no external format specifications.
Limits(LimitError)
Completing the operation would have required more resources than allowed.
Errors of this type are limits set by the user or environment, not inherent in a specific format or operation that was executed.
Unsupported(UnsupportedError)
An operation can not be completed by the chosen abstraction.
This means that it might be possible for the operation to succeed in general but
- it requires a disabled feature,
- the implementation does not yet exist, or
- no abstraction for a lower level could be found.
IoError(Error)
An error occurred while interacting with the environment.