pub struct ReentrantMutex<R, G, T>where
T: ?Sized,{ /* private fields */ }Expand description
A mutex which can be recursively locked by a single thread.
This type is identical to Mutex except for the following points:
- Locking multiple times from the same thread will work correctly instead of deadlocking.
ReentrantMutexGuarddoes not give mutable references to the locked data. Use aRefCellif you need this.
See Mutex for more details about the underlying mutex
primitive.
Implementations
Sourceimpl<R, G, T> ReentrantMutex<R, G, T>where
R: RawMutex,
G: GetThreadId,
impl<R, G, T> ReentrantMutex<R, G, T>where
R: RawMutex,
G: GetThreadId,
Sourcepub const fn new(val: T) -> ReentrantMutex<R, G, T>
pub const fn new(val: T) -> ReentrantMutex<R, G, T>
Creates a new reentrant mutex in an unlocked state ready for use.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes this mutex, returning the underlying data.
Sourceimpl<R, G, T> ReentrantMutex<R, G, T>
impl<R, G, T> ReentrantMutex<R, G, T>
Sourcepub const fn from_raw(
raw_mutex: R,
get_thread_id: G,
val: T,
) -> ReentrantMutex<R, G, T>
pub const fn from_raw( raw_mutex: R, get_thread_id: G, val: T, ) -> ReentrantMutex<R, G, T>
Creates a new reentrant mutex based on a pre-existing raw mutex and a helper to get the thread ID.
Sourcepub const fn const_new(
raw_mutex: R,
get_thread_id: G,
val: T,
) -> ReentrantMutex<R, G, T>
pub const fn const_new( raw_mutex: R, get_thread_id: G, val: T, ) -> ReentrantMutex<R, G, T>
Creates a new reentrant mutex based on a pre-existing raw mutex and a helper to get the thread ID.
This allows creating a reentrant mutex in a constant context on stable Rust.
This method is a legacy alias for from_raw.
Sourceimpl<R, G, T> ReentrantMutex<R, G, T>
impl<R, G, T> ReentrantMutex<R, G, T>
Sourcepub unsafe fn make_guard_unchecked(&self) -> ReentrantMutexGuard<'_, R, G, T>
pub unsafe fn make_guard_unchecked(&self) -> ReentrantMutexGuard<'_, R, G, T>
Creates a new ReentrantMutexGuard without checking if the lock is held.
Safety
This method must only be called if the thread logically holds the lock.
Calling this function when a guard has already been produced is undefined behaviour unless
the guard was forgotten with mem::forget.
Sourcepub fn lock(&self) -> ReentrantMutexGuard<'_, R, G, T>
pub fn lock(&self) -> ReentrantMutexGuard<'_, R, G, T>
Acquires a reentrant mutex, blocking the current thread until it is able to do so.
If the mutex is held by another thread then this function will block the local thread until it is available to acquire the mutex. If the mutex is already held by the current thread then this function will increment the lock reference count and return immediately. Upon returning, the thread is the only thread with the mutex held. An RAII guard is returned to allow scoped unlock of the lock. When the guard goes out of scope, the mutex will be unlocked.
Sourcepub fn try_lock(&self) -> Option<ReentrantMutexGuard<'_, R, G, T>>
pub fn try_lock(&self) -> Option<ReentrantMutexGuard<'_, R, G, T>>
Attempts to acquire this lock.
If the lock could not be acquired at this time, then None is returned.
Otherwise, an RAII guard is returned. The lock will be unlocked when the
guard is dropped.
This function does not block.
Sourcepub fn get_mut(&mut self) -> &mut T
pub fn get_mut(&mut self) -> &mut T
Returns a mutable reference to the underlying data.
Since this call borrows the ReentrantMutex mutably, no actual locking needs to
take place—the mutable borrow statically guarantees no locks exist.
Sourcepub fn is_owned_by_current_thread(&self) -> bool
pub fn is_owned_by_current_thread(&self) -> bool
Checks whether the mutex is currently held by the current thread.
Sourcepub unsafe fn force_unlock(&self)
pub unsafe fn force_unlock(&self)
Forcibly unlocks the mutex.
This is useful when combined with mem::forget to hold a lock without
the need to maintain a ReentrantMutexGuard object alive, for example when
dealing with FFI.
Safety
This method must only be called if the current thread logically owns a
ReentrantMutexGuard but that guard has be discarded using mem::forget.
Behavior is undefined if a mutex is unlocked when not locked.
Sourcepub unsafe fn raw(&self) -> &R
pub unsafe fn raw(&self) -> &R
Returns the underlying raw mutex object.
Note that you will most likely need to import the RawMutex trait from
lock_api to be able to call functions on the raw mutex.
Safety
This method is unsafe because it allows unlocking a mutex while
still holding a reference to a ReentrantMutexGuard.
Sourcepub fn data_ptr(&self) -> *mut T
pub fn data_ptr(&self) -> *mut T
Returns a raw pointer to the underlying data.
This is useful when combined with mem::forget to hold a lock without
the need to maintain a ReentrantMutexGuard object alive, for example
when dealing with FFI.
Safety
You must ensure that there are no data races when dereferencing the
returned pointer, for example if the current thread logically owns a
ReentrantMutexGuard but that guard has been discarded using
mem::forget.
Sourcepub unsafe fn make_arc_guard_unchecked(
self: &Arc<ReentrantMutex<R, G, T>>,
) -> ArcReentrantMutexGuard<R, G, T>
pub unsafe fn make_arc_guard_unchecked( self: &Arc<ReentrantMutex<R, G, T>>, ) -> ArcReentrantMutexGuard<R, G, T>
Creates a new ArcReentrantMutexGuard without checking if the lock is held.
Safety
This method must only be called if the thread logically holds the lock.
Calling this function when a guard has already been produced is undefined behaviour unless
the guard was forgotten with mem::forget.
Sourcepub fn lock_arc(
self: &Arc<ReentrantMutex<R, G, T>>,
) -> ArcReentrantMutexGuard<R, G, T>
pub fn lock_arc( self: &Arc<ReentrantMutex<R, G, T>>, ) -> ArcReentrantMutexGuard<R, G, T>
Acquires a reentrant mutex through an Arc.
This method is similar to the lock method; however, it requires the ReentrantMutex to be inside of an
Arc and the resulting mutex guard has no lifetime requirements.
Sourcepub fn try_lock_arc(
self: &Arc<ReentrantMutex<R, G, T>>,
) -> Option<ArcReentrantMutexGuard<R, G, T>>
pub fn try_lock_arc( self: &Arc<ReentrantMutex<R, G, T>>, ) -> Option<ArcReentrantMutexGuard<R, G, T>>
Attempts to acquire a reentrant mutex through an Arc.
This method is similar to the try_lock method; however, it requires the ReentrantMutex to be inside
of an Arc and the resulting mutex guard has no lifetime requirements.
Sourceimpl<R, G, T> ReentrantMutex<R, G, T>
impl<R, G, T> ReentrantMutex<R, G, T>
Sourcepub unsafe fn force_unlock_fair(&self)
pub unsafe fn force_unlock_fair(&self)
Forcibly unlocks the mutex using a fair unlock protocol.
This is useful when combined with mem::forget to hold a lock without
the need to maintain a ReentrantMutexGuard object alive, for example when
dealing with FFI.
Safety
This method must only be called if the current thread logically owns a
ReentrantMutexGuard but that guard has be discarded using mem::forget.
Behavior is undefined if a mutex is unlocked when not locked.
Sourceimpl<R, G, T> ReentrantMutex<R, G, T>
impl<R, G, T> ReentrantMutex<R, G, T>
Sourcepub fn try_lock_for(
&self,
timeout: <R as RawMutexTimed>::Duration,
) -> Option<ReentrantMutexGuard<'_, R, G, T>>
pub fn try_lock_for( &self, timeout: <R as RawMutexTimed>::Duration, ) -> Option<ReentrantMutexGuard<'_, R, G, T>>
Attempts to acquire this lock until a timeout is reached.
If the lock could not be acquired before the timeout expired, then
None is returned. Otherwise, an RAII guard is returned. The lock will
be unlocked when the guard is dropped.
Sourcepub fn try_lock_until(
&self,
timeout: <R as RawMutexTimed>::Instant,
) -> Option<ReentrantMutexGuard<'_, R, G, T>>
pub fn try_lock_until( &self, timeout: <R as RawMutexTimed>::Instant, ) -> Option<ReentrantMutexGuard<'_, R, G, T>>
Attempts to acquire this lock until a timeout is reached.
If the lock could not be acquired before the timeout expired, then
None is returned. Otherwise, an RAII guard is returned. The lock will
be unlocked when the guard is dropped.
Sourcepub fn try_lock_arc_for(
self: &Arc<ReentrantMutex<R, G, T>>,
timeout: <R as RawMutexTimed>::Duration,
) -> Option<ArcReentrantMutexGuard<R, G, T>>
pub fn try_lock_arc_for( self: &Arc<ReentrantMutex<R, G, T>>, timeout: <R as RawMutexTimed>::Duration, ) -> Option<ArcReentrantMutexGuard<R, G, T>>
Attempts to acquire this lock until a timeout is reached, through an Arc.
This method is similar to the try_lock_for method; however, it requires the ReentrantMutex to be
inside of an Arc and the resulting mutex guard has no lifetime requirements.
Sourcepub fn try_lock_arc_until(
self: &Arc<ReentrantMutex<R, G, T>>,
timeout: <R as RawMutexTimed>::Instant,
) -> Option<ArcReentrantMutexGuard<R, G, T>>
pub fn try_lock_arc_until( self: &Arc<ReentrantMutex<R, G, T>>, timeout: <R as RawMutexTimed>::Instant, ) -> Option<ArcReentrantMutexGuard<R, G, T>>
Attempts to acquire this lock until a timeout is reached, through an Arc.
This method is similar to the try_lock_until method; however, it requires the ReentrantMutex to be
inside of an Arc and the resulting mutex guard has no lifetime requirements.