pub struct ReentrantMutexGuard<'a, R, G, T>{ /* private fields */ }Expand description
An RAII implementation of a “scoped lock” of a reentrant mutex. When this structure is dropped (falls out of scope), the lock will be unlocked.
The data protected by the mutex can be accessed through this guard via its
Deref implementation.
Implementations
Sourceimpl<'a, R, G, T> ReentrantMutexGuard<'a, R, G, T>
impl<'a, R, G, T> ReentrantMutexGuard<'a, R, G, T>
Sourcepub fn remutex(
s: &ReentrantMutexGuard<'a, R, G, T>,
) -> &'a ReentrantMutex<R, G, T>
pub fn remutex( s: &ReentrantMutexGuard<'a, R, G, T>, ) -> &'a ReentrantMutex<R, G, T>
Returns a reference to the original ReentrantMutex object.
Sourcepub fn map<U, F>(
s: ReentrantMutexGuard<'a, R, G, T>,
f: F,
) -> MappedReentrantMutexGuard<'a, R, G, U>
pub fn map<U, F>( s: ReentrantMutexGuard<'a, R, G, T>, f: F, ) -> MappedReentrantMutexGuard<'a, R, G, U>
Makes a new MappedReentrantMutexGuard for a component of the locked data.
This operation cannot fail as the ReentrantMutexGuard passed
in already locked the mutex.
This is an associated function that needs to be
used as ReentrantMutexGuard::map(...). A method would interfere with methods of
the same name on the contents of the locked data.
Sourcepub fn try_map<U, F>(
s: ReentrantMutexGuard<'a, R, G, T>,
f: F,
) -> Result<MappedReentrantMutexGuard<'a, R, G, U>, ReentrantMutexGuard<'a, R, G, T>>
pub fn try_map<U, F>( s: ReentrantMutexGuard<'a, R, G, T>, f: F, ) -> Result<MappedReentrantMutexGuard<'a, R, G, U>, ReentrantMutexGuard<'a, R, G, T>>
Attempts to make a new MappedReentrantMutexGuard for a component of the
locked data. The original guard is return if the closure returns None.
This operation cannot fail as the ReentrantMutexGuard passed
in already locked the mutex.
This is an associated function that needs to be
used as ReentrantMutexGuard::try_map(...). A method would interfere with methods of
the same name on the contents of the locked data.
Sourcepub fn try_map_or_err<U, F, E>(
s: ReentrantMutexGuard<'a, R, G, T>,
f: F,
) -> Result<MappedReentrantMutexGuard<'a, R, G, U>, (ReentrantMutexGuard<'a, R, G, T>, E)>
pub fn try_map_or_err<U, F, E>( s: ReentrantMutexGuard<'a, R, G, T>, f: F, ) -> Result<MappedReentrantMutexGuard<'a, R, G, U>, (ReentrantMutexGuard<'a, R, G, T>, E)>
Attempts to make a new MappedReentrantMutexGuard for a component of the
locked data. The original guard is returned alongside arbitrary user data
if the closure returns Err.
This operation cannot fail as the ReentrantMutexGuard passed
in already locked the mutex.
This is an associated function that needs to be
used as ReentrantMutexGuard::try_map_or_err(...). A method would interfere with methods of
the same name on the contents of the locked data.
Sourcepub fn unlocked<F, U>(s: &mut ReentrantMutexGuard<'a, R, G, T>, f: F) -> Uwhere
F: FnOnce() -> U,
pub fn unlocked<F, U>(s: &mut ReentrantMutexGuard<'a, R, G, T>, f: F) -> Uwhere
F: FnOnce() -> U,
Temporarily unlocks the mutex to execute the given function.
This is safe because &mut guarantees that there exist no other
references to the data protected by the mutex.
Sourceimpl<'a, R, G, T> ReentrantMutexGuard<'a, R, G, T>
impl<'a, R, G, T> ReentrantMutexGuard<'a, R, G, T>
Sourcepub fn unlock_fair(s: ReentrantMutexGuard<'a, R, G, T>)
pub fn unlock_fair(s: ReentrantMutexGuard<'a, R, G, T>)
Unlocks the mutex using a fair unlock protocol.
By default, mutexes are unfair and allow the current thread to re-lock the mutex before another has the chance to acquire the lock, even if that thread has been blocked on the mutex for a long time. This is the default because it allows much higher throughput as it avoids forcing a context switch on every mutex unlock. This can result in one thread acquiring a mutex many more times than other threads.
However in some cases it can be beneficial to ensure fairness by forcing
the lock to pass on to a waiting thread if there is one. This is done by
using this method instead of dropping the ReentrantMutexGuard normally.
Sourcepub fn unlocked_fair<F, U>(s: &mut ReentrantMutexGuard<'a, R, G, T>, f: F) -> Uwhere
F: FnOnce() -> U,
pub fn unlocked_fair<F, U>(s: &mut ReentrantMutexGuard<'a, R, G, T>, f: F) -> Uwhere
F: FnOnce() -> U,
Temporarily unlocks the mutex to execute the given function.
The mutex is unlocked a fair unlock protocol.
This is safe because &mut guarantees that there exist no other
references to the data protected by the mutex.
Sourcepub fn bump(s: &mut ReentrantMutexGuard<'a, R, G, T>)
pub fn bump(s: &mut ReentrantMutexGuard<'a, R, G, T>)
Temporarily yields the mutex to a waiting thread if there is one.
This method is functionally equivalent to calling unlock_fair followed
by lock, however it can be much more efficient in the case where there
are no waiting threads.