pub struct AbsoluteTimeRange {
pub min: TimeInt,
pub max: TimeInt,
}Expand description
An absolute time range using TimeInt.
Can be resolved from re_types_core::datatypes::TimeRange (which may have relative bounds) using a given timeline & cursor.
Should not include TimeInt::STATIC.
Fields
min: TimeIntmax: TimeIntImplementations
Sourceimpl AbsoluteTimeRange
impl AbsoluteTimeRange
Sourcepub const EMPTY: AbsoluteTimeRange
pub const EMPTY: AbsoluteTimeRange
Contains no time at all.
Sourcepub const EVERYTHING: AbsoluteTimeRange
pub const EVERYTHING: AbsoluteTimeRange
Contains all time.
Sourcepub fn new(
min: impl TryInto<TimeInt>,
max: impl TryInto<TimeInt>,
) -> AbsoluteTimeRange
pub fn new( min: impl TryInto<TimeInt>, max: impl TryInto<TimeInt>, ) -> AbsoluteTimeRange
Creates a new temporal AbsoluteTimeRange.
The returned range is guaranteed to never include TimeInt::STATIC.
Sourcepub fn point(time: impl TryInto<TimeInt>) -> AbsoluteTimeRange
pub fn point(time: impl TryInto<TimeInt>) -> AbsoluteTimeRange
The returned range is guaranteed to never include TimeInt::STATIC.
pub fn min(&self) -> TimeInt
pub fn max(&self) -> TimeInt
Sourcepub fn set_min(&mut self, time: impl TryInto<TimeInt>)
pub fn set_min(&mut self, time: impl TryInto<TimeInt>)
Overwrites the start bound of the range.
The resulting range is guaranteed to never include TimeInt::STATIC.
Sourcepub fn set_max(&mut self, time: impl TryInto<TimeInt>)
pub fn set_max(&mut self, time: impl TryInto<TimeInt>)
Overwrites the end bound of the range.
The resulting range is guaranteed to never include TimeInt::STATIC.
Sourcepub fn abs_length(&self) -> u64
pub fn abs_length(&self) -> u64
The amount of time or sequences covered by this range.
pub fn is_empty(&self) -> bool
pub fn center(&self) -> TimeInt
pub fn contains(&self, time: TimeInt) -> bool
Sourcepub fn contains_range(&self, other: AbsoluteTimeRange) -> bool
pub fn contains_range(&self, other: AbsoluteTimeRange) -> bool
Does this range fully contain the other?
pub fn intersects(&self, other: AbsoluteTimeRange) -> bool
pub fn intersection( &self, other: AbsoluteTimeRange, ) -> Option<AbsoluteTimeRange>
pub fn union(&self, other: AbsoluteTimeRange) -> AbsoluteTimeRange
pub fn from_relative_time_range( range: &TimeRange, cursor: impl Into<TimeInt>, ) -> AbsoluteTimeRange