EntityDb

Struct EntityDb 

pub struct EntityDb {
    pub data_source: Option<LogSource>,
    /* private fields */
}
An in-memory database built from a stream of LogMsges.

NOTE: all mutation is to be done via public functions!

Fields

data_source: Option<LogSource>

Set by whomever created this EntityDb.

Clones of an EntityDb gets a None source.

Implementations

Source

impl EntityDb

pub fn new(store_id: StoreId) -> EntityDb

pub fn with_store_config( store_id: StoreId, store_config: ChunkStoreConfig, ) -> EntityDb

pub fn tree(&self) -> &EntityTree

pub fn format_with_components(&self) -> String

Formats the entity tree into a human-readable text representation with component schema information.

pub fn storage_engine(&self) -> StorageEngineReadGuard<'_>

Returns a read-only guard to the backing StorageEngine.

pub unsafe fn storage_engine_raw(&self) -> &StorageEngine

Returns a reference to the backing StorageEngine.

This can be used to obtain a clone of the StorageEngine.

Safety

Trying to lock the StorageEngine (whether read or write) while the computation of a viewer’s frame is already in progress will lead to data inconsistencies, livelocks and deadlocks. The viewer runs a synchronous work-stealing scheduler (rayon) as well as an asynchronous one (tokio): when and where locks are taken is entirely non-deterministic (even unwanted reentrancy is a possibility).

Don’t use this unless you know what you’re doing. Use Self::storage_engine instead.

pub fn storage_engine_arc(&self) -> StorageEngineArcReadGuard

Returns a read-only guard to the backing StorageEngine.

That guard can be cloned at will and has a static lifetime.

It is not possible to insert any more data in this EntityDb until the returned guard, and any clones, have been dropped.

pub fn rrd_manifest_index(&self) -> &RrdManifestIndex

pub fn store_info_msg(&self) -> Option<&SetStoreInfo>

pub fn store_info(&self) -> Option<&StoreInfo>

pub fn application_id(&self) -> &ApplicationId

pub fn recording_id(&self) -> &RecordingId

pub fn store_kind(&self) -> StoreKind

pub fn store_id(&self) -> &StoreId

pub fn store_class(&self) -> EntityDbClass<'_>

Returns the EntityDbClass of this entity db.

pub fn recording_info_property<C>( &self, component: ComponentIdentifier, ) -> Option<C>
where C: Component,

Read one of the built-in RecordingInfo properties.

pub fn set_recording_property<Component>( &mut self, entity_path: EntityPath, component_descr: ComponentDescriptor, value: &Component, ) -> Result<(), Error>
where Component: Component,

Use can use this both for setting the built-in RecordingInfo components, and for setting custom properties on the recording.

pub fn timeline_type(&self, timeline_name: &TimelineName) -> TimeType

pub fn latest_at( &self, query: &LatestAtQuery, entity_path: &EntityPath, components: impl IntoIterator<Item = ComponentIdentifier>, ) -> LatestAtResults

Queries for the given components using latest-at semantics.

See re_query::LatestAtResults for more information about how to handle the results.

This is a cached API – data will be lazily cached upon access.

pub fn latest_at_component<C>( &self, entity_path: &EntityPath, query: &LatestAtQuery, component: ComponentIdentifier, ) -> Option<((TimeInt, RowId), C)>
where C: Component,

Get the latest index and value for a given dense re_types_core::Component.

This assumes that the row we get from the store contains at most one instance for this component; it will log a warning otherwise.

This should only be used for “mono-components” such as Transform and Tensor.

This is a best-effort helper, it will merely log errors on failure.

pub fn latest_at_component_quiet<C>( &self, entity_path: &EntityPath, query: &LatestAtQuery, component: ComponentIdentifier, ) -> Option<((TimeInt, RowId), C)>
where C: Component,

Get the latest index and value for a given dense re_types_core::Component.

This assumes that the row we get from the store contains at most one instance for this component; it will log a warning otherwise.

This should only be used for “mono-components” such as Transform and Tensor.

This is a best-effort helper, and will quietly swallow any errors.

pub fn latest_at_component_at_closest_ancestor<C>( &self, entity_path: &EntityPath, query: &LatestAtQuery, component: ComponentIdentifier, ) -> Option<(EntityPath, (TimeInt, RowId), C)>
where C: Component,

pub fn cloned_from(&self) -> Option<&StoreId>

If this entity db is the result of a clone, which store was it cloned from?

A cloned store always gets a new unique ID.

We currently only use entity db cloning for blueprints: when we activate a default blueprint that was received on the wire (e.g. from a recording), we clone it and make the clone the active blueprint. This means all active blueprints are clones.

pub fn timelines(&self) -> BTreeMap<TimelineName, Timeline>

pub fn timeline_histograms(&self) -> &TimeHistogramPerTimeline

When do we have data on each timeline?

pub fn time_range_for( &self, timeline: &TimelineName, ) -> Option<AbsoluteTimeRange>

Returns the time range of data on the given timeline, ignoring any static times.

pub fn time_histogram(&self, timeline: &TimelineName) -> Option<&TimeHistogram>

Histogram of all events on the timeeline, of all entities.

pub fn num_rows(&self) -> u64

pub fn generation(&self) -> ChunkStoreGeneration

Return the current ChunkStoreGeneration. This can be used to determine whether the database has been modified since the last time it was queried.

pub fn last_modified_at(&self) -> Instant

pub fn latest_row_id(&self) -> Option<RowId>

The highest RowId in the store, which corresponds to the last edit time. Ignores deletions.

pub fn is_empty(&self) -> bool

pub fn entity_paths(&self) -> Vec<&EntityPath>

A sorted list of all the entity paths in this database.

pub fn ingestion_stats(&self) -> &IngestionStatistics

pub fn entity_path_from_hash( &self, entity_path_hash: &EntityPathHash, ) -> Option<&EntityPath>

pub fn is_known_entity(&self, entity_path: &EntityPath) -> bool

Returns true also for entities higher up in the hierarchy.

pub fn is_logged_entity(&self, entity_path: &EntityPath) -> bool

If you log world/points, then that is a logged entity, but world is not, unless you log something to world too.

pub fn add_rrd_manifest_message(&mut self, rrd_manifest: RrdManifest)

pub fn add(&mut self, msg: &LogMsg) -> Result<Vec<ChunkStoreEvent>, Error>

pub fn add_chunk( &mut self, chunk: &Arc<Chunk>, ) -> Result<Vec<ChunkStoreEvent>, Error>

Used mostly for tests

pub fn set_store_info(&mut self, store_info: SetStoreInfo)

pub fn purge_fraction_of_ram( &mut self, fraction_to_purge: f32, time_cursor: Option<(Timeline, TimeInt)>, ) -> Vec<ChunkStoreEvent>

Free up some RAM by forgetting the older parts of all timelines.

pub fn gc( &mut self, gc_options: &GarbageCollectionOptions, ) -> Vec<ChunkStoreEvent>

pub fn drop_time_range( &mut self, timeline: &TimelineName, drop_range: AbsoluteTimeRange, ) -> Vec<ChunkStoreEvent>

Drop all events in the given time range from the given timeline.

Used to implement undo (erase the last event from the blueprint db).

pub fn drop_entity_path(&mut self, entity_path: &EntityPath)

Unconditionally drops all the data for a given EntityPath .

This is not recursive. Children of this entity will not be affected.

To drop the entire subtree below an entity, see: Self::drop_entity_path_recursive.

pub fn drop_entity_path_recursive(&mut self, entity_path: &EntityPath)

Unconditionally drops all the data for a given EntityPath and all its children.

pub fn to_messages( &self, time_selection: Option<(TimelineName, AbsoluteTimeRangeF)>, ) -> impl Iterator<Item = Result<LogMsg, ChunkError>>

Export the contents of the current database to a sequence of messages.

If time_selection is specified, then only data for that specific timeline over that specific time range will be accounted for.

pub fn clone_with_new_id(&self, new_id: StoreId) -> Result<EntityDb, Error>

Make a clone of this EntityDb, assigning it a new StoreId.

Source

impl EntityDb

Stats
pub fn subtree_stats_static( &self, engine: &StorageEngineReadGuard<'_>, entity_path: &EntityPath, ) -> ChunkStoreChunkStats

Returns the stats for the static store of the entity and all its children, recursively.

This excludes temporal data.

pub fn subtree_stats_on_timeline( &self, engine: &StorageEngineReadGuard<'_>, entity_path: &EntityPath, timeline: &TimelineName, ) -> ChunkStoreChunkStats

Returns the stats for the entity and all its children on the given timeline, recursively.

This excludes static data.

pub fn subtree_has_data_on_timeline( &self, engine: &StorageEngineReadGuard<'_>, timeline: &TimelineName, entity_path: &EntityPath, ) -> bool

Returns true if an entity or any of its children have any data on the given timeline.

This includes static data.

pub fn subtree_has_temporal_data_on_timeline( &self, engine: &StorageEngineReadGuard<'_>, timeline: &TimelineName, entity_path: &EntityPath, ) -> bool

Returns true if an entity or any of its children have any temporal data on the given timeline.

This ignores static data.

pub fn entity_has_temporal_data_on_timeline( &self, engine: &StorageEngineReadGuard<'_>, timeline: &TimelineName, entity_path: &EntityPath, ) -> bool

Returns true if an entity has any temporal data on the given timeline.

This ignores static data.