pub struct EntityTree {
pub path: EntityPath,
pub children: BTreeMap<EntityPathPart, EntityTree>,
}Expand description
A recursive, manually updated ChunkStoreSubscriber that maintains the entity hierarchy.
The tree contains a list of subtrees, and so on recursively.
Fields
path: EntityPathFull path prefix to the root of this (sub)tree.
children: BTreeMap<EntityPathPart, EntityTree>Direct descendants of this (sub)tree.
Implementations
Sourceimpl EntityTree
impl EntityTree
pub fn root() -> EntityTree
pub fn new(path: EntityPath) -> EntityTree
Sourcepub fn check_is_empty(&self, engine: &StorageEngineReadGuard<'_>) -> bool
pub fn check_is_empty(&self, engine: &StorageEngineReadGuard<'_>) -> bool
Returns true if this entity has no children and no data.
Checking for the absence of data is neither costly nor totally free: do it a few hundreds or
thousands times a frame and it will absolutely kill framerate.
Don’t blindly call this on every existing entity every frame: use ChunkStoreEvents to make
sure anything changed at all first.
Sourcepub fn on_store_additions(&mut self, events: &[ChunkStoreEvent])
pub fn on_store_additions(&mut self, events: &[ChunkStoreEvent])
Updates the EntityTree by applying a batch of ChunkStoreEvents,
adding any new entities to the tree.
Only reacts to additions (event.kind == StoreDiffKind::Addition).
pub fn on_new_entity(&mut self, entity_path: &EntityPath)
Sourcepub fn on_store_deletions(
&mut self,
engine: &StorageEngineReadGuard<'_>,
entity_paths_with_deletions: &HashSet<EntityPath, BuildHasherDefault<NoHashHasher<EntityPath>>>,
events: &[ChunkStoreEvent],
)
pub fn on_store_deletions( &mut self, engine: &StorageEngineReadGuard<'_>, entity_paths_with_deletions: &HashSet<EntityPath, BuildHasherDefault<NoHashHasher<EntityPath>>>, events: &[ChunkStoreEvent], )
Updates the EntityTree by removing any entities which have no data and no children.
pub fn subtree(&self, path: &EntityPath) -> Option<&EntityTree>
Sourcepub fn visit_children_recursively(&self, visitor: impl FnMut(&EntityPath))
pub fn visit_children_recursively(&self, visitor: impl FnMut(&EntityPath))
Invokes visitor for self and all children recursively.
Sourcepub fn find_first_child_recursive(
&self,
predicate: impl FnMut(&EntityPath) -> bool,
) -> Option<&EntityTree>
pub fn find_first_child_recursive( &self, predicate: impl FnMut(&EntityPath) -> bool, ) -> Option<&EntityTree>
Invokes the predicate for self and all children recursively,
returning the first entity for which the predicate returns true.
Note that this function has early return semantics, meaning if multiple
entities would return true, only the first is returned.
The entities are yielded in order of their entity paths.