pub struct Client { /* private fields */ }Expand description
This is the gRPC client used for the SDK-side log-sink.
Implementations
Sourceimpl Client
impl Client
pub fn new(uri: ProxyUri, options: Options) -> Client
Sourcepub async fn send_async(&self, msg: LogMsg)
pub async fn send_async(&self, msg: LogMsg)
Send a message asynchronously with backpressure.
This will block (async) if the channel is full.
Sourcepub fn send_blocking(&self, msg: LogMsg)
pub fn send_blocking(&self, msg: LogMsg)
Send a message with blocking backpressure.
This will block the current thread if the channel is full.
Sourcepub fn status(&self) -> ClientConnectionState
pub fn status(&self) -> ClientConnectionState
Whether the client is connected to a remote server.
Sourcepub fn flush_blocking(&self, timeout: Duration) -> Result<(), GrpcFlushError>
pub fn flush_blocking(&self, timeout: Duration) -> Result<(), GrpcFlushError>
Block until all messages are sent, or there is a failure.
If the gRPC connection has not yet been established,
this call will block for at most Options::connect_timeout_on_flush.
This means this function will only block all the way to the given timeout argument
IF there is some hope of progress being made - i.e. the connection open.
If the gRPC connection was severed before all messages were sent, this function will return an error.
If a timeout is provided, we will break when that timeout is received, returning an error.