pub struct BlueprintActivationCommand {
pub blueprint_id: StoreId,
pub make_active: bool,
pub make_default: bool,
}Expand description
Command used for activating a blueprint once it has been fully transmitted.
This command serves two purposes:
- It is important that a blueprint is never activated before it has been fully transmitted. Displaying, or allowing a user to modify, a half-transmitted blueprint can cause confusion and bad interactions with the view heuristics.
- Additionally, this command allows fine-tuning the activation behavior itself by specifying whether the blueprint should be immediately activated, or only become the default for future activations.
Fields
blueprint_id: StoreIdThe blueprint this command refers to.
make_active: boolImmediately make this the active blueprint for the associated app_id.
Note that setting this to false does not mean the blueprint may not still end
up becoming active. In particular, if make_default is true and there is no other
currently active blueprint.
make_default: boolMake this the default blueprint for the app_id.
The default blueprint will be used as the template when the user resets the blueprint for the app. It will also become the active blueprint if no other blueprint is currently active.
Implementations
Sourceimpl BlueprintActivationCommand
impl BlueprintActivationCommand
Sourcepub fn make_default(blueprint_id: StoreId) -> BlueprintActivationCommand
pub fn make_default(blueprint_id: StoreId) -> BlueprintActivationCommand
Make blueprint_id the default blueprint for its associated app_id.
Sourcepub fn make_active(blueprint_id: StoreId) -> BlueprintActivationCommand
pub fn make_active(blueprint_id: StoreId) -> BlueprintActivationCommand
Immediately make blueprint_id the active blueprint for its associated app_id.
This also sets make_default to true.