pub struct DataPath {
pub entity_path: EntityPath,
pub instance: Option<Instance>,
pub component: Option<ComponentIdentifier>,
}Expand description
A general path to some data.
This always starts with an EntityPath, followed by an optional instance index,
followed by an optional ComponentIdentifier.
For instance:
pointspoints:Colorpoints[#42]points[#42]:Color
Fields
entity_path: EntityPathinstance: Option<Instance>component: Option<ComponentIdentifier>Trait Implementations
impl Eq for DataPath
Sourceimpl FromStr for DataPath
impl FromStr for DataPath
Sourcefn from_str(path: &str) -> Result<DataPath, <DataPath as FromStr>::Err>
fn from_str(path: &str) -> Result<DataPath, <DataPath as FromStr>::Err>
For instance:
/world/points/world/points:Color/world/points:Points3D:Color/world/points:Points3D:Color#colors/world/points[#42]/world/points[#42]:rerun.components.Color/world/points[#42]:Points3D:Color#colors
(the leadign slash is optional)
Sourcetype Err = PathParseError
type Err = PathParseError
The associated error which can be returned from parsing.
Sourceimpl Ord for DataPath
impl Ord for DataPath
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for DataPath
impl PartialOrd for DataPath
Sourceimpl SizeBytes for DataPath
impl SizeBytes for DataPath
const IS_POD: bool
Sourcefn heap_size_bytes(&self) -> u64
fn heap_size_bytes(&self) -> u64
Returns how many bytes
self uses on the heap. Read moreSourcefn total_size_bytes(&self) -> u64
fn total_size_bytes(&self) -> u64
Returns the total size of
self in bytes, accounting for both stack and heap space.Sourcefn stack_size_bytes(&self) -> u64
fn stack_size_bytes(&self) -> u64
Returns the total size of
self on the stack, in bytes. Read moreimpl StructuralPartialEq for DataPath