pub struct Help { /* private fields */ }Expand description
A help popup where you can show markdown text and controls as a table.
Implementations
Sourceimpl Help
impl Help
pub fn title(&self) -> Option<&str>
Sourcepub fn new_without_title() -> Help
pub fn new_without_title() -> Help
Create a new help popup.
Sourcepub fn horizontal_spacing(self, horizontal_spacing: f32) -> Help
pub fn horizontal_spacing(self, horizontal_spacing: f32) -> Help
Minimum distance between key and value
Sourcepub fn docs_link(self, docs_link: impl Into<String>) -> Help
pub fn docs_link(self, docs_link: impl Into<String>) -> Help
Add a docs link, to be shown in the top right corner.
Sourcepub fn controls(self, controls: Vec<ControlRow>) -> Help
pub fn controls(self, controls: Vec<ControlRow>) -> Help
Add a controls section.
Sourcepub fn control(
self,
label: impl Into<String>,
items: impl IntoAtoms<'static>,
) -> Help
pub fn control( self, label: impl Into<String>, items: impl IntoAtoms<'static>, ) -> Help
Add a single control row to the last controls section.
Split any + or / into an extra IconTextItem, like this:
re_ui::Help::new("Example").control("Pan", ("click", "+", "drag"));Sourcepub fn control_separator(self) -> Help
pub fn control_separator(self) -> Help
Create a new empty control section.
Sourcepub fn ui(self, ui: &mut Ui)
pub fn ui(self, ui: &mut Ui)
Show the help popup. Usually you want to show this in egui::Response::on_hover_ui.