pub enum ContentsName {
Named(String),
Placeholder(String),
}Expand description
The name of a Contents.
Variants
Named(String)
This Contents has been given a name by the user.
Placeholder(String)
This Contents is unnamed and should be displayed with this placeholder name.