pub enum Item {
AppId(ApplicationId),
DataSource(LogSource),
StoreId(StoreId),
TableId(TableId),
InstancePath(InstancePath),
ComponentPath(ComponentPath),
Container(BlueprintId<ContainerIdRegistry>),
View(BlueprintId<ViewIdRegistry>),
DataResult(DataResultInteractionAddress),
RedapEntry(EntryUri),
RedapServer(Origin),
}Expand description
One “thing” in the UI.
This is the granularity of what is selectable and hoverable.
Variants
AppId(ApplicationId)
Select a specific application, to see which recordings and blueprints are loaded for it.
DataSource(LogSource)
A place where data comes from, e.g. the path to a .rrd or a gRPC URL.
StoreId(StoreId)
A recording (or blueprint)
TableId(TableId)
A table (i.e. a dataframe)
InstancePath(InstancePath)
An entity or instance from the chunk store.
ComponentPath(ComponentPath)
A component of an entity from the chunk store.
Container(BlueprintId<ContainerIdRegistry>)
A viewport container.
View(BlueprintId<ViewIdRegistry>)
A viewport view.
DataResult(DataResultInteractionAddress)
An entity or instance in the context of a view’s data results.
RedapEntry(EntryUri)
A table or dataset entry stored in a Redap server.
RedapServer(Origin)
A Redap server.
Implementations
Sourceimpl Item
impl Item
Sourcepub fn welcome_page() -> Item
pub fn welcome_page() -> Item
The example page / welcome screen
pub fn redap_origin(&self) -> Option<&Origin>
pub fn view_id(&self) -> Option<BlueprintId<ViewIdRegistry>>
pub fn entity_path(&self) -> Option<&EntityPath>
Sourcepub fn is_compatible_with_route(&self, route: &Route) -> bool
pub fn is_compatible_with_route(&self, route: &Route) -> bool
Is this item compatible with the given crate::Route?
For example, a recording or redap entry that belongs to a different route than the currently active one is incompatible.
Sourcepub fn to_data_path(&self) -> Option<DataPath>
pub fn to_data_path(&self) -> Option<DataPath>
Converts this item to a data path if possible.