pub struct ComponentUiTypes(/* private fields */);Expand description
Specifies which UI callbacks are available for a component.
Implementations
Sourceimpl ComponentUiTypes
impl ComponentUiTypes
Sourcepub const DisplayUi: ComponentUiTypes
pub const DisplayUi: ComponentUiTypes
Display the component in a read-only way.
Sourcepub const SingleLineEditor: ComponentUiTypes
pub const SingleLineEditor: ComponentUiTypes
Edit the component in a single re_ui::list_item::ListItem line.
Sourcepub const MultiLineEditor: ComponentUiTypes
pub const MultiLineEditor: ComponentUiTypes
Edit the component over multiple re_ui::list_item::ListItems.
Sourcepub const MultiValueEditor: ComponentUiTypes
pub const MultiValueEditor: ComponentUiTypes
Edit multiple values (arrays) of this component at once.
Sourceimpl ComponentUiTypes
impl ComponentUiTypes
Sourcepub const fn empty() -> ComponentUiTypes
pub const fn empty() -> ComponentUiTypes
Get a flags value with all bits unset.
Sourcepub const fn all() -> ComponentUiTypes
pub const fn all() -> ComponentUiTypes
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<ComponentUiTypes>
pub const fn from_bits(bits: u8) -> Option<ComponentUiTypes>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> ComponentUiTypes
pub const fn from_bits_truncate(bits: u8) -> ComponentUiTypes
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> ComponentUiTypes
pub const fn from_bits_retain(bits: u8) -> ComponentUiTypes
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ComponentUiTypes>
pub fn from_name(name: &str) -> Option<ComponentUiTypes>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ComponentUiTypes) -> bool
pub const fn intersects(&self, other: ComponentUiTypes) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ComponentUiTypes) -> bool
pub const fn contains(&self, other: ComponentUiTypes) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ComponentUiTypes)
pub fn insert(&mut self, other: ComponentUiTypes)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ComponentUiTypes)
pub fn remove(&mut self, other: ComponentUiTypes)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ComponentUiTypes)
pub fn toggle(&mut self, other: ComponentUiTypes)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ComponentUiTypes, value: bool)
pub fn set(&mut self, other: ComponentUiTypes, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ComponentUiTypes) -> ComponentUiTypes
pub const fn intersection(self, other: ComponentUiTypes) -> ComponentUiTypes
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ComponentUiTypes) -> ComponentUiTypes
pub const fn union(self, other: ComponentUiTypes) -> ComponentUiTypes
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ComponentUiTypes) -> ComponentUiTypes
pub const fn difference(self, other: ComponentUiTypes) -> ComponentUiTypes
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ComponentUiTypes,
) -> ComponentUiTypes
pub const fn symmetric_difference( self, other: ComponentUiTypes, ) -> ComponentUiTypes
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ComponentUiTypes
pub const fn complement(self) -> ComponentUiTypes
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ComponentUiTypes
impl ComponentUiTypes
Sourcepub const fn iter(&self) -> Iter<ComponentUiTypes> ⓘ
pub const fn iter(&self) -> Iter<ComponentUiTypes> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ComponentUiTypes> ⓘ
pub const fn iter_names(&self) -> IterNames<ComponentUiTypes> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ComponentUiTypes
impl ComponentUiTypes
Sourcepub fn has_edit_ui(&self, multi_value: bool) -> bool
pub fn has_edit_ui(&self, multi_value: bool) -> bool
Whether an edit UI is available.
If multi_value is true, requires a Self::MultiValueEditor to be registered.