ChunkId

Struct ChunkId 

pub struct ChunkId(/* private fields */);
A unique ID for a Chunk.

Chunks are the atomic unit of ingestion, transport, storage, events and GC in Rerun.

Internally, a Chunk is made up of rows, which are themselves uniquely identified by their RowId.

There is no relationship whatsoever between a ChunkId and the RowIds within that chunk.

String format

Example: chunk_182342300C5F8C327a7b4a6e5a379ac4. The “chunk_” prefix is optional when parsing. See re_tuid docs for explanations of TUID namespaces.

Uniqueness

ChunkId are assumed unique within a single Recording.

The chunk store will treat two chunks with the same ChunkId as the same, and only keep one of them (which one is kept is an arbitrary and unstable implementation detail).

This makes it easy to build and maintain secondary indices around RowIds with few to no extraneous state tracking.

Garbage collection

Garbage collection is handled at the chunk level by first ordering the chunks based on the minimum RowId present in each of them. Garbage collection therefore happens (roughly) in the logger’s wall-clock order.

This has very important implications when inserting data far into the past or into the future: think carefully about your RowIds in these cases.

Implementations

Source

impl ChunkId

pub const ZERO: ChunkId

pub const MAX: ChunkId

pub fn new() -> ChunkId

Create a new unique ChunkId based on the current time.

pub fn from_tuid(tuid: Tuid) -> ChunkId

pub fn as_tuid(&self) -> Tuid

pub fn next(&self) -> ChunkId

Returns the next logical ChunkId.

Beware: wrong usage can easily lead to conflicts. Prefer ChunkId::new when unsure.

Only available in debug builds (tests). Use ChunkId::new in production.

pub fn from_u128(id: u128) -> ChunkId

pub fn arrow_from_slice(slice: &[ChunkId]) -> FixedSizeBinaryArray

Source

impl ChunkId

Methods from Deref<Target = Tuid>

pub const ARROW_EXTENSION_NAME: &'static str = "rerun.datatypes.TUID"

pub const ZERO: Tuid

pub const MAX: Tuid

pub fn as_u128(&self) -> u128

pub fn as_bytes(&self) -> [u8; 16]

Returns most significant byte first (big endian).

pub fn nanos_since_epoch(&self) -> u64

Approximate nanoseconds since unix epoch.

The upper 64 bits of the Tuid.

pub fn inc(&self) -> u64

The increment part of the Tuid.

The lower 64 bits of the Tuid.

pub fn next(&self) -> Tuid

Returns the next logical Tuid.

Wraps the monotonically increasing back to zero on overflow.

Beware: wrong usage can easily lead to conflicts. Prefer Tuid::new when unsure.

pub fn incremented_by(&self, n: u64) -> Tuid

Returns the n-next logical Tuid.

This is equivalent to calling Tuid::next n times. Wraps the monotonically increasing back to zero on overflow.

Beware: wrong usage can easily lead to conflicts. Prefer Tuid::new when unsure.

pub fn short_string(&self) -> String

A shortened string representation of the Tuid.