pub struct PendingRow {
pub row_id: RowId,
pub timepoint: TimePoint,
pub components: HashMap<ComponentIdentifier, SerializedComponentBatch, BuildHasherDefault<NoHashHasher<ComponentIdentifier>>>,
}Expand description
A single row’s worth of data (i.e. a single log call).
Send those to the batcher to build up a Chunk.
Fields
row_id: RowIdAuto-generated TUID, uniquely identifying this event and keeping track of the client’s
wall-clock.
timepoint: TimePointUser-specified TimePoint for this event.
components: HashMap<ComponentIdentifier, SerializedComponentBatch, BuildHasherDefault<NoHashHasher<ComponentIdentifier>>>The component data.
Each array is a single component, i.e. not a list array.
Implementations
Sourceimpl PendingRow
impl PendingRow
pub fn new( timepoint: TimePoint, components: HashMap<ComponentIdentifier, SerializedComponentBatch, BuildHasherDefault<NoHashHasher<ComponentIdentifier>>>, ) -> PendingRow
pub fn from_iter( timepoint: TimePoint, components: impl IntoIterator<Item = SerializedComponentBatch>, ) -> PendingRow
Sourceimpl PendingRow
impl PendingRow
Sourcepub fn into_chunk(self, entity_path: EntityPath) -> Result<Chunk, ChunkError>
pub fn into_chunk(self, entity_path: EntityPath) -> Result<Chunk, ChunkError>
Turn a single row into a Chunk of its own.
That’s very wasteful, probably don’t do that outside of testing, or unless you have very good reasons too.
See also Self::many_into_chunks.
Sourcepub fn many_into_chunks(
entity_path: EntityPath,
chunk_max_rows_if_unsorted: u64,
rows: Vec<PendingRow>,
) -> impl Iterator<Item = Result<Chunk, ChunkError>>
pub fn many_into_chunks( entity_path: EntityPath, chunk_max_rows_if_unsorted: u64, rows: Vec<PendingRow>, ) -> impl Iterator<Item = Result<Chunk, ChunkError>>
This turns a batch of PendingRows into a Chunk.
There are a lot of conditions to fulfill for a Chunk to be valid: this helper makes
sure to fulfill all of them by splitting the chunk into one or more pieces as necessary.
In particular, a Chunk cannot:
- contain data for more than one entity path
- contain rows with different sets of timelines
- use more than one datatype for a given component
- contain more rows than a pre-configured threshold if one or more timelines are unsorted