Boxes3D

Struct Boxes3D 

pub struct Boxes3D {
    pub half_sizes: Option<SerializedComponentBatch>,
    pub centers: Option<SerializedComponentBatch>,
    pub rotation_axis_angles: Option<SerializedComponentBatch>,
    pub quaternions: Option<SerializedComponentBatch>,
    pub colors: Option<SerializedComponentBatch>,
    pub radii: Option<SerializedComponentBatch>,
    pub fill_mode: Option<SerializedComponentBatch>,
    pub labels: Option<SerializedComponentBatch>,
    pub show_labels: Option<SerializedComponentBatch>,
    pub class_ids: Option<SerializedComponentBatch>,
}
Archetype: 3D boxes with half-extents and optional center, rotations, colors etc.

If there’s more instance poses than half sizes, the last box’s orientation will be repeated for the remaining poses. Orienting and placing boxes forms a separate transform that is applied prior to archetypes::InstancePoses3D and archetypes::Transform3D.

Example

Batch of 3D boxes

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let rec = rerun::RecordingStreamBuilder::new("rerun_example_box3d_batch").spawn()?;

    rec.log(
        "batch",
        &rerun::Boxes3D::from_centers_and_half_sizes(
            [(2.0, 0.0, 0.0), (-2.0, 0.0, 0.0), (0.0, 0.0, 2.0)],
            [(2.0, 2.0, 1.0), (1.0, 1.0, 0.5), (2.0, 0.5, 1.0)],
        )
        .with_quaternions([
            rerun::Quaternion::IDENTITY,
            rerun::Quaternion::from_xyzw([0.0, 0.0, 0.382683, 0.923880]), // 45 degrees around Z
        ])
        .with_radii([0.025])
        .with_colors([
            rerun::Color::from_rgb(255, 0, 0),
            rerun::Color::from_rgb(0, 255, 0),
            rerun::Color::from_rgb(0, 0, 255),
        ])
        .with_fill_mode(rerun::FillMode::Solid)
        .with_labels(["red", "green", "blue"]),
    )?;

    Ok(())
}

Fields

half_sizes: Option<SerializedComponentBatch>

All half-extents that make up the batch of boxes.

centers: Option<SerializedComponentBatch>

Optional center positions of the boxes.

If not specified, the centers will be at (0, 0, 0).

rotation_axis_angles: Option<SerializedComponentBatch>

Rotations via axis + angle.

If no rotation is specified, the axes of the boxes align with the axes of the local coordinate system.

quaternions: Option<SerializedComponentBatch>

Rotations via quaternion.

If no rotation is specified, the axes of the boxes align with the axes of the local coordinate system.

colors: Option<SerializedComponentBatch>

Optional colors for the boxes.

Alpha channel is used for transparency for solid fill-mode.

radii: Option<SerializedComponentBatch>

Optional radii for the lines that make up the boxes.

fill_mode: Option<SerializedComponentBatch>

Optionally choose whether the boxes are drawn with lines or solid.

labels: Option<SerializedComponentBatch>

Optional text labels for the boxes.

If there’s a single label present, it will be placed at the center of the entity. Otherwise, each instance will have its own label.

show_labels: Option<SerializedComponentBatch>

Whether the text labels should be shown.

If not set, labels will automatically appear when there is exactly one label for this entity or the number of instances on this entity is under a certain threshold.

class_ids: Option<SerializedComponentBatch>

Optional components::ClassIds for the boxes.

The components::ClassId provides colors and labels if not specified explicitly.

Implementations

Source

impl Boxes3D

pub fn descriptor_half_sizes() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::half_sizes.

The corresponding component is crate::components::HalfSize3D.

pub fn descriptor_centers() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::centers.

The corresponding component is crate::components::Translation3D.

pub fn descriptor_rotation_axis_angles() -> ComponentDescriptor

pub fn descriptor_quaternions() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::quaternions.

The corresponding component is crate::components::RotationQuat.

pub fn descriptor_colors() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::colors.

The corresponding component is crate::components::Color.

pub fn descriptor_radii() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::radii.

The corresponding component is crate::components::Radius.

pub fn descriptor_fill_mode() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::fill_mode.

The corresponding component is crate::components::FillMode.

pub fn descriptor_labels() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::labels.

The corresponding component is crate::components::Text.

pub fn descriptor_show_labels() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::show_labels.

The corresponding component is crate::components::ShowLabels.

pub fn descriptor_class_ids() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::class_ids.

The corresponding component is crate::components::ClassId.

Source

impl Boxes3D

pub const NUM_COMPONENTS: usize = 10usize

The total number of components in the archetype: 1 required, 2 recommended, 7 optional

Source

impl Boxes3D

pub fn update_fields() -> Boxes3D

Update only some specific fields of a Boxes3D.

pub fn clear_fields() -> Boxes3D

Clear all the fields of a Boxes3D.

pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
where I: IntoIterator<Item = usize> + Clone,

Partitions the component data into multiple sub-batches.

Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns instead, via SerializedComponentBatch::partitioned.

This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.

The specified lengths must sum to the total length of the component batch.

pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>

Helper to partition the component data into unit-length sub-batches.

This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n), where n is automatically guessed.

pub fn with_half_sizes( self, half_sizes: impl IntoIterator<Item = impl Into<HalfSize3D>>, ) -> Boxes3D

All half-extents that make up the batch of boxes.

pub fn with_centers( self, centers: impl IntoIterator<Item = impl Into<Translation3D>>, ) -> Boxes3D

Optional center positions of the boxes.

If not specified, the centers will be at (0, 0, 0).

pub fn with_rotation_axis_angles( self, rotation_axis_angles: impl IntoIterator<Item = impl Into<RotationAxisAngle>>, ) -> Boxes3D

Rotations via axis + angle.

If no rotation is specified, the axes of the boxes align with the axes of the local coordinate system.

pub fn with_quaternions( self, quaternions: impl IntoIterator<Item = impl Into<RotationQuat>>, ) -> Boxes3D

Rotations via quaternion.

If no rotation is specified, the axes of the boxes align with the axes of the local coordinate system.

pub fn with_colors( self, colors: impl IntoIterator<Item = impl Into<Color>>, ) -> Boxes3D

Optional colors for the boxes.

Alpha channel is used for transparency for solid fill-mode.

pub fn with_radii( self, radii: impl IntoIterator<Item = impl Into<Radius>>, ) -> Boxes3D

Optional radii for the lines that make up the boxes.

pub fn with_fill_mode(self, fill_mode: impl Into<FillMode>) -> Boxes3D

Optionally choose whether the boxes are drawn with lines or solid.

pub fn with_many_fill_mode( self, fill_mode: impl IntoIterator<Item = impl Into<FillMode>>, ) -> Boxes3D

This method makes it possible to pack multiple crate::components::FillMode in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_fill_mode should be used when logging a single row’s worth of data.

pub fn with_labels( self, labels: impl IntoIterator<Item = impl Into<Text>>, ) -> Boxes3D

Optional text labels for the boxes.

If there’s a single label present, it will be placed at the center of the entity. Otherwise, each instance will have its own label.

pub fn with_show_labels(self, show_labels: impl Into<ShowLabels>) -> Boxes3D

Whether the text labels should be shown.

If not set, labels will automatically appear when there is exactly one label for this entity or the number of instances on this entity is under a certain threshold.

pub fn with_many_show_labels( self, show_labels: impl IntoIterator<Item = impl Into<ShowLabels>>, ) -> Boxes3D

This method makes it possible to pack multiple crate::components::ShowLabels in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_show_labels should be used when logging a single row’s worth of data.

pub fn with_class_ids( self, class_ids: impl IntoIterator<Item = impl Into<ClassId>>, ) -> Boxes3D

Optional components::ClassIds for the boxes.

The components::ClassId provides colors and labels if not specified explicitly.

Source

impl Boxes3D

pub fn from_half_sizes( half_sizes: impl IntoIterator<Item = impl Into<HalfSize3D>>, ) -> Boxes3D

Creates new Boxes3D with Self::half_sizes centered around the local origin.

pub fn from_centers_and_half_sizes( centers: impl IntoIterator<Item = impl Into<Translation3D>>, half_sizes: impl IntoIterator<Item = impl Into<HalfSize3D>>, ) -> Boxes3D

Creates new Boxes3D with Self::centers and Self::half_sizes.

pub fn from_sizes(sizes: impl IntoIterator<Item = impl Into<Vec3D>>) -> Boxes3D

Creates new Boxes3D with Self::half_sizes created from (full) sizes.

TODO(#3285): Does not preserve data as-is and instead creates half-sizes from the input data.

pub fn from_centers_and_sizes( centers: impl IntoIterator<Item = impl Into<Translation3D>>, sizes: impl IntoIterator<Item = impl Into<Vec3D>>, ) -> Boxes3D

Creates new Boxes3D with Self::centers and Self::half_sizes created from centers and (full) sizes.

TODO(#3285): Does not preserve data as-is and instead creates half-sizes from the input data.

pub fn from_mins_and_sizes( mins: impl IntoIterator<Item = impl Into<Vec3D>>, sizes: impl IntoIterator<Item = impl Into<Vec3D>>, ) -> Boxes3D

Creates new Boxes3D with Self::centers and Self::half_sizes created from minimums and (full) sizes.

TODO(#3285): Does not preserve data as-is and instead creates centers and half-sizes from the input data.