Capsules3D

Struct Capsules3D 

pub struct Capsules3D {
    pub lengths: Option<SerializedComponentBatch>,
    pub radii: Option<SerializedComponentBatch>,
    pub translations: Option<SerializedComponentBatch>,
    pub rotation_axis_angles: Option<SerializedComponentBatch>,
    pub quaternions: Option<SerializedComponentBatch>,
    pub colors: Option<SerializedComponentBatch>,
    pub line_radii: Option<SerializedComponentBatch>,
    pub fill_mode: Option<SerializedComponentBatch>,
    pub labels: Option<SerializedComponentBatch>,
    pub show_labels: Option<SerializedComponentBatch>,
    pub class_ids: Option<SerializedComponentBatch>,
}
Archetype: 3D capsules; cylinders with hemispherical caps.

Capsules are defined by two endpoints (the centers of their end cap spheres), which are located at (0, 0, 0) and (0, 0, length), that is, extending along the positive direction of the Z axis. Capsules in other orientations may be produced by applying a rotation to the entity or instances.

If there’s more instance poses than lengths & radii, the last capsule’s orientation will be repeated for the remaining poses. Orienting and placing capsules forms a separate transform that is applied prior to archetypes::InstancePoses3D and archetypes::Transform3D.

Example

Batch of capsules

use rerun::external::glam::vec3;

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let rec = rerun::RecordingStreamBuilder::new("rerun_example_capsule3d_batch").spawn()?;

    rec.log(
        "capsules",
        &rerun::Capsules3D::from_lengths_and_radii(
            [0.0, 2.0, 4.0, 6.0, 8.0],
            [1.0, 0.5, 0.5, 0.5, 1.0],
        )
        .with_colors([
            rerun::Color::from_rgb(255, 0, 0),
            rerun::Color::from_rgb(188, 188, 0),
            rerun::Color::from_rgb(0, 255, 0),
            rerun::Color::from_rgb(0, 188, 188),
            rerun::Color::from_rgb(0, 0, 255),
        ])
        .with_translations([
            vec3(0., 0., 0.),
            vec3(2., 0., 0.),
            vec3(4., 0., 0.),
            vec3(6., 0., 0.),
            vec3(8., 0., 0.),
        ])
        .with_rotation_axis_angles((0..5).map(|i| {
            rerun::RotationAxisAngle::new(
                [1.0, 0.0, 0.0],
                rerun::Angle::from_degrees(i as f32 * -22.5),
            )
        })),
    )?;

    Ok(())
}

Fields

lengths: Option<SerializedComponentBatch>

Lengths of the capsules, defined as the distance between the centers of the endcaps.

radii: Option<SerializedComponentBatch>

Radii of the capsules.

translations: Option<SerializedComponentBatch>

Optional translations of the capsules.

If not specified, one end of each capsule will be at (0, 0, 0).

rotation_axis_angles: Option<SerializedComponentBatch>

Rotations via axis + angle.

If no rotation is specified, the capsules align with the +Z axis of the local coordinate system.

quaternions: Option<SerializedComponentBatch>

Rotations via quaternion.

If no rotation is specified, the capsules align with the +Z axis of the local coordinate system.

colors: Option<SerializedComponentBatch>

Optional colors for the capsules.

Alpha channel is used for transparency for solid fill-mode.

line_radii: Option<SerializedComponentBatch>

Optional radii for the lines used when the cylinder is rendered as a wireframe.

fill_mode: Option<SerializedComponentBatch>

Optionally choose whether the cylinders are drawn with lines or solid.

labels: Option<SerializedComponentBatch>

Optional text labels for the capsules, which will be located at their centers.

show_labels: Option<SerializedComponentBatch>

Whether the text labels should be shown.

If not set, labels will automatically appear when there is exactly one label for this entity or the number of instances on this entity is under a certain threshold.

class_ids: Option<SerializedComponentBatch>

Optional class ID for the ellipsoids.

The class ID provides colors and labels if not specified explicitly.

Implementations

Source

impl Capsules3D

pub fn descriptor_lengths() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::lengths.

The corresponding component is crate::components::Length.

pub fn descriptor_radii() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::radii.

The corresponding component is crate::components::Radius.

pub fn descriptor_translations() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::translations.

The corresponding component is crate::components::Translation3D.

pub fn descriptor_rotation_axis_angles() -> ComponentDescriptor

pub fn descriptor_quaternions() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::quaternions.

The corresponding component is crate::components::RotationQuat.

pub fn descriptor_colors() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::colors.

The corresponding component is crate::components::Color.

pub fn descriptor_line_radii() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::line_radii.

The corresponding component is crate::components::Radius.

pub fn descriptor_fill_mode() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::fill_mode.

The corresponding component is crate::components::FillMode.

pub fn descriptor_labels() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::labels.

The corresponding component is crate::components::Text.

pub fn descriptor_show_labels() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::show_labels.

The corresponding component is crate::components::ShowLabels.

pub fn descriptor_class_ids() -> ComponentDescriptor

Returns the ComponentDescriptor for Self::class_ids.

The corresponding component is crate::components::ClassId.

Source

impl Capsules3D

pub const NUM_COMPONENTS: usize = 11usize

The total number of components in the archetype: 2 required, 2 recommended, 7 optional

Source

impl Capsules3D

pub fn update_fields() -> Capsules3D

Update only some specific fields of a Capsules3D.

pub fn clear_fields() -> Capsules3D

Clear all the fields of a Capsules3D.

pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
where I: IntoIterator<Item = usize> + Clone,

Partitions the component data into multiple sub-batches.

Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns instead, via SerializedComponentBatch::partitioned.

This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.

The specified lengths must sum to the total length of the component batch.

pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>

Helper to partition the component data into unit-length sub-batches.

This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n), where n is automatically guessed.

pub fn with_lengths( self, lengths: impl IntoIterator<Item = impl Into<Length>>, ) -> Capsules3D

Lengths of the capsules, defined as the distance between the centers of the endcaps.

pub fn with_radii( self, radii: impl IntoIterator<Item = impl Into<Radius>>, ) -> Capsules3D

Radii of the capsules.

pub fn with_translations( self, translations: impl IntoIterator<Item = impl Into<Translation3D>>, ) -> Capsules3D

Optional translations of the capsules.

If not specified, one end of each capsule will be at (0, 0, 0).

pub fn with_rotation_axis_angles( self, rotation_axis_angles: impl IntoIterator<Item = impl Into<RotationAxisAngle>>, ) -> Capsules3D

Rotations via axis + angle.

If no rotation is specified, the capsules align with the +Z axis of the local coordinate system.

pub fn with_quaternions( self, quaternions: impl IntoIterator<Item = impl Into<RotationQuat>>, ) -> Capsules3D

Rotations via quaternion.

If no rotation is specified, the capsules align with the +Z axis of the local coordinate system.

pub fn with_colors( self, colors: impl IntoIterator<Item = impl Into<Color>>, ) -> Capsules3D

Optional colors for the capsules.

Alpha channel is used for transparency for solid fill-mode.

pub fn with_line_radii( self, line_radii: impl IntoIterator<Item = impl Into<Radius>>, ) -> Capsules3D

Optional radii for the lines used when the cylinder is rendered as a wireframe.

pub fn with_fill_mode(self, fill_mode: impl Into<FillMode>) -> Capsules3D

Optionally choose whether the cylinders are drawn with lines or solid.

pub fn with_many_fill_mode( self, fill_mode: impl IntoIterator<Item = impl Into<FillMode>>, ) -> Capsules3D

This method makes it possible to pack multiple crate::components::FillMode in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_fill_mode should be used when logging a single row’s worth of data.

pub fn with_labels( self, labels: impl IntoIterator<Item = impl Into<Text>>, ) -> Capsules3D

Optional text labels for the capsules, which will be located at their centers.

pub fn with_show_labels(self, show_labels: impl Into<ShowLabels>) -> Capsules3D

Whether the text labels should be shown.

If not set, labels will automatically appear when there is exactly one label for this entity or the number of instances on this entity is under a certain threshold.

pub fn with_many_show_labels( self, show_labels: impl IntoIterator<Item = impl Into<ShowLabels>>, ) -> Capsules3D

This method makes it possible to pack multiple crate::components::ShowLabels in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_show_labels should be used when logging a single row’s worth of data.

pub fn with_class_ids( self, class_ids: impl IntoIterator<Item = impl Into<ClassId>>, ) -> Capsules3D

Optional class ID for the ellipsoids.

The class ID provides colors and labels if not specified explicitly.

Source

impl Capsules3D

pub fn from_lengths_and_radii( lengths: impl IntoIterator<Item = impl Into<Length>>, radii: impl IntoIterator<Item = f32>, ) -> Capsules3D

Creates a new Capsules3D with the given axis-aligned lengths and radii.

For multiple capsules, you should generally follow this with Capsules3D::with_translations() and one of the rotation methods, in order to move them apart from each other.

pub fn from_endpoints_and_radii( start_points: impl IntoIterator<Item = impl Into<Position3D>>, end_points: impl IntoIterator<Item = impl Into<Position3D>>, radii: impl IntoIterator<Item = f32>, ) -> Capsules3D

Creates a new Capsules3D where each capsule extends between the given pairs of points.