pub struct ChunkStoreDiffVirtualAddition {
pub rrd_manifest: Arc<RrdManifest>,
}Expand description
Everything needed to build custom ChunkStoreSubscribers.
Fields
rrd_manifest: Arc<RrdManifest>The RrdManifest that was passed to ChunkStore::insert_rrd_manifest.
This is very different from the usual chunk-related events as this is purely virtual. Still, even though no physical data was ingested yet, it might be important for downstream consumers to know what kind of virtual data is being referenced from now on. For example, query caches must know about pending tombstones as soon as they start being referenced.
If this is set, all fields below are irrelevant (set to their default/empty values).
Implementations
Sourceimpl ChunkStoreDiffVirtualAddition
impl ChunkStoreDiffVirtualAddition
Sourcepub fn chunk_metas(&self) -> impl Iterator<Item = ChunkMeta>
pub fn chunk_metas(&self) -> impl Iterator<Item = ChunkMeta>
Iterator over ChunkMetas in the new rrd manifest.
In no particular order.