CoordinateFrame

Struct CoordinateFrame 

pub struct CoordinateFrame {
    pub frame: Option<SerializedComponentBatch>,
}
Archetype: Specifies the coordinate frame for an entity.

If not specified, the coordinate frame uses an implicit frame derived from the entity path. The implicit frame’s name is tf#/your/entity/path and has an identity transform connection to its parent path.

To learn more about transforms see Spaces & Transforms in the reference.

Example

Change coordinate frame to different built-in frames

#![expect(clippy::cast_possible_wrap)]

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let rec = rerun::RecordingStreamBuilder::new(
        "rerun_example_transform3d_hierarchy",
    )
    .spawn()?;

    rec.set_time_sequence("time", 0);
    rec.log(
        "red_box",
        &[
            &rerun::Boxes3D::from_half_sizes([(0.5, 0.5, 0.5)])
                .with_colors([(255, 0, 0)])
                as &dyn rerun::AsComponents,
            // Use Transform3D to place the box, so we actually change the underlying coordinate frame and not just the box's pose.
            &rerun::Transform3D::from_translation([2.0, 0.0, 0.0]),
        ],
    )?;
    rec.log(
        "blue_box",
        &[
            &rerun::Boxes3D::from_half_sizes([(0.5, 0.5, 0.5)])
                .with_colors([(0, 0, 255)])
                as &dyn rerun::AsComponents,
            // Use Transform3D to place the box, so we actually change the underlying coordinate frame and not just the box's pose.
            &rerun::Transform3D::from_translation([-2.0, 0.0, 0.0]),
        ],
    )?;
    rec.log(
        "point",
        &rerun::Points3D::new([(0.0, 0.0, 0.0)]).with_radii([0.5]),
    )?;

    // Change where the point is located by cycling through its coordinate frame.
    for (t, frame_id) in ["tf#/red_box", "tf#/blue_box"].into_iter().enumerate()
    {
        rec.set_time_sequence("time", t as i64 + 1); // leave it untouched at t==0.
        rec.log("point", &rerun::CoordinateFrame::new(frame_id))?;
    }

    Ok(())
}

Fields

frame: Option<SerializedComponentBatch>

The coordinate frame to use for the current entity.

Note that empty strings are not valid transform frame IDs.

Implementations

Source

impl CoordinateFrame

Source

impl CoordinateFrame

pub const NUM_COMPONENTS: usize = 1usize

The total number of components in the archetype: 1 required, 0 recommended, 0 optional

Source

impl CoordinateFrame

pub fn new(frame: impl Into<TransformFrameId>) -> CoordinateFrame

Create a new CoordinateFrame.

pub fn update_fields() -> CoordinateFrame

Update only some specific fields of a CoordinateFrame.

pub fn clear_fields() -> CoordinateFrame

Clear all the fields of a CoordinateFrame.

pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
where I: IntoIterator<Item = usize> + Clone,

Partitions the component data into multiple sub-batches.

Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns instead, via SerializedComponentBatch::partitioned.

This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.

The specified lengths must sum to the total length of the component batch.

pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>

Helper to partition the component data into unit-length sub-batches.

This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n), where n is automatically guessed.

pub fn with_frame(self, frame: impl Into<TransformFrameId>) -> CoordinateFrame

The coordinate frame to use for the current entity.

Note that empty strings are not valid transform frame IDs.

pub fn with_many_frame( self, frame: impl IntoIterator<Item = impl Into<TransformFrameId>>, ) -> CoordinateFrame

This method makes it possible to pack multiple crate::components::TransformFrameId in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_frame should be used when logging a single row’s worth of data.