pub struct Ellipsoids3D {
pub half_sizes: Option<SerializedComponentBatch>,
pub centers: Option<SerializedComponentBatch>,
pub rotation_axis_angles: Option<SerializedComponentBatch>,
pub quaternions: Option<SerializedComponentBatch>,
pub colors: Option<SerializedComponentBatch>,
pub line_radii: Option<SerializedComponentBatch>,
pub fill_mode: Option<SerializedComponentBatch>,
pub labels: Option<SerializedComponentBatch>,
pub show_labels: Option<SerializedComponentBatch>,
pub class_ids: Option<SerializedComponentBatch>,
}Expand description
Archetype: 3D ellipsoids or spheres.
This archetype is for ellipsoids or spheres whose size is a key part of the data
(e.g. a bounding sphere).
For points whose radii are for the sake of visualization, use archetypes::Points3D instead.
If there’s more instance poses than half sizes, the last ellipsoid/sphere’s orientation will be repeated for the remaining poses.
Orienting and placing ellipsoids/spheres forms a separate transform that is applied prior to archetypes::InstancePoses3D and archetypes::Transform3D.
Example
Covariance ellipsoid
use rand::prelude::*;
fn main() -> Result<(), Box<dyn std::error::Error>> {
let rec = rerun::RecordingStreamBuilder::new("rerun_example_ellipsoid_simple").spawn()?;
let sigmas: [f32; 3] = [5., 3., 1.];
let mut rng = rand::rngs::SmallRng::seed_from_u64(42);
let normal = rand_distr::Normal::new(0.0, 1.0)?;
rec.log(
"points",
&rerun::Points3D::new((0..50_000).map(|_| {
(
sigmas[0] * normal.sample(&mut rng),
sigmas[1] * normal.sample(&mut rng),
sigmas[2] * normal.sample(&mut rng),
)
}))
.with_radii([0.02])
.with_colors([rerun::Color::from_rgb(188, 77, 185)]),
)?;
rec.log(
"ellipsoid",
&rerun::Ellipsoids3D::from_centers_and_half_sizes(
[(0.0, 0.0, 0.0), (0.0, 0.0, 0.0)],
[sigmas, [sigmas[0] * 3., sigmas[1] * 3., sigmas[2] * 3.]],
)
.with_colors([
rerun::Color::from_rgb(255, 255, 0),
rerun::Color::from_rgb(64, 64, 0),
]),
)?;
Ok(())
}
Fields
half_sizes: Option<SerializedComponentBatch>For each ellipsoid, half of its size on its three axes.
If all components are equal, then it is a sphere with that radius.
centers: Option<SerializedComponentBatch>Optional center positions of the ellipsoids.
If not specified, the centers will be at (0, 0, 0).
rotation_axis_angles: Option<SerializedComponentBatch>Rotations via axis + angle.
If no rotation is specified, the axes of the ellipsoid align with the axes of the local coordinate system.
quaternions: Option<SerializedComponentBatch>Rotations via quaternion.
If no rotation is specified, the axes of the ellipsoid align with the axes of the local coordinate system.
colors: Option<SerializedComponentBatch>Optional colors for the ellipsoids.
Alpha channel is used for transparency for solid fill-mode.
line_radii: Option<SerializedComponentBatch>Optional radii for the lines used when the ellipsoid is rendered as a wireframe.
fill_mode: Option<SerializedComponentBatch>Optionally choose whether the ellipsoids are drawn with lines or solid.
labels: Option<SerializedComponentBatch>Optional text labels for the ellipsoids.
show_labels: Option<SerializedComponentBatch>Whether the text labels should be shown.
If not set, labels will automatically appear when there is exactly one label for this entity or the number of instances on this entity is under a certain threshold.
class_ids: Option<SerializedComponentBatch>Optional class ID for the ellipsoids.
The class ID provides colors and labels if not specified explicitly.
Implementations
Sourceimpl Ellipsoids3D
impl Ellipsoids3D
Sourcepub fn descriptor_half_sizes() -> ComponentDescriptor
pub fn descriptor_half_sizes() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::half_sizes.
The corresponding component is crate::components::HalfSize3D.
Sourcepub fn descriptor_centers() -> ComponentDescriptor
pub fn descriptor_centers() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::centers.
The corresponding component is crate::components::Translation3D.
Sourcepub fn descriptor_rotation_axis_angles() -> ComponentDescriptor
pub fn descriptor_rotation_axis_angles() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::rotation_axis_angles.
The corresponding component is crate::components::RotationAxisAngle.
Sourcepub fn descriptor_quaternions() -> ComponentDescriptor
pub fn descriptor_quaternions() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::quaternions.
The corresponding component is crate::components::RotationQuat.
Sourcepub fn descriptor_colors() -> ComponentDescriptor
pub fn descriptor_colors() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::colors.
The corresponding component is crate::components::Color.
Sourcepub fn descriptor_line_radii() -> ComponentDescriptor
pub fn descriptor_line_radii() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::line_radii.
The corresponding component is crate::components::Radius.
Sourcepub fn descriptor_fill_mode() -> ComponentDescriptor
pub fn descriptor_fill_mode() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::fill_mode.
The corresponding component is crate::components::FillMode.
Sourcepub fn descriptor_labels() -> ComponentDescriptor
pub fn descriptor_labels() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::labels.
The corresponding component is crate::components::Text.
Sourcepub fn descriptor_show_labels() -> ComponentDescriptor
pub fn descriptor_show_labels() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::show_labels.
The corresponding component is crate::components::ShowLabels.
Sourcepub fn descriptor_class_ids() -> ComponentDescriptor
pub fn descriptor_class_ids() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::class_ids.
The corresponding component is crate::components::ClassId.
Sourceimpl Ellipsoids3D
impl Ellipsoids3D
Sourcepub const NUM_COMPONENTS: usize = 10usize
pub const NUM_COMPONENTS: usize = 10usize
The total number of components in the archetype: 1 required, 2 recommended, 7 optional
Sourceimpl Ellipsoids3D
impl Ellipsoids3D
Sourcepub fn update_fields() -> Ellipsoids3D
pub fn update_fields() -> Ellipsoids3D
Update only some specific fields of a Ellipsoids3D.
Sourcepub fn clear_fields() -> Ellipsoids3D
pub fn clear_fields() -> Ellipsoids3D
Clear all the fields of a Ellipsoids3D.
Sourcepub fn columns<I>(
self,
_lengths: I,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Partitions the component data into multiple sub-batches.
Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns
instead, via SerializedComponentBatch::partitioned.
This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.
The specified lengths must sum to the total length of the component batch.
Sourcepub fn columns_of_unit_batches(
self,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Helper to partition the component data into unit-length sub-batches.
This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n),
where n is automatically guessed.
Sourcepub fn with_half_sizes(
self,
half_sizes: impl IntoIterator<Item = impl Into<HalfSize3D>>,
) -> Ellipsoids3D
pub fn with_half_sizes( self, half_sizes: impl IntoIterator<Item = impl Into<HalfSize3D>>, ) -> Ellipsoids3D
For each ellipsoid, half of its size on its three axes.
If all components are equal, then it is a sphere with that radius.
Sourcepub fn with_centers(
self,
centers: impl IntoIterator<Item = impl Into<Translation3D>>,
) -> Ellipsoids3D
pub fn with_centers( self, centers: impl IntoIterator<Item = impl Into<Translation3D>>, ) -> Ellipsoids3D
Optional center positions of the ellipsoids.
If not specified, the centers will be at (0, 0, 0).
Sourcepub fn with_rotation_axis_angles(
self,
rotation_axis_angles: impl IntoIterator<Item = impl Into<RotationAxisAngle>>,
) -> Ellipsoids3D
pub fn with_rotation_axis_angles( self, rotation_axis_angles: impl IntoIterator<Item = impl Into<RotationAxisAngle>>, ) -> Ellipsoids3D
Rotations via axis + angle.
If no rotation is specified, the axes of the ellipsoid align with the axes of the local coordinate system.
Sourcepub fn with_quaternions(
self,
quaternions: impl IntoIterator<Item = impl Into<RotationQuat>>,
) -> Ellipsoids3D
pub fn with_quaternions( self, quaternions: impl IntoIterator<Item = impl Into<RotationQuat>>, ) -> Ellipsoids3D
Rotations via quaternion.
If no rotation is specified, the axes of the ellipsoid align with the axes of the local coordinate system.
Sourcepub fn with_colors(
self,
colors: impl IntoIterator<Item = impl Into<Color>>,
) -> Ellipsoids3D
pub fn with_colors( self, colors: impl IntoIterator<Item = impl Into<Color>>, ) -> Ellipsoids3D
Optional colors for the ellipsoids.
Alpha channel is used for transparency for solid fill-mode.
Sourcepub fn with_line_radii(
self,
line_radii: impl IntoIterator<Item = impl Into<Radius>>,
) -> Ellipsoids3D
pub fn with_line_radii( self, line_radii: impl IntoIterator<Item = impl Into<Radius>>, ) -> Ellipsoids3D
Optional radii for the lines used when the ellipsoid is rendered as a wireframe.
Sourcepub fn with_fill_mode(self, fill_mode: impl Into<FillMode>) -> Ellipsoids3D
pub fn with_fill_mode(self, fill_mode: impl Into<FillMode>) -> Ellipsoids3D
Optionally choose whether the ellipsoids are drawn with lines or solid.
Sourcepub fn with_many_fill_mode(
self,
fill_mode: impl IntoIterator<Item = impl Into<FillMode>>,
) -> Ellipsoids3D
pub fn with_many_fill_mode( self, fill_mode: impl IntoIterator<Item = impl Into<FillMode>>, ) -> Ellipsoids3D
This method makes it possible to pack multiple crate::components::FillMode in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_fill_mode should
be used when logging a single row’s worth of data.
Sourcepub fn with_labels(
self,
labels: impl IntoIterator<Item = impl Into<Text>>,
) -> Ellipsoids3D
pub fn with_labels( self, labels: impl IntoIterator<Item = impl Into<Text>>, ) -> Ellipsoids3D
Optional text labels for the ellipsoids.
Sourcepub fn with_show_labels(
self,
show_labels: impl Into<ShowLabels>,
) -> Ellipsoids3D
pub fn with_show_labels( self, show_labels: impl Into<ShowLabels>, ) -> Ellipsoids3D
Whether the text labels should be shown.
If not set, labels will automatically appear when there is exactly one label for this entity or the number of instances on this entity is under a certain threshold.
Sourcepub fn with_many_show_labels(
self,
show_labels: impl IntoIterator<Item = impl Into<ShowLabels>>,
) -> Ellipsoids3D
pub fn with_many_show_labels( self, show_labels: impl IntoIterator<Item = impl Into<ShowLabels>>, ) -> Ellipsoids3D
This method makes it possible to pack multiple crate::components::ShowLabels in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_show_labels should
be used when logging a single row’s worth of data.
Sourcepub fn with_class_ids(
self,
class_ids: impl IntoIterator<Item = impl Into<ClassId>>,
) -> Ellipsoids3D
pub fn with_class_ids( self, class_ids: impl IntoIterator<Item = impl Into<ClassId>>, ) -> Ellipsoids3D
Optional class ID for the ellipsoids.
The class ID provides colors and labels if not specified explicitly.
Sourceimpl Ellipsoids3D
impl Ellipsoids3D
Sourcepub fn from_radii(radii: impl IntoIterator<Item = f32>) -> Ellipsoids3D
pub fn from_radii(radii: impl IntoIterator<Item = f32>) -> Ellipsoids3D
Creates a new Ellipsoids3D for spheres with the given radii.
Sourcepub fn from_centers_and_radii(
centers: impl IntoIterator<Item = impl Into<Translation3D>>,
radii: impl IntoIterator<Item = f32>,
) -> Ellipsoids3D
pub fn from_centers_and_radii( centers: impl IntoIterator<Item = impl Into<Translation3D>>, radii: impl IntoIterator<Item = f32>, ) -> Ellipsoids3D
Creates a new Ellipsoids3D for spheres with the given Self::centers, and
Self::half_sizes all equal to the given radii.
Sourcepub fn from_half_sizes(
half_sizes: impl IntoIterator<Item = impl Into<HalfSize3D>>,
) -> Ellipsoids3D
pub fn from_half_sizes( half_sizes: impl IntoIterator<Item = impl Into<HalfSize3D>>, ) -> Ellipsoids3D
Creates a new Ellipsoids3D with Self::half_sizes.
Sourcepub fn from_centers_and_half_sizes(
centers: impl IntoIterator<Item = impl Into<Translation3D>>,
half_sizes: impl IntoIterator<Item = impl Into<HalfSize3D>>,
) -> Ellipsoids3D
pub fn from_centers_and_half_sizes( centers: impl IntoIterator<Item = impl Into<Translation3D>>, half_sizes: impl IntoIterator<Item = impl Into<HalfSize3D>>, ) -> Ellipsoids3D
Creates a new Ellipsoids3D with Self::centers and Self::half_sizes.