EncodedDepthImage

Struct EncodedDepthImage 

pub struct EncodedDepthImage {
    pub blob: Option<SerializedComponentBatch>,
    pub media_type: Option<SerializedComponentBatch>,
    pub meter: Option<SerializedComponentBatch>,
    pub colormap: Option<SerializedComponentBatch>,
    pub depth_range: Option<SerializedComponentBatch>,
    pub point_fill_ratio: Option<SerializedComponentBatch>,
    pub draw_order: Option<SerializedComponentBatch>,
}
Archetype: A depth image encoded with a codec (e.g. RVL or PNG).

Rerun also supports uncompressed depth images with the archetypes.DepthImage.

⚠️ This type is unstable and may change significantly in a way that the data won’t be backwards compatible.

Example

Encoded depth image

use rerun::external::anyhow;

fn main() -> anyhow::Result<()> {
    let args = _args;
    let Some(path) = args.get(1) else {
        anyhow::bail!("Usage: {} <path_to_depth_image.[png|rvl]>", args[0]);
    };

    let rec = rerun::RecordingStreamBuilder::new("rerun_example_encoded_depth_image").spawn()?;

    let depth_blob = std::fs::read(path)?;
    let encoded_depth = rerun::EncodedDepthImage::new(depth_blob)
        .with_media_type(if path.ends_with(".png") {
            rerun::components::MediaType::PNG
        } else {
            rerun::components::MediaType::RVL
        })
        .with_meter(0.001_f32);

    rec.log("depth/encoded", &encoded_depth)?;

    Ok(())
}

Fields

blob: Option<SerializedComponentBatch>

The encoded depth payload.

Supported are:

media_type: Option<SerializedComponentBatch>

Media type of the blob, e.g.:

  • application/rvl (RVL-compressed 16-bit)
  • image/png
meter: Option<SerializedComponentBatch>

Conversion from native units to meters (e.g. 0.001 for millimeters).

If omitted, the Viewer defaults to 1.0 for floating-point depth formats and 1000.0 for integer formats (millimeters).

colormap: Option<SerializedComponentBatch>

Optional colormap for visualization of decoded depth.

depth_range: Option<SerializedComponentBatch>

Optional visualization range for depth values.

point_fill_ratio: Option<SerializedComponentBatch>

Optional point fill ratio for point-cloud projection.

draw_order: Option<SerializedComponentBatch>

Optional 2D draw order.

Implementations

Source

impl EncodedDepthImage

Source

impl EncodedDepthImage

pub const NUM_COMPONENTS: usize = 7usize

The total number of components in the archetype: 1 required, 2 recommended, 4 optional

Source

impl EncodedDepthImage

pub fn new(blob: impl Into<Blob>) -> EncodedDepthImage

Create a new EncodedDepthImage.

pub fn update_fields() -> EncodedDepthImage

Update only some specific fields of a EncodedDepthImage.

pub fn clear_fields() -> EncodedDepthImage

Clear all the fields of a EncodedDepthImage.

pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
where I: IntoIterator<Item = usize> + Clone,

Partitions the component data into multiple sub-batches.

Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns instead, via SerializedComponentBatch::partitioned.

This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.

The specified lengths must sum to the total length of the component batch.

pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>

Helper to partition the component data into unit-length sub-batches.

This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n), where n is automatically guessed.

pub fn with_blob(self, blob: impl Into<Blob>) -> EncodedDepthImage

The encoded depth payload.

Supported are:

pub fn with_many_blob( self, blob: impl IntoIterator<Item = impl Into<Blob>>, ) -> EncodedDepthImage

This method makes it possible to pack multiple crate::components::Blob in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_blob should be used when logging a single row’s worth of data.

pub fn with_media_type( self, media_type: impl Into<MediaType>, ) -> EncodedDepthImage

Media type of the blob, e.g.:

  • application/rvl (RVL-compressed 16-bit)
  • image/png
pub fn with_many_media_type( self, media_type: impl IntoIterator<Item = impl Into<MediaType>>, ) -> EncodedDepthImage

This method makes it possible to pack multiple crate::components::MediaType in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_media_type should be used when logging a single row’s worth of data.

pub fn with_meter(self, meter: impl Into<DepthMeter>) -> EncodedDepthImage

Conversion from native units to meters (e.g. 0.001 for millimeters).

If omitted, the Viewer defaults to 1.0 for floating-point depth formats and 1000.0 for integer formats (millimeters).

pub fn with_many_meter( self, meter: impl IntoIterator<Item = impl Into<DepthMeter>>, ) -> EncodedDepthImage

This method makes it possible to pack multiple crate::components::DepthMeter in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_meter should be used when logging a single row’s worth of data.

pub fn with_colormap(self, colormap: impl Into<Colormap>) -> EncodedDepthImage

Optional colormap for visualization of decoded depth.

pub fn with_many_colormap( self, colormap: impl IntoIterator<Item = impl Into<Colormap>>, ) -> EncodedDepthImage

This method makes it possible to pack multiple crate::components::Colormap in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_colormap should be used when logging a single row’s worth of data.

pub fn with_depth_range( self, depth_range: impl Into<ValueRange>, ) -> EncodedDepthImage

Optional visualization range for depth values.

pub fn with_many_depth_range( self, depth_range: impl IntoIterator<Item = impl Into<ValueRange>>, ) -> EncodedDepthImage

This method makes it possible to pack multiple crate::components::ValueRange in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_depth_range should be used when logging a single row’s worth of data.

pub fn with_point_fill_ratio( self, point_fill_ratio: impl Into<FillRatio>, ) -> EncodedDepthImage

Optional point fill ratio for point-cloud projection.

pub fn with_many_point_fill_ratio( self, point_fill_ratio: impl IntoIterator<Item = impl Into<FillRatio>>, ) -> EncodedDepthImage

This method makes it possible to pack multiple crate::components::FillRatio in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_point_fill_ratio should be used when logging a single row’s worth of data.

pub fn with_draw_order( self, draw_order: impl Into<DrawOrder>, ) -> EncodedDepthImage

Optional 2D draw order.

pub fn with_many_draw_order( self, draw_order: impl IntoIterator<Item = impl Into<DrawOrder>>, ) -> EncodedDepthImage

This method makes it possible to pack multiple crate::components::DrawOrder in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_draw_order should be used when logging a single row’s worth of data.

Source

impl EncodedDepthImage

pub fn from_file(filepath: impl AsRef<Path>) -> Result<EncodedDepthImage, Error>

Creates a new depth image from the file contents at path.

The MediaType will first be guessed from the file contents.

Returns an error if the file cannot be read.

pub fn from_file_contents(bytes: Vec<u8>) -> EncodedDepthImage

Construct a depth image given the encoded content of some image file, e.g. a PNG or RVL.

Self::media_type will be guessed from the bytes.