pub struct EncodedImage {
pub blob: Option<SerializedComponentBatch>,
pub media_type: Option<SerializedComponentBatch>,
pub opacity: Option<SerializedComponentBatch>,
pub draw_order: Option<SerializedComponentBatch>,
}Expand description
Archetype: An image encoded as e.g. a JPEG or PNG.
Rerun also supports uncompressed images with the archetypes::Image.
For images that refer to video frames see archetypes::VideoFrameReference.
Example
Encoded image
fn main() -> Result<(), Box<dyn std::error::Error>> {
let rec = rerun::RecordingStreamBuilder::new("rerun_example_encoded_image").spawn()?;
let image = include_bytes!("ferris.png");
rec.log(
"image",
&rerun::EncodedImage::from_file_contents(image.to_vec()),
)?;
Ok(())
}
Fields
blob: Option<SerializedComponentBatch>The encoded content of some image file, e.g. a PNG or JPEG.
media_type: Option<SerializedComponentBatch>The Media Type of the asset.
Supported values:
image/jpegimage/png
If omitted, the viewer will try to guess from the data blob. If it cannot guess, it won’t be able to render the asset.
opacity: Option<SerializedComponentBatch>Opacity of the image, useful for layering several media.
Defaults to 1.0 (fully opaque).
draw_order: Option<SerializedComponentBatch>An optional floating point value that specifies the 2D drawing order.
Objects with higher values are drawn on top of those with lower values.
Implementations
Sourceimpl EncodedImage
impl EncodedImage
Sourcepub fn descriptor_blob() -> ComponentDescriptor
pub fn descriptor_blob() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::blob.
The corresponding component is crate::components::Blob.
Sourcepub fn descriptor_media_type() -> ComponentDescriptor
pub fn descriptor_media_type() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::media_type.
The corresponding component is crate::components::MediaType.
Sourcepub fn descriptor_opacity() -> ComponentDescriptor
pub fn descriptor_opacity() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::opacity.
The corresponding component is crate::components::Opacity.
Sourcepub fn descriptor_draw_order() -> ComponentDescriptor
pub fn descriptor_draw_order() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::draw_order.
The corresponding component is crate::components::DrawOrder.
Sourceimpl EncodedImage
impl EncodedImage
Sourcepub const NUM_COMPONENTS: usize = 4usize
pub const NUM_COMPONENTS: usize = 4usize
The total number of components in the archetype: 1 required, 1 recommended, 2 optional
Sourceimpl EncodedImage
impl EncodedImage
Sourcepub fn new(blob: impl Into<Blob>) -> EncodedImage
pub fn new(blob: impl Into<Blob>) -> EncodedImage
Create a new EncodedImage.
Sourcepub fn update_fields() -> EncodedImage
pub fn update_fields() -> EncodedImage
Update only some specific fields of a EncodedImage.
Sourcepub fn clear_fields() -> EncodedImage
pub fn clear_fields() -> EncodedImage
Clear all the fields of a EncodedImage.
Sourcepub fn columns<I>(
self,
_lengths: I,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Partitions the component data into multiple sub-batches.
Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns
instead, via SerializedComponentBatch::partitioned.
This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.
The specified lengths must sum to the total length of the component batch.
Sourcepub fn columns_of_unit_batches(
self,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Helper to partition the component data into unit-length sub-batches.
This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n),
where n is automatically guessed.
Sourcepub fn with_blob(self, blob: impl Into<Blob>) -> EncodedImage
pub fn with_blob(self, blob: impl Into<Blob>) -> EncodedImage
The encoded content of some image file, e.g. a PNG or JPEG.
Sourcepub fn with_many_blob(
self,
blob: impl IntoIterator<Item = impl Into<Blob>>,
) -> EncodedImage
pub fn with_many_blob( self, blob: impl IntoIterator<Item = impl Into<Blob>>, ) -> EncodedImage
This method makes it possible to pack multiple crate::components::Blob in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_blob should
be used when logging a single row’s worth of data.
Sourcepub fn with_media_type(self, media_type: impl Into<MediaType>) -> EncodedImage
pub fn with_media_type(self, media_type: impl Into<MediaType>) -> EncodedImage
The Media Type of the asset.
Supported values:
image/jpegimage/png
If omitted, the viewer will try to guess from the data blob. If it cannot guess, it won’t be able to render the asset.
Sourcepub fn with_many_media_type(
self,
media_type: impl IntoIterator<Item = impl Into<MediaType>>,
) -> EncodedImage
pub fn with_many_media_type( self, media_type: impl IntoIterator<Item = impl Into<MediaType>>, ) -> EncodedImage
This method makes it possible to pack multiple crate::components::MediaType in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_media_type should
be used when logging a single row’s worth of data.
Sourcepub fn with_opacity(self, opacity: impl Into<Opacity>) -> EncodedImage
pub fn with_opacity(self, opacity: impl Into<Opacity>) -> EncodedImage
Opacity of the image, useful for layering several media.
Defaults to 1.0 (fully opaque).
Sourcepub fn with_many_opacity(
self,
opacity: impl IntoIterator<Item = impl Into<Opacity>>,
) -> EncodedImage
pub fn with_many_opacity( self, opacity: impl IntoIterator<Item = impl Into<Opacity>>, ) -> EncodedImage
This method makes it possible to pack multiple crate::components::Opacity in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_opacity should
be used when logging a single row’s worth of data.
Sourcepub fn with_draw_order(self, draw_order: impl Into<DrawOrder>) -> EncodedImage
pub fn with_draw_order(self, draw_order: impl Into<DrawOrder>) -> EncodedImage
An optional floating point value that specifies the 2D drawing order.
Objects with higher values are drawn on top of those with lower values.
Sourcepub fn with_many_draw_order(
self,
draw_order: impl IntoIterator<Item = impl Into<DrawOrder>>,
) -> EncodedImage
pub fn with_many_draw_order( self, draw_order: impl IntoIterator<Item = impl Into<DrawOrder>>, ) -> EncodedImage
This method makes it possible to pack multiple crate::components::DrawOrder in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_draw_order should
be used when logging a single row’s worth of data.
Sourceimpl EncodedImage
impl EncodedImage
Sourcepub fn from_file(filepath: impl AsRef<Path>) -> Result<EncodedImage, Error>
pub fn from_file(filepath: impl AsRef<Path>) -> Result<EncodedImage, Error>
Creates a new image from the file contents at path.
The MediaType will first be guessed from the file contents.
Returns an error if the file cannot be read.
Sourcepub fn from_file_contents(bytes: Vec<u8>) -> EncodedImage
pub fn from_file_contents(bytes: Vec<u8>) -> EncodedImage
Construct an image given the encoded content of some image file, e.g. a PNG or JPEG.
Self::media_type will be guessed from the bytes.