pub struct GraphNodes {
pub node_ids: Option<SerializedComponentBatch>,
pub positions: Option<SerializedComponentBatch>,
pub colors: Option<SerializedComponentBatch>,
pub labels: Option<SerializedComponentBatch>,
pub show_labels: Option<SerializedComponentBatch>,
pub radii: Option<SerializedComponentBatch>,
}Expand description
Archetype: A list of nodes in a graph with optional labels, colors, etc.
Example
Simple directed graph
fn main() -> Result<(), Box<dyn std::error::Error>> {
let rec = rerun::RecordingStreamBuilder::new("rerun_example_graph_directed").spawn()?;
rec.log(
"simple",
&[
&rerun::GraphNodes::new(["a", "b", "c"])
.with_positions([(0.0, 100.0), (-100.0, 0.0), (100.0, 0.0)])
.with_labels(["A", "B", "C"]) as &dyn rerun::AsComponents,
&rerun::GraphEdges::new([("a", "b"), ("b", "c"), ("c", "a")]).with_directed_edges(),
],
)?;
Ok(())
}
Fields
node_ids: Option<SerializedComponentBatch>A list of node IDs.
positions: Option<SerializedComponentBatch>Optional center positions of the nodes.
colors: Option<SerializedComponentBatch>Optional colors for the boxes.
labels: Option<SerializedComponentBatch>Optional text labels for the node.
show_labels: Option<SerializedComponentBatch>Whether the text labels should be shown.
If not set, labels will automatically appear when there is exactly one label for this entity or the number of instances on this entity is under a certain threshold.
radii: Option<SerializedComponentBatch>Optional radii for nodes.
Implementations
Sourceimpl GraphNodes
impl GraphNodes
Sourcepub fn descriptor_node_ids() -> ComponentDescriptor
pub fn descriptor_node_ids() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::node_ids.
The corresponding component is crate::components::GraphNode.
Sourcepub fn descriptor_positions() -> ComponentDescriptor
pub fn descriptor_positions() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::positions.
The corresponding component is crate::components::Position2D.
Sourcepub fn descriptor_colors() -> ComponentDescriptor
pub fn descriptor_colors() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::colors.
The corresponding component is crate::components::Color.
Sourcepub fn descriptor_labels() -> ComponentDescriptor
pub fn descriptor_labels() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::labels.
The corresponding component is crate::components::Text.
Sourcepub fn descriptor_show_labels() -> ComponentDescriptor
pub fn descriptor_show_labels() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::show_labels.
The corresponding component is crate::components::ShowLabels.
Sourcepub fn descriptor_radii() -> ComponentDescriptor
pub fn descriptor_radii() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::radii.
The corresponding component is crate::components::Radius.
Sourceimpl GraphNodes
impl GraphNodes
Sourcepub const NUM_COMPONENTS: usize = 6usize
pub const NUM_COMPONENTS: usize = 6usize
The total number of components in the archetype: 1 required, 0 recommended, 5 optional
Sourceimpl GraphNodes
impl GraphNodes
Sourcepub fn new(
node_ids: impl IntoIterator<Item = impl Into<GraphNode>>,
) -> GraphNodes
pub fn new( node_ids: impl IntoIterator<Item = impl Into<GraphNode>>, ) -> GraphNodes
Create a new GraphNodes.
Sourcepub fn update_fields() -> GraphNodes
pub fn update_fields() -> GraphNodes
Update only some specific fields of a GraphNodes.
Sourcepub fn clear_fields() -> GraphNodes
pub fn clear_fields() -> GraphNodes
Clear all the fields of a GraphNodes.
Sourcepub fn columns<I>(
self,
_lengths: I,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Partitions the component data into multiple sub-batches.
Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns
instead, via SerializedComponentBatch::partitioned.
This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.
The specified lengths must sum to the total length of the component batch.
Sourcepub fn columns_of_unit_batches(
self,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Helper to partition the component data into unit-length sub-batches.
This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n),
where n is automatically guessed.
Sourcepub fn with_node_ids(
self,
node_ids: impl IntoIterator<Item = impl Into<GraphNode>>,
) -> GraphNodes
pub fn with_node_ids( self, node_ids: impl IntoIterator<Item = impl Into<GraphNode>>, ) -> GraphNodes
A list of node IDs.
Sourcepub fn with_positions(
self,
positions: impl IntoIterator<Item = impl Into<Position2D>>,
) -> GraphNodes
pub fn with_positions( self, positions: impl IntoIterator<Item = impl Into<Position2D>>, ) -> GraphNodes
Optional center positions of the nodes.
Sourcepub fn with_colors(
self,
colors: impl IntoIterator<Item = impl Into<Color>>,
) -> GraphNodes
pub fn with_colors( self, colors: impl IntoIterator<Item = impl Into<Color>>, ) -> GraphNodes
Optional colors for the boxes.
Sourcepub fn with_labels(
self,
labels: impl IntoIterator<Item = impl Into<Text>>,
) -> GraphNodes
pub fn with_labels( self, labels: impl IntoIterator<Item = impl Into<Text>>, ) -> GraphNodes
Optional text labels for the node.
Sourcepub fn with_show_labels(self, show_labels: impl Into<ShowLabels>) -> GraphNodes
pub fn with_show_labels(self, show_labels: impl Into<ShowLabels>) -> GraphNodes
Whether the text labels should be shown.
If not set, labels will automatically appear when there is exactly one label for this entity or the number of instances on this entity is under a certain threshold.
Sourcepub fn with_many_show_labels(
self,
show_labels: impl IntoIterator<Item = impl Into<ShowLabels>>,
) -> GraphNodes
pub fn with_many_show_labels( self, show_labels: impl IntoIterator<Item = impl Into<ShowLabels>>, ) -> GraphNodes
This method makes it possible to pack multiple crate::components::ShowLabels in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_show_labels should
be used when logging a single row’s worth of data.
Sourcepub fn with_radii(
self,
radii: impl IntoIterator<Item = impl Into<Radius>>,
) -> GraphNodes
pub fn with_radii( self, radii: impl IntoIterator<Item = impl Into<Radius>>, ) -> GraphNodes
Optional radii for nodes.