pub struct Instance(/* private fields */);Expand description
A unique numeric index for each individual instance within a batch.
Use Instance::ALL to refer to all instances in a batch.
Implementations
Sourceimpl Instance
impl Instance
pub fn get(self) -> u64
pub fn from_iter( it: impl IntoIterator<Item = impl Into<Instance>>, ) -> Vec<Instance>
Sourcepub fn is_all(self) -> bool
pub fn is_all(self) -> bool
Are we referring to all instances of the entity (e.g. all points in a point cloud entity)?
The opposite of Self::is_specific.
Sourcepub fn is_specific(self) -> bool
pub fn is_specific(self) -> bool
Are we referring to a specific instance of the entity (e.g. a specific point in a point cloud)?
The opposite of Self::is_all.
Sourcepub fn specific_index(self) -> Option<Instance>
pub fn specific_index(self) -> Option<Instance>
Returns None if ALL, otherwise the index.
Sourcepub fn from_2d_image_coordinate(_: [u32; 2], image_width: u64) -> Instance
pub fn from_2d_image_coordinate(_: [u32; 2], image_width: u64) -> Instance
Creates a new Instance that identifies a 2D coordinate.
Sourcepub fn to_2d_image_coordinate(self, image_width: u32) -> [u32; 2]
pub fn to_2d_image_coordinate(self, image_width: u32) -> [u32; 2]
Retrieves 2D image coordinates (x, y) encoded in an instance key