pub struct MainThreadToken { /* private fields */ }Expand description
A token that (almost) proves we are on the main thread.
Certain operations are only allowed on the main thread.
These operations should require this token.
For instance, any function using file dialogs (e.g. using rfd) should require this token.
The token should only be constructed in fn main, using MainThreadToken::i_promise_i_am_on_the_main_thread,
and then be passed down the call tree to where it is needed.
MainThreadToken is neither Send nor Sync,
thus guaranteeing that it cannot be found in other threads.
Of course, there is nothing stopping you from calling MainThreadToken::i_promise_i_am_on_the_main_thread from a background thread,
but PLEASE DON’T DO THAT.
In other words, don’t use this as a guarantee for unsafe code.
There is also MainThreadToken::from_egui_ui which uses the implicit guarantee of egui
(which usually is run on the main thread) to construct a MainThreadToken.
Use this only in a code base where you are sure that egui is running only on the main thread.
Implementations
Sourceimpl MainThreadToken
impl MainThreadToken
Sourcepub fn i_promise_i_am_on_the_main_thread() -> MainThreadToken
pub fn i_promise_i_am_on_the_main_thread() -> MainThreadToken
Only call this from fn main, or you may get weird runtime errors!
Sourcepub fn i_promise_i_am_only_using_this_for_a_test() -> MainThreadToken
pub fn i_promise_i_am_only_using_this_for_a_test() -> MainThreadToken
Only call this from tests, where the thread wouldn’t be “main”.
Sourcepub fn from_egui_ui(_ui: &Ui) -> MainThreadToken
pub fn from_egui_ui(_ui: &Ui) -> MainThreadToken
We should only create an egui::Ui on the main thread,
so having it is good enough to “prove” that we are on the main thread.
Use this only in a code base where you are sure that egui is running only on the main thread.
In theory there is nothing preventing anyone from creating a egui::Ui on another thread,
but practice that is unlikely (or intentionally malicious).