SpawnOptions

Struct SpawnOptions 

pub struct SpawnOptions {
    pub port: u16,
    pub wait_for_bind: bool,
    pub memory_limit: String,
    pub server_memory_limit: String,
    pub executable_name: String,
    pub executable_path: Option<String>,
    pub extra_args: Vec<String>,
    pub extra_env: Vec<(String, String)>,
    pub hide_welcome_screen: bool,
    pub detach_process: bool,
}
Options to control the behavior of spawn.

Refer to the field-level documentation for more information about each individual options.

The defaults are ok for most use cases: SpawnOptions::default(). Use the partial-default pattern to customize them further:

let opts = re_sdk::SpawnOptions {
    port: 1234,
    memory_limit: "25%".into(),
    ..Default::default()
};

Fields

port: u16

The port to listen on.

Defaults to 9876.

wait_for_bind: bool

If true, the call to spawn will block until the Rerun Viewer has successfully bound to the port.

memory_limit: String

An upper limit on how much memory the Rerun Viewer should use. When this limit is reached, Rerun will drop the oldest data. Example: 16GB or 50% (of system total).

Defaults to 75%.

server_memory_limit: String

An upper limit on how much memory the gRPC server running in the same process as the Rerun Viewer should use. When this limit is reached, Rerun will drop the oldest data. Example: 16GB or 50% (of system total).

Defaults to 1GiB.

executable_name: String

Specifies the name of the Rerun executable.

You can omit the .exe suffix on Windows.

Defaults to rerun.

executable_path: Option<String>

Enforce a specific executable to use instead of searching though PATH for Self::executable_name.

Unspecified by default.

extra_args: Vec<String>

Extra arguments that will be passed as-is to the Rerun Viewer process.

extra_env: Vec<(String, String)>

Extra environment variables that will be passed as-is to the Rerun Viewer process.

hide_welcome_screen: bool

Hide the welcome screen.

detach_process: bool

Detach Rerun Viewer process from the application process.

Implementations

Source

impl SpawnOptions

pub fn connect_addr(&self) -> SocketAddr

Resolves the final connect address value.

pub fn listen_addr(&self) -> SocketAddr

Resolves the final listen address value.

pub fn executable_path(&self) -> String

Resolves the final executable path.