pub struct StateChange {
pub state: Option<SerializedComponentBatch>,
}Expand description
Archetype: A state change, representing a transition of an entity into a new state.
Useful for representing discrete state machines, mode transitions, or
state changes over time. Each logged archetypes::StateChange marks a new state
at the given time. A null state is ignored by the state timeline view.
The state timeline view displays these as horizontal colored lanes over time.
⚠️ This type is unstable and may change significantly in a way that the data won’t be backwards compatible.
Example
State changes over time
fn main() -> Result<(), Box<dyn std::error::Error>> {
let rec = rerun::RecordingStreamBuilder::new("rerun_example_state_change")
.spawn()?;
rec.set_time_sequence("step", 0);
rec.log("door", &rerun::StateChange::new().with_state("open"))?;
rec.set_time_sequence("step", 1);
rec.log("door", &rerun::StateChange::new().with_state("closed"))?;
rec.set_time_sequence("step", 2);
rec.log("door", &rerun::StateChange::new().with_state("open"))?;
Ok(())
}
Fields
state: Option<SerializedComponentBatch>The new state value.
A null state is ignored, it can be used to partially update a multi-instance state array.
An empty string is treated as state reset, and a gap is shown in the state timeline view.
Implementations
Sourceimpl StateChange
impl StateChange
Sourcepub fn descriptor_state() -> ComponentDescriptor
pub fn descriptor_state() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::state.
The corresponding component is crate::components::Text.
Sourceimpl StateChange
impl StateChange
Sourcepub const NUM_COMPONENTS: usize = 1usize
pub const NUM_COMPONENTS: usize = 1usize
The total number of components in the archetype: 1 required, 0 recommended, 0 optional
Sourceimpl StateChange
impl StateChange
Sourcepub fn new() -> StateChange
pub fn new() -> StateChange
Create a new StateChange.
Sourcepub fn update_fields() -> StateChange
pub fn update_fields() -> StateChange
Update only some specific fields of a StateChange.
Sourcepub fn clear_fields() -> StateChange
pub fn clear_fields() -> StateChange
Clear all the fields of a StateChange.
Sourcepub fn columns<I>(
self,
_lengths: I,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Partitions the component data into multiple sub-batches.
Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns
instead, via SerializedComponentBatch::partitioned.
This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.
The specified lengths must sum to the total length of the component batch.
Sourcepub fn columns_of_unit_batches(
self,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Helper to partition the component data into unit-length sub-batches.
This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n),
where n is automatically guessed.
Sourcepub fn with_state(self, state: impl Into<Text>) -> StateChange
pub fn with_state(self, state: impl Into<Text>) -> StateChange
The new state value.
A null state is ignored, it can be used to partially update a multi-instance state array.
An empty string is treated as state reset, and a gap is shown in the state timeline view.
Sourcepub fn with_many_state(
self,
state: impl IntoIterator<Item = impl Into<Text>>,
) -> StateChange
pub fn with_many_state( self, state: impl IntoIterator<Item = impl Into<Text>>, ) -> StateChange
This method makes it possible to pack multiple crate::components::Text in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_state should
be used when logging a single row’s worth of data.