pub struct StoreId { /* private fields */ }Expand description
A unique id per store.
The kind of store is part of the id, and can be either a StoreKind::Recording or a
StoreKind::Blueprint.
Uniqueness
All data associated with a given StoreId, regardless of its source, is considered to belong
to the same logical recording. As such, when ingested in the viewer, they will be pooled into
a single store and displayed as a single, in-viewer recording. This can be very confusing if it
happens inadvertently. However, the ability to pool data sharing the same StoreId can be very
powerful. As a result, we do not want to enforce uniqueness. Still, it is important to
understand what a StoreId is, and, to avoid footguns, default to make them unique.
In the context of the logging SDK, the application id is a mandatory, user-defined string. By default, the recording id is a UUID, which ensures unique-by-default behavior. The user can override the recording id though. In that case, the user is responsible for making the application id/recording id pair unique or not, based on their needs.
In the context of remote recordings (aka a dataset’s segment), the application id is the
dataset entry id, and the recording id is the segment id. The former is a UUID, and the latter
is, by definition, unique within the dataset entry. As a result, the uniqueness of the StoreId
is always guaranteed in this case.
Implementations
Sourceimpl StoreId
impl StoreId
pub fn new( kind: StoreKind, application_id: impl Into<ApplicationId>, recording_id: impl Into<RecordingId>, ) -> StoreId
pub fn recording( application_id: impl Into<ApplicationId>, recording_id: impl Into<RecordingId>, ) -> StoreId
Sourcepub fn default_blueprint(application_id: ApplicationId) -> StoreId
pub fn default_blueprint(application_id: ApplicationId) -> StoreId
Create a Self for the default blueprint of a given application id
Sourcepub fn random(
kind: StoreKind,
application_id: impl Into<ApplicationId>,
) -> StoreId
pub fn random( kind: StoreKind, application_id: impl Into<ApplicationId>, ) -> StoreId
Generate a random StoreId with the provided application id.
Note: the application id is required here because fully random store ids are often a logically incorrect thing to build (the notable exceptions being tests).
pub fn empty_recording() -> StoreId
pub fn with_recording_id(self, recording_id: impl Into<RecordingId>) -> StoreId
pub fn with_application_id( self, application_id: impl Into<ApplicationId>, ) -> StoreId
pub fn from_uuid( kind: StoreKind, application_id: ApplicationId, uuid: Uuid, ) -> StoreId
pub fn is_empty_recording(&self) -> bool
pub fn is_default_blueprint(&self) -> bool
pub fn kind(&self) -> StoreKind
pub fn is_recording(&self) -> bool
pub fn is_blueprint(&self) -> bool
pub fn recording_id(&self) -> &RecordingId
pub fn application_id(&self) -> &ApplicationId