pub struct TransformAxes3D {
pub axis_length: Option<SerializedComponentBatch>,
pub show_frame: Option<SerializedComponentBatch>,
}Expand description
Archetype: A visual representation of a archetypes::Transform3D.
Example
Visual representation of a transform as three arrows
use rerun::AsComponents;
fn main() -> Result<(), Box<dyn std::error::Error>> {
let rec = rerun::RecordingStreamBuilder::new("rerun_example_transform3d_axes").spawn()?;
rec.set_time_sequence("step", 0);
rec.log(
"base",
&[
&rerun::Transform3D::new() as &dyn AsComponents,
&rerun::TransformAxes3D::new(1.0),
],
)?;
for deg in 0..360 {
rec.set_time_sequence("step", deg);
rec.log(
"base/rotated",
&[
&rerun::Transform3D::new().with_rotation(rerun::RotationAxisAngle::new(
[1.0, 1.0, 1.0],
rerun::Angle::from_degrees(deg as f32),
)) as &dyn AsComponents,
&rerun::TransformAxes3D::new(0.5),
],
)?;
rec.log(
"base/rotated/translated",
&[
&rerun::Transform3D::new().with_translation([2.0, 0.0, 0.0]) as &dyn AsComponents,
&rerun::TransformAxes3D::new(0.5),
],
)?;
}
Ok(())
}
Fields
axis_length: Option<SerializedComponentBatch>Visual length of the 3 axes.
The length is interpreted in the local coordinate system of the transform. If the transform is scaled, the axes will be scaled accordingly.
show_frame: Option<SerializedComponentBatch>Whether to show a text label with the corresponding frame.
Implementations
Sourceimpl TransformAxes3D
impl TransformAxes3D
Sourcepub fn descriptor_axis_length() -> ComponentDescriptor
pub fn descriptor_axis_length() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::axis_length.
The corresponding component is crate::components::AxisLength.
Sourcepub fn descriptor_show_frame() -> ComponentDescriptor
pub fn descriptor_show_frame() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::show_frame.
The corresponding component is crate::components::ShowLabels.
Sourceimpl TransformAxes3D
impl TransformAxes3D
Sourcepub const NUM_COMPONENTS: usize = 2usize
pub const NUM_COMPONENTS: usize = 2usize
The total number of components in the archetype: 1 required, 0 recommended, 1 optional
Sourceimpl TransformAxes3D
impl TransformAxes3D
Sourcepub fn new(axis_length: impl Into<AxisLength>) -> TransformAxes3D
pub fn new(axis_length: impl Into<AxisLength>) -> TransformAxes3D
Create a new TransformAxes3D.
Sourcepub fn update_fields() -> TransformAxes3D
pub fn update_fields() -> TransformAxes3D
Update only some specific fields of a TransformAxes3D.
Sourcepub fn clear_fields() -> TransformAxes3D
pub fn clear_fields() -> TransformAxes3D
Clear all the fields of a TransformAxes3D.
Sourcepub fn columns<I>(
self,
_lengths: I,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Partitions the component data into multiple sub-batches.
Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns
instead, via SerializedComponentBatch::partitioned.
This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.
The specified lengths must sum to the total length of the component batch.
Sourcepub fn columns_of_unit_batches(
self,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Helper to partition the component data into unit-length sub-batches.
This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n),
where n is automatically guessed.
Sourcepub fn with_axis_length(
self,
axis_length: impl Into<AxisLength>,
) -> TransformAxes3D
pub fn with_axis_length( self, axis_length: impl Into<AxisLength>, ) -> TransformAxes3D
Visual length of the 3 axes.
The length is interpreted in the local coordinate system of the transform. If the transform is scaled, the axes will be scaled accordingly.
Sourcepub fn with_many_axis_length(
self,
axis_length: impl IntoIterator<Item = impl Into<AxisLength>>,
) -> TransformAxes3D
pub fn with_many_axis_length( self, axis_length: impl IntoIterator<Item = impl Into<AxisLength>>, ) -> TransformAxes3D
This method makes it possible to pack multiple crate::components::AxisLength in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_axis_length should
be used when logging a single row’s worth of data.
Sourcepub fn with_show_frame(
self,
show_frame: impl Into<ShowLabels>,
) -> TransformAxes3D
pub fn with_show_frame( self, show_frame: impl Into<ShowLabels>, ) -> TransformAxes3D
Whether to show a text label with the corresponding frame.
Sourcepub fn with_many_show_frame(
self,
show_frame: impl IntoIterator<Item = impl Into<ShowLabels>>,
) -> TransformAxes3D
pub fn with_many_show_frame( self, show_frame: impl IntoIterator<Item = impl Into<ShowLabels>>, ) -> TransformAxes3D
This method makes it possible to pack multiple crate::components::ShowLabels in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_show_frame should
be used when logging a single row’s worth of data.