ViewCoordinates

Struct ViewCoordinates 

#[repr(transparent)]
pub struct ViewCoordinates { pub xyz: Option<SerializedComponentBatch>, }
Archetype: Sets the default orientation for 3D views at or below this entity.

The orientation determines the 3D view’s eye orientation, navigation, and default grid plane. It does not change logged transforms.

The three directions are always ordered as [x, y, z] and specify where each positive axis points. For example, [Right, Down, Forward] means that +X points right, +Y points down, and +Z points forward.

A 3D view uses the value logged at its origin entity or the closest ancestor. SpatialInformation can override it for an individual view.

Rerun does not yet support left-handed coordinate systems.

⚠️ This type is unstable and may change significantly in a way that the data won’t be backwards compatible.

Example

Set the default 3D view orientation

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let rec =
        rerun::RecordingStreamBuilder::new("rerun_example_view_coordinates")
            .spawn()?;

    rec.log_static("world", &rerun::ViewCoordinates::RIGHT_HAND_Z_UP())?; // Set the 3D view's up direction
    rec.log(
        "world/xyz",
        &rerun::Arrows3D::from_vectors(
            [[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]], //
        )
        .with_colors([[255, 0, 0], [0, 255, 0], [0, 0, 255]]),
    )?;

    Ok(())
}

Fields

xyz: Option<SerializedComponentBatch>

The directions of the [x, y, z] axes.

Implementations

Source

impl ViewCoordinates

Source

impl ViewCoordinates

pub const NUM_COMPONENTS: usize = 1usize

The total number of components in the archetype: 1 required, 0 recommended, 0 optional

Source

impl ViewCoordinates

pub fn new(xyz: impl Into<ViewCoordinates>) -> ViewCoordinates

Create a new ViewCoordinates.

pub fn update_fields() -> ViewCoordinates

Update only some specific fields of a ViewCoordinates.

pub fn clear_fields() -> ViewCoordinates

Clear all the fields of a ViewCoordinates.

pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
where I: IntoIterator<Item = usize> + Clone,

Partitions the component data into multiple sub-batches.

Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns instead, via SerializedComponentBatch::partitioned.

This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.

The specified lengths must sum to the total length of the component batch.

pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>

Helper to partition the component data into unit-length sub-batches.

This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n), where n is automatically guessed.

pub fn with_xyz(self, xyz: impl Into<ViewCoordinates>) -> ViewCoordinates

The directions of the [x, y, z] axes.

pub fn with_many_xyz( self, xyz: impl IntoIterator<Item = impl Into<ViewCoordinates>>, ) -> ViewCoordinates

This method makes it possible to pack multiple crate::components::ViewCoordinates in a single component batch.

This only makes sense when used in conjunction with Self::columns. Self::with_xyz should be used when logging a single row’s worth of data.

Source

impl ViewCoordinates

pub fn ULF() -> ViewCoordinates

X=Up, Y=Left, Z=Forward

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn UFL() -> ViewCoordinates

X=Up, Y=Forward, Z=Left

pub fn LUF() -> ViewCoordinates

X=Left, Y=Up, Z=Forward

pub fn LFU() -> ViewCoordinates

X=Left, Y=Forward, Z=Up

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn FUL() -> ViewCoordinates

X=Forward, Y=Up, Z=Left

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn FLU() -> ViewCoordinates

X=Forward, Y=Left, Z=Up

pub fn ULB() -> ViewCoordinates

X=Up, Y=Left, Z=Back

pub fn UBL() -> ViewCoordinates

X=Up, Y=Back, Z=Left

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn LUB() -> ViewCoordinates

X=Left, Y=Up, Z=Back

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn LBU() -> ViewCoordinates

X=Left, Y=Back, Z=Up

pub fn BUL() -> ViewCoordinates

X=Back, Y=Up, Z=Left

pub fn BLU() -> ViewCoordinates

X=Back, Y=Left, Z=Up

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn URF() -> ViewCoordinates

X=Up, Y=Right, Z=Forward

pub fn UFR() -> ViewCoordinates

X=Up, Y=Forward, Z=Right

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn RUF() -> ViewCoordinates

X=Right, Y=Up, Z=Forward

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn RFU() -> ViewCoordinates

X=Right, Y=Forward, Z=Up

pub fn FUR() -> ViewCoordinates

X=Forward, Y=Up, Z=Right

pub fn FRU() -> ViewCoordinates

X=Forward, Y=Right, Z=Up

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn URB() -> ViewCoordinates

X=Up, Y=Right, Z=Back

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn UBR() -> ViewCoordinates

X=Up, Y=Back, Z=Right

pub fn RUB() -> ViewCoordinates

X=Right, Y=Up, Z=Back

pub fn RBU() -> ViewCoordinates

X=Right, Y=Back, Z=Up

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn BUR() -> ViewCoordinates

X=Back, Y=Up, Z=Right

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn BRU() -> ViewCoordinates

X=Back, Y=Right, Z=Up

pub fn DLF() -> ViewCoordinates

X=Down, Y=Left, Z=Forward

pub fn DFL() -> ViewCoordinates

X=Down, Y=Forward, Z=Left

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn LDF() -> ViewCoordinates

X=Left, Y=Down, Z=Forward

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn LFD() -> ViewCoordinates

X=Left, Y=Forward, Z=Down

pub fn FDL() -> ViewCoordinates

X=Forward, Y=Down, Z=Left

pub fn FLD() -> ViewCoordinates

X=Forward, Y=Left, Z=Down

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn DLB() -> ViewCoordinates

X=Down, Y=Left, Z=Back

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn DBL() -> ViewCoordinates

X=Down, Y=Back, Z=Left

pub fn LDB() -> ViewCoordinates

X=Left, Y=Down, Z=Back

pub fn LBD() -> ViewCoordinates

X=Left, Y=Back, Z=Down

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn BDL() -> ViewCoordinates

X=Back, Y=Down, Z=Left

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn BLD() -> ViewCoordinates

X=Back, Y=Left, Z=Down

pub fn DRF() -> ViewCoordinates

X=Down, Y=Right, Z=Forward

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn DFR() -> ViewCoordinates

X=Down, Y=Forward, Z=Right

pub fn RDF() -> ViewCoordinates

X=Right, Y=Down, Z=Forward

pub fn RFD() -> ViewCoordinates

X=Right, Y=Forward, Z=Down

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn FDR() -> ViewCoordinates

X=Forward, Y=Down, Z=Right

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn FRD() -> ViewCoordinates

X=Forward, Y=Right, Z=Down

pub fn DRB() -> ViewCoordinates

X=Down, Y=Right, Z=Back

pub fn DBR() -> ViewCoordinates

X=Down, Y=Back, Z=Right

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn RDB() -> ViewCoordinates

X=Right, Y=Down, Z=Back

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn RBD() -> ViewCoordinates

X=Right, Y=Back, Z=Down

pub fn BDR() -> ViewCoordinates

X=Back, Y=Down, Z=Right

pub fn BRD() -> ViewCoordinates

X=Back, Y=Right, Z=Down

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn RIGHT_HAND_X_UP() -> ViewCoordinates

X=Up, Y=Right, Z=Forward

pub fn RIGHT_HAND_X_DOWN() -> ViewCoordinates

X=Down, Y=Right, Z=Back

pub fn RIGHT_HAND_Y_UP() -> ViewCoordinates

X=Right, Y=Up, Z=Back

pub fn RIGHT_HAND_Y_DOWN() -> ViewCoordinates

X=Right, Y=Down, Z=Forward

pub fn RIGHT_HAND_Z_UP() -> ViewCoordinates

X=Right, Y=Forward, Z=Up

pub fn RIGHT_HAND_Z_DOWN() -> ViewCoordinates

X=Right, Y=Back, Z=Down

pub fn LEFT_HAND_X_UP() -> ViewCoordinates

X=Up, Y=Right, Z=Back

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn LEFT_HAND_X_DOWN() -> ViewCoordinates

X=Down, Y=Right, Z=Forward

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn LEFT_HAND_Y_UP() -> ViewCoordinates

X=Right, Y=Up, Z=Forward

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn LEFT_HAND_Y_DOWN() -> ViewCoordinates

X=Right, Y=Down, Z=Back

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn LEFT_HAND_Z_UP() -> ViewCoordinates

X=Right, Y=Back, Z=Up

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.

pub fn LEFT_HAND_Z_DOWN() -> ViewCoordinates

X=Right, Y=Forward, Z=Down

⚠️ This is a left-handed coordinate system, which is not yet supported by Rerun.