Module time

Module time 

Time-related types.

Structs

Duration
A signed duration represented as nanoseconds since unix epoch
TimeCell
An typed cell of an index, e.g. a point in time on some unknown timeline.
TimeInt
A 64-bit number describing either nanoseconds, sequence numbers or fully static data.
TimePoint
A point in time on any number of Timelines.
Timeline
A time frame/space, e.g. log_time or frame_nr, coupled with the type of time it keeps.
Timestamp
Encodes a timestamp in nanoseconds since unix epoch.

Enums

TimeType
The type of a TimeInt or crate::Timeline.