pub enum TimeType {
Sequence,
DurationNs,
TimestampNs,
}Expand description
The type of a TimeInt or crate::Timeline.
Variants
Sequence
Used e.g. for frames in a film.
DurationNs
Duration measured in nanoseconds.
TimestampNs
Nanoseconds since unix epoch (1970-01-01 00:00:00 UTC).
Implementations
Sourceimpl TimeType
impl TimeType
pub fn format_sequence(time_int: TimeInt) -> String
pub fn parse_sequence(s: &str) -> Option<TimeInt>
Sourcepub fn parse_time(
&self,
s: &str,
timestamp_format: TimestampFormat,
) -> Option<TimeInt>
pub fn parse_time( &self, s: &str, timestamp_format: TimestampFormat, ) -> Option<TimeInt>
Parses a human-readable time string into a TimeInt.
pub fn format( &self, time_int: impl Into<TimeInt>, timestamp_format: TimestampFormat, ) -> String
Sourcepub fn format_opt(
&self,
time_int: impl Into<TimeInt>,
timestamp_format: TimestampFormat,
subsecond_decimals: RangeInclusive<usize>,
) -> String
pub fn format_opt( &self, time_int: impl Into<TimeInt>, timestamp_format: TimestampFormat, subsecond_decimals: RangeInclusive<usize>, ) -> String
The format will omit trailing sub-second zeroes as far as subsecond_decimals perimts it.
pub fn format_utc(&self, time_int: TimeInt) -> String
pub fn format_range( &self, time_range: AbsoluteTimeRange, timestamp_format: TimestampFormat, ) -> String
pub fn format_range_utc(&self, time_range: AbsoluteTimeRange) -> String
Sourcepub fn datatype(self) -> DataType
pub fn datatype(self) -> DataType
Returns the appropriate arrow datatype to represent this timeline.
pub fn from_arrow_datatype(datatype: &DataType) -> Option<TimeType>
Sourcepub fn make_arrow_array(
self,
times: impl Into<ScalarBuffer<i64>>,
) -> Arc<dyn Array> ⓘ
pub fn make_arrow_array( self, times: impl Into<ScalarBuffer<i64>>, ) -> Arc<dyn Array> ⓘ
Returns an array with the appropriate datatype.
Sourcepub fn make_arrow_array_with_nulls(
self,
times: impl Into<ScalarBuffer<i64>>,
nulls: Option<NullBuffer>,
) -> Arc<dyn Array> ⓘ
pub fn make_arrow_array_with_nulls( self, times: impl Into<ScalarBuffer<i64>>, nulls: Option<NullBuffer>, ) -> Arc<dyn Array> ⓘ
Returns an array with the appropriate datatype, attaching the supplied null buffer.
Sourcepub fn make_arrow_array_from_time_ints(
self,
times: impl Iterator<Item = TimeInt>,
) -> Arc<dyn Array> ⓘ
pub fn make_arrow_array_from_time_ints( self, times: impl Iterator<Item = TimeInt>, ) -> Arc<dyn Array> ⓘ
Returns an array with the appropriate datatype, using None for TimeInt::STATIC.
Sourcepub fn from_arrow_array(
array: &dyn Array,
) -> Result<(TimeType, &ScalarBuffer<i64>), ArrowError>
pub fn from_arrow_array( array: &dyn Array, ) -> Result<(TimeType, &ScalarBuffer<i64>), ArrowError>
Take an array of time values, and based on its data type,
figure out its TimeType and contents.