pub trait SizeBytes {
const IS_POD: bool = false;
// Required method
fn heap_size_bytes(&self) -> u64;
// Provided methods
fn total_size_bytes(&self) -> u64 { ... }
fn stack_size_bytes(&self) -> u64 { ... }
}Expand description
Approximations of stack and heap size for both internal and external types.
Mostly used for statistics and triggering events such as garbage collection.
Provided Associated Constants
Required Methods
Sourcefn heap_size_bytes(&self) -> u64
fn heap_size_bytes(&self) -> u64
Returns how many bytes self uses on the heap.
In some cases self may be just a slice of a larger buffer.
This will in that case only return the memory used by that smaller slice.
If we however are the sole owner of the memory (e.g. a Vec), then we return
the heap size of all children plus the capacity of the buffer.
Provided Methods
Sourcefn total_size_bytes(&self) -> u64
fn total_size_bytes(&self) -> u64
Returns the total size of self in bytes, accounting for both stack and heap space.
Sourcefn stack_size_bytes(&self) -> u64
fn stack_size_bytes(&self) -> u64
Returns the total size of self on the stack, in bytes.
Defaults to std::mem::size_of_val(self).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl SizeBytes for ActiveVisualizers
impl SizeBytes for ActiveVisualizers
Sourceimpl SizeBytes for AnnotationMap
impl SizeBytes for AnnotationMap
Sourceimpl SizeBytes for Annotations
impl SizeBytes for Annotations
Sourceimpl SizeBytes for ApplicationId
impl SizeBytes for ApplicationId
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for Background
impl SizeBytes for Background
Sourceimpl SizeBytes for BarChartView
impl SizeBytes for BarChartView
Sourceimpl SizeBytes for BlueprintActivationCommand
impl SizeBytes for BlueprintActivationCommand
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for BlueprintUndoState
impl SizeBytes for BlueprintUndoState
Sourceimpl SizeBytes for BoundingBox
impl SizeBytes for BoundingBox
Sourceimpl SizeBytes for BufferAndFormatMatch
impl SizeBytes for BufferAndFormatMatch
Sourceimpl SizeBytes for ChunkRequests
impl SizeBytes for ChunkRequests
Sourceimpl SizeBytes for ColumnDescriptor
impl SizeBytes for ColumnDescriptor
Sourceimpl SizeBytes for ContainerBlueprint
impl SizeBytes for ContainerBlueprint
Sourceimpl SizeBytes for DataSourceMessage
impl SizeBytes for DataSourceMessage
Sourceimpl SizeBytes for DataSourceUiCommand
impl SizeBytes for DataSourceUiCommand
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for DataframePart
impl SizeBytes for DataframePart
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for DataframeQuery
impl SizeBytes for DataframeQuery
Sourceimpl SizeBytes for DataframeView
impl SizeBytes for DataframeView
Sourceimpl SizeBytes for DatatypeMatch
impl SizeBytes for DatatypeMatch
Sourceimpl SizeBytes for DecodeError
impl SizeBytes for DecodeError
Sourceimpl SizeBytes for DecodedFrameContent
impl SizeBytes for DecodedFrameContent
Sourceimpl SizeBytes for EntityBehavior
impl SizeBytes for EntityBehavior
Sourceimpl SizeBytes for EyeControls3D
impl SizeBytes for EyeControls3D
Sourceimpl SizeBytes for ForceCenter
impl SizeBytes for ForceCenter
Sourceimpl SizeBytes for ForceCollisionRadius
impl SizeBytes for ForceCollisionRadius
Sourceimpl SizeBytes for ForceManyBody
impl SizeBytes for ForceManyBody
Sourceimpl SizeBytes for ForcePosition
impl SizeBytes for ForcePosition
Sourceimpl SizeBytes for FrameIdRegistry
impl SizeBytes for FrameIdRegistry
Sourceimpl SizeBytes for FunctionRegistry
impl SizeBytes for FunctionRegistry
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for GaussianShCoefficient
impl SizeBytes for GaussianShCoefficient
Sourceimpl SizeBytes for GraphBackground
impl SizeBytes for GraphBackground
Sourceimpl SizeBytes for GraphViewState
impl SizeBytes for GraphViewState
Sourceimpl SizeBytes for ImageStats
impl SizeBytes for ImageStats
Sourceimpl SizeBytes for IndexColumnDescriptor
impl SizeBytes for IndexColumnDescriptor
Sourceimpl SizeBytes for IndicatedEntities
impl SizeBytes for IndicatedEntities
Sourceimpl SizeBytes for InstancePathHash
impl SizeBytes for InstancePathHash
Sourceimpl SizeBytes for IsoTransform
impl SizeBytes for IsoTransform
Sourceimpl SizeBytes for LineGrid3D
impl SizeBytes for LineGrid3D
Sourceimpl SizeBytes for MapBackground
impl SizeBytes for MapBackground
Sourceimpl SizeBytes for NearClipPlane
impl SizeBytes for NearClipPlane
Sourceimpl SizeBytes for PanelBlueprint
impl SizeBytes for PanelBlueprint
Sourceimpl SizeBytes for PickingLayerInstanceId
impl SizeBytes for PickingLayerInstanceId
Sourceimpl SizeBytes for PinholeTreeRoot
impl SizeBytes for PinholeTreeRoot
Sourceimpl SizeBytes for PlotBackground
impl SizeBytes for PlotBackground
Sourceimpl SizeBytes for PlotLegend
impl SizeBytes for PlotLegend
Sourceimpl SizeBytes for PointCloudBounds
impl SizeBytes for PointCloudBounds
Sourceimpl SizeBytes for PositionRadius
impl SizeBytes for PositionRadius
Sourceimpl SizeBytes for PreviewState
impl SizeBytes for PreviewState
Sourceimpl SizeBytes for PrioritizationState
impl SizeBytes for PrioritizationState
Sourceimpl SizeBytes for ProtectedChunks
impl SizeBytes for ProtectedChunks
Sourceimpl SizeBytes for RequestInfo
impl SizeBytes for RequestInfo
Sourceimpl SizeBytes for ResolvedAnnotationInfo
impl SizeBytes for ResolvedAnnotationInfo
Sourceimpl SizeBytes for ResolvedAnnotationInfos
impl SizeBytes for ResolvedAnnotationInfos
Sourceimpl SizeBytes for Rgb8Histogram
impl SizeBytes for Rgb8Histogram
Sourceimpl SizeBytes for Rgba32Unmul
impl SizeBytes for Rgba32Unmul
Sourceimpl SizeBytes for RowIdColumnDescriptor
impl SizeBytes for RowIdColumnDescriptor
Sourceimpl SizeBytes for RrdManifestIndex
impl SizeBytes for RrdManifestIndex
Sourceimpl SizeBytes for SampleMetadata
impl SizeBytes for SampleMetadata
Sourceimpl SizeBytes for SampleMetadataState
impl SizeBytes for SampleMetadataState
Sourceimpl SizeBytes for SamplesStatistics
impl SizeBytes for SamplesStatistics
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for ScalarAxis
impl SizeBytes for ScalarAxis
Sourceimpl SizeBytes for SetStoreInfo
impl SizeBytes for SetStoreInfo
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for SmartMessage
impl SizeBytes for SmartMessage
Sourceimpl SizeBytes for SmartMessagePayload
impl SizeBytes for SmartMessagePayload
Sourceimpl SizeBytes for SortOrderCache
impl SizeBytes for SortOrderCache
Sourceimpl SizeBytes for Spatial2DView
impl SizeBytes for Spatial2DView
Sourceimpl SizeBytes for Spatial3DView
impl SizeBytes for Spatial3DView
Sourceimpl SizeBytes for SpatialInformation
impl SizeBytes for SpatialInformation
Sourceimpl SizeBytes for SpatialViewState
impl SizeBytes for SpatialViewState
Sourceimpl SizeBytes for StateTimelineView
impl SizeBytes for StateTimelineView
Sourceimpl SizeBytes for StateTimelineViewState
impl SizeBytes for StateTimelineViewState
Sourceimpl SizeBytes for StoreSource
impl SizeBytes for StoreSource
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for StoreSourceExtra
impl SizeBytes for StoreSourceExtra
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for StoreVersion
impl SizeBytes for StoreVersion
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for StoredBlobCacheKey
impl SizeBytes for StoredBlobCacheKey
Sourceimpl SizeBytes for TableBlueprint
impl SizeBytes for TableBlueprint
Sourceimpl SizeBytes for TensorScalarMapping
impl SizeBytes for TensorScalarMapping
Sourceimpl SizeBytes for TensorSliceSelection
impl SizeBytes for TensorSliceSelection
Sourceimpl SizeBytes for TensorStats
impl SizeBytes for TensorStats
Sourceimpl SizeBytes for TensorView
impl SizeBytes for TensorView
Sourceimpl SizeBytes for TensorViewFit
impl SizeBytes for TensorViewFit
Sourceimpl SizeBytes for TextDocumentFormat
impl SizeBytes for TextDocumentFormat
Sourceimpl SizeBytes for TextDocumentView
impl SizeBytes for TextDocumentView
Sourceimpl SizeBytes for TextLogColumns
impl SizeBytes for TextLogColumns
Sourceimpl SizeBytes for TextLogFormat
impl SizeBytes for TextLogFormat
Sourceimpl SizeBytes for TextLogRows
impl SizeBytes for TextLogRows
Sourceimpl SizeBytes for TextLogView
impl SizeBytes for TextLogView
Sourceimpl SizeBytes for TimeControl
impl SizeBytes for TimeControl
Sourceimpl SizeBytes for TimePanelBlueprint
impl SizeBytes for TimePanelBlueprint
Sourceimpl SizeBytes for TimeRangeHighlight
impl SizeBytes for TimeRangeHighlight
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for TimeSeriesView
impl SizeBytes for TimeSeriesView
Sourceimpl SizeBytes for TransformForest
impl SizeBytes for TransformForest
Sourceimpl SizeBytes for TransformFrameIdHash
impl SizeBytes for TransformFrameIdHash
Sourceimpl SizeBytes for TransformResolutionCache
impl SizeBytes for TransformResolutionCache
Sourceimpl SizeBytes for TreeTransform
impl SizeBytes for TreeTransform
Sourceimpl SizeBytes for VariantName
impl SizeBytes for VariantName
Sourceimpl SizeBytes for VideoDataDescription
impl SizeBytes for VideoDataDescription
fn heap_size_bytes(&self) -> u64
Sourceimpl SizeBytes for VideoLoadError
impl SizeBytes for VideoLoadError
Sourceimpl SizeBytes for VideoPlayerStreamId
impl SizeBytes for VideoPlayerStreamId
Sourceimpl SizeBytes for VideoSampleDecoder
impl SizeBytes for VideoSampleDecoder
Sourceimpl SizeBytes for VideoSource
impl SizeBytes for VideoSource
Sourceimpl SizeBytes for ViewBlueprint
impl SizeBytes for ViewBlueprint
Sourceimpl SizeBytes for ViewBuilderId
impl SizeBytes for ViewBuilderId
Sourceimpl SizeBytes for ViewContents
impl SizeBytes for ViewContents
Sourceimpl SizeBytes for ViewStates
impl SizeBytes for ViewStates
Sourceimpl SizeBytes for ViewSystemIdentifier
impl SizeBytes for ViewSystemIdentifier
Sourceimpl SizeBytes for ViewerDiagnostic
impl SizeBytes for ViewerDiagnostic
Sourceimpl SizeBytes for ViewerReportSeverity
impl SizeBytes for ViewerReportSeverity
Sourceimpl SizeBytes for ViewportBlueprint
impl SizeBytes for ViewportBlueprint
Sourceimpl SizeBytes for VisibleTimeRanges
impl SizeBytes for VisibleTimeRanges
Sourceimpl SizeBytes for VisualBounds2D
impl SizeBytes for VisualBounds2D
Sourceimpl SizeBytes for VisualizableEntities
impl SizeBytes for VisualizableEntities
Sourceimpl SizeBytes for VisualizableReason
impl SizeBytes for VisualizableReason
Sourceimpl SizeBytes for VisualizerInstruction
impl SizeBytes for VisualizerInstruction
Sourceimpl SizeBytes for VisualizerReportContext
impl SizeBytes for VisualizerReportContext
Sourceimpl SizeBytes for VisualizerTypeReport
impl SizeBytes for VisualizerTypeReport
Sourceimpl SizeBytes for dyn ViewState
Bridges dyn ViewState back to SizeBytes, so containers like Box<dyn ViewState> can be sized.
impl SizeBytes for dyn ViewState
Bridges dyn ViewState back to SizeBytes, so containers like Box<dyn ViewState> can be sized.
fn heap_size_bytes(&self) -> u64
Sourceimpl<K, S> SizeBytes for HashSet<K, S>where
K: SizeBytes,
impl<K, S> SizeBytes for HashSet<K, S>where
K: SizeBytes,
fn heap_size_bytes(&self) -> u64
Sourceimpl<T, U, V, W> SizeBytes for (T, U, V, W)
impl<T, U, V, W> SizeBytes for (T, U, V, W)
Sourceimpl<T, const N: usize> SizeBytes for SmallVec<[T; N]>where
T: SizeBytes,
impl<T, const N: usize> SizeBytes for SmallVec<[T; N]>where
T: SizeBytes,
Sourcefn heap_size_bytes(&self) -> u64
fn heap_size_bytes(&self) -> u64
Does not take capacity into account.