ToArrowOpt

Trait ToArrowOpt 

pub trait ToArrowOpt: ArrowDataType + Clone {
    // Required method
    fn to_arrow_opt<'a>(
        data: impl IntoIterator<Item = Option<impl Into<Cow<'a, Self>>>>,
    ) -> Result<Arc<dyn Array>, SerializationError>
       where Self: 'a;
}
Serializes an iterator of optional values into a nullable Arrow array.

Required Methods

fn to_arrow_opt<'a>( data: impl IntoIterator<Item = Option<impl Into<Cow<'a, Self>>>>, ) -> Result<Arc<dyn Array>, SerializationError>
where Self: 'a,

Given an iterator of options of owned or reference values, serializes them into an Arrow array.

When using Rerun’s builtin components & encodings, this can only fail if the data exceeds the maximum number of entries in an Arrow array (2^31 for standard arrays, 2^63 for large arrays).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors