Integration with integration with the clap command line argument parser.
Structs
- Rerun
Args - This struct implements a
clap::Parserthat defines all the arguments that a typical Rerun application might use, and provides helpers to evaluate those arguments and behave consequently.