The low-level datatypes that components are built from.
They all implement the Loggable trait.
Structs
- Absolute
Time Range - Datatype: Two
datatypes::TimeIntdescribing a range of time. - Angle
- Datatype: Angle in radians.
- Annotation
Info - Datatype: Annotation info annotating a class id or key-point id.
- Blob
- Datatype: A binary blob of data.
- Bool
- Datatype: A single boolean.
- Channel
Count Pair - Datatype: A pair representing a channel ID and its associated message count.
- Class
Description - Datatype: The description of a semantic Class.
- Class
Description MapElem - Datatype: A helper type for mapping
datatypes::ClassIds to class descriptions. - ClassId
- Datatype: A 16-bit ID representing a type of semantic class.
- DVec2D
- Datatype: A double-precision vector in 2D space.
- Entity
Path - Datatype: A path to an entity in the
ChunkStore. - Float32
- Datatype: A single-precision 32-bit IEEE 754 floating point number.
- Float64
- Datatype: A double-precision 64-bit IEEE 754 floating point number.
- Image
Format - Datatype: The metadata describing the contents of a
components::ImageBuffer. - Keypoint
Id - Datatype: A 16-bit ID representing a type of semantic keypoint within a class.
- Keypoint
Pair - Datatype: A connection between two
datatypes::KeypointIds. - Mat3x3
- Datatype: A 3x3 Matrix.
- Mat4x4
- Datatype: A 4x4 Matrix.
- Plane3D
- Datatype: An infinite 3D plane represented by a unit normal vector and a distance.
- Quaternion
- Datatype: A Quaternion represented by 4 real numbers.
- Range1D
- Datatype: A 1D range, specifying a lower and upper bound.
- Range2D
- Datatype: An Axis-Aligned Bounding Box in 2D space, implemented as the minimum and maximum corners.
- Rgba32
- Datatype: An RGBA color with unmultiplied/separate alpha, in sRGB gamma space with linear alpha.
- Rotation
Axis Angle - Datatype: 3D rotation represented by a rotation around a given axis.
- Tensor
Data - Datatype: An N-dimensional array of numbers.
- Tensor
Dimension Index Selection - Datatype: Indexing a specific tensor dimension.
- Tensor
Dimension Selection - Datatype: Selection of a single tensor dimension.
- TimeInt
- Datatype: A 64-bit number describing either nanoseconds OR sequence numbers.
- Time
Range - Datatype: Visible time range bounds for a specific timeline.
- UInt16
- Datatype: A 16bit unsigned integer.
- UInt32
- Datatype: A 32bit unsigned integer.
- UInt64
- Datatype: A 64bit unsigned integer.
- UVec2D
- Datatype: A uint32 vector in 2D space.
- UVec3D
- Datatype: A uint32 vector in 3D space.
- UVec4D
- Datatype: A uint vector in 4D space.
- Utf8
- Datatype: A string of text, encoded as UTF-8.
- Utf8
Pair - Datatype: Stores a tuple of UTF-8 strings.
- Uuid
- Datatype: A 16-byte UUID.
- Vec2D
- Datatype: A vector in 2D space.
- Vec3D
- Datatype: A vector in 3D space.
- Vec4D
- Datatype: A vector in 4D space.
- Video
Timestamp - Datatype: Presentation timestamp within a
archetypes::AssetVideo. - View
Coordinates - Datatype: How we interpret the coordinate system of an entity/space.
- Visible
Time Range - Datatype: Visible time range bounds for a specific timeline.
Enums
- Channel
Datatype - Datatype: The innermost datatype of an image.
- Color
Model - Datatype: Specified what color components are present in an
archetypes::Image. - Pixel
Format - Datatype: Specifieds a particular format of an
archetypes::Image. - Tensor
Buffer - Datatype: The underlying storage for
archetypes::Tensor. - Time
Range Boundary - Datatype: Left or right boundary of a time range.