pub struct GenericListBuilder<OffsetSize, T>where
OffsetSize: OffsetSizeTrait,
T: ArrayBuilder,{ /* private fields */ }Expand description
Builder for GenericListArray
Use ListBuilder to build ListArrays and LargeListBuilder to build LargeListArrays.
Example
Here is code that constructs a ListArray with the contents:
[[A,B,C], [], NULL, [D], [NULL, F]]
let values_builder = StringBuilder::new();
let mut builder = ListBuilder::new(values_builder);
// [A, B, C]
builder.values().append_value("A");
builder.values().append_value("B");
builder.values().append_value("C");
builder.append(true);
// [ ] (empty list)
builder.append(true);
// Null
builder.append(false);
// [D]
builder.values().append_value("D");
builder.append(true);
// [NULL, F]
builder.values().append_null();
builder.values().append_value("F");
builder.append(true);
// Build the array
let array = builder.finish();
// Values is a string array
// "A", "B" "C", "?", "D", NULL, "F"
assert_eq!(
array.values().as_ref(),
&StringArray::from(vec![
Some("A"), Some("B"), Some("C"),
Some("D"), None, Some("F")
])
);
// Offsets are indexes into the values array
assert_eq!(
array.value_offsets(),
&[0, 3, 3, 3, 4, 6]
);Implementations
Sourceimpl<OffsetSize, T> GenericListBuilder<OffsetSize, T>where
OffsetSize: OffsetSizeTrait,
T: ArrayBuilder,
impl<OffsetSize, T> GenericListBuilder<OffsetSize, T>where
OffsetSize: OffsetSizeTrait,
T: ArrayBuilder,
Sourcepub fn new(values_builder: T) -> GenericListBuilder<OffsetSize, T>
pub fn new(values_builder: T) -> GenericListBuilder<OffsetSize, T>
Creates a new GenericListBuilder from a given values array builder
Sourcepub fn with_capacity(
values_builder: T,
capacity: usize,
) -> GenericListBuilder<OffsetSize, T>
pub fn with_capacity( values_builder: T, capacity: usize, ) -> GenericListBuilder<OffsetSize, T>
Creates a new GenericListBuilder from a given values array builder
capacity is the number of items to pre-allocate space for in this builder
Sourcepub fn with_field(
self,
field: impl Into<Arc<Field>>,
) -> GenericListBuilder<OffsetSize, T>
pub fn with_field( self, field: impl Into<Arc<Field>>, ) -> GenericListBuilder<OffsetSize, T>
Override the field passed to GenericListArray::new
By default a nullable field is created with the name item
Note: Self::finish and Self::finish_cloned will panic if the
field’s data type does not match that of T
Sourceimpl<OffsetSize, T> GenericListBuilder<OffsetSize, T>where
OffsetSize: OffsetSizeTrait,
T: ArrayBuilder + 'static,
impl<OffsetSize, T> GenericListBuilder<OffsetSize, T>where
OffsetSize: OffsetSizeTrait,
T: ArrayBuilder + 'static,
Sourcepub fn values(&mut self) -> &mut T
pub fn values(&mut self) -> &mut T
Returns the child array builder as a mutable reference.
This mutable reference can be used to append values into the child array builder,
but you must call append to delimit each distinct list value.
Sourcepub fn values_ref(&self) -> &T
pub fn values_ref(&self) -> &T
Returns the child array builder as an immutable reference
Sourcepub fn append(&mut self, is_valid: bool)
pub fn append(&mut self, is_valid: bool)
Finish the current variable-length list array slot
Panics
Panics if the length of Self::values exceeds OffsetSize::MAX
Sourcepub fn append_value<I, V>(&mut self, i: I)
pub fn append_value<I, V>(&mut self, i: I)
Append a value to this GenericListBuilder
let mut builder = ListBuilder::new(Int32Builder::new());
builder.append_value([Some(1), Some(2), Some(3)]);
builder.append_value([]);
builder.append_value([None]);
let array = builder.finish();
assert_eq!(array.len(), 3);
assert_eq!(array.value_offsets(), &[0, 3, 3, 4]);
let values = array.values().as_primitive::<Int32Type>();
assert_eq!(values, &Int32Array::from(vec![Some(1), Some(2), Some(3), None]));This is an alternative API to appending directly to Self::values and
delimiting the result with Self::append
let mut builder = ListBuilder::new(Int32Builder::new());
builder.values().append_value(1);
builder.values().append_value(2);
builder.values().append_value(3);
builder.append(true);
builder.append(true);
builder.values().append_null();
builder.append(true);
let array = builder.finish();
assert_eq!(array.len(), 3);
assert_eq!(array.value_offsets(), &[0, 3, 3, 4]);
let values = array.values().as_primitive::<Int32Type>();
assert_eq!(values, &Int32Array::from(vec![Some(1), Some(2), Some(3), None]));Sourcepub fn append_null(&mut self)
pub fn append_null(&mut self)
Append a null to this GenericListBuilder
See Self::append_value for an example use.
Sourcepub fn append_nulls(&mut self, n: usize)
pub fn append_nulls(&mut self, n: usize)
Appends n nulls into the builder.
Sourcepub fn append_option<I, V>(&mut self, i: Option<I>)
pub fn append_option<I, V>(&mut self, i: Option<I>)
Appends an optional value into this GenericListBuilder
If Some calls Self::append_value otherwise calls Self::append_null
Sourcepub fn finish(&mut self) -> GenericListArray<OffsetSize>
pub fn finish(&mut self) -> GenericListArray<OffsetSize>
Builds the GenericListArray and reset this builder.
Sourcepub fn finish_cloned(&self) -> GenericListArray<OffsetSize>
pub fn finish_cloned(&self) -> GenericListArray<OffsetSize>
Builds the GenericListArray without resetting the builder.
Sourcepub fn offsets_slice(&self) -> &[OffsetSize]
pub fn offsets_slice(&self) -> &[OffsetSize]
Returns the current offsets buffer as a slice
Sourcepub fn validity_slice(&self) -> Option<&[u8]>
pub fn validity_slice(&self) -> Option<&[u8]>
Returns the current null buffer as a slice