pub struct ShardedLock<T>where
T: ?Sized,{ /* private fields */ }Expand description
A sharded reader-writer lock.
This lock is equivalent to RwLock, except read operations are faster and write operations
are slower.
A ShardedLock is internally made of a list of shards, each being a RwLock occupying a
single cache line. Read operations will pick one of the shards depending on the current thread
and lock it. Write operations need to lock all shards in succession.
By splitting the lock into shards, concurrent read operations will in most cases choose different shards and thus update different cache lines, which is good for scalability. However, write operations need to do more work and are therefore slower than usual.
The priority policy of the lock is dependent on the underlying operating system’s implementation, and this type does not guarantee that any particular policy will be used.
Poisoning
A ShardedLock, like RwLock, will become poisoned on a panic. Note that it may only be
poisoned if a panic occurs while a write operation is in progress. If a panic occurs in any
read operation, the lock will not be poisoned.
Examples
use crossbeam_utils::sync::ShardedLock;
let lock = ShardedLock::new(5);
// Any number of read locks can be held at once.
{
let r1 = lock.read().unwrap();
let r2 = lock.read().unwrap();
assert_eq!(*r1, 5);
assert_eq!(*r2, 5);
} // Read locks are dropped at this point.
// However, only one write lock may be held.
{
let mut w = lock.write().unwrap();
*w += 1;
assert_eq!(*w, 6);
} // Write lock is dropped here.Implementations
Sourceimpl<T> ShardedLock<T>
impl<T> ShardedLock<T>
Sourcepub fn new(value: T) -> ShardedLock<T>
pub fn new(value: T) -> ShardedLock<T>
Creates a new sharded reader-writer lock.
Examples
use crossbeam_utils::sync::ShardedLock;
let lock = ShardedLock::new(5);Sourcepub fn into_inner(self) -> Result<T, PoisonError<T>>
pub fn into_inner(self) -> Result<T, PoisonError<T>>
Consumes this lock, returning the underlying data.
Errors
This method will return an error if the lock is poisoned. A lock gets poisoned when a write operation panics.
Examples
use crossbeam_utils::sync::ShardedLock;
let lock = ShardedLock::new(String::new());
{
let mut s = lock.write().unwrap();
*s = "modified".to_owned();
}
assert_eq!(lock.into_inner().unwrap(), "modified");Sourceimpl<T> ShardedLock<T>where
T: ?Sized,
impl<T> ShardedLock<T>where
T: ?Sized,
Sourcepub fn is_poisoned(&self) -> bool
pub fn is_poisoned(&self) -> bool
Returns true if the lock is poisoned.
If another thread can still access the lock, it may become poisoned at any time. A false
result should not be trusted without additional synchronization.
Examples
use crossbeam_utils::sync::ShardedLock;
use std::sync::Arc;
use std::thread;
let lock = Arc::new(ShardedLock::new(0));
let c_lock = lock.clone();
let _ = thread::spawn(move || {
let _lock = c_lock.write().unwrap();
panic!(); // the lock gets poisoned
}).join();
assert_eq!(lock.is_poisoned(), true);Sourcepub fn get_mut(&mut self) -> Result<&mut T, PoisonError<&mut T>>
pub fn get_mut(&mut self) -> Result<&mut T, PoisonError<&mut T>>
Returns a mutable reference to the underlying data.
Since this call borrows the lock mutably, no actual locking needs to take place.
Errors
This method will return an error if the lock is poisoned. A lock gets poisoned when a write operation panics.
Examples
use crossbeam_utils::sync::ShardedLock;
let mut lock = ShardedLock::new(0);
*lock.get_mut().unwrap() = 10;
assert_eq!(*lock.read().unwrap(), 10);Sourcepub fn try_read(
&self,
) -> Result<ShardedLockReadGuard<'_, T>, TryLockError<ShardedLockReadGuard<'_, T>>>
pub fn try_read( &self, ) -> Result<ShardedLockReadGuard<'_, T>, TryLockError<ShardedLockReadGuard<'_, T>>>
Attempts to acquire this lock with shared read access.
If the access could not be granted at this time, an error is returned. Otherwise, a guard is returned which will release the shared access when it is dropped. This method does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Errors
This method will return an error if the lock is poisoned. A lock gets poisoned when a write operation panics.
Examples
use crossbeam_utils::sync::ShardedLock;
let lock = ShardedLock::new(1);
match lock.try_read() {
Ok(n) => assert_eq!(*n, 1),
Err(_) => unreachable!(),
};Sourcepub fn read(
&self,
) -> Result<ShardedLockReadGuard<'_, T>, PoisonError<ShardedLockReadGuard<'_, T>>>
pub fn read( &self, ) -> Result<ShardedLockReadGuard<'_, T>, PoisonError<ShardedLockReadGuard<'_, T>>>
Locks with shared read access, blocking the current thread until it can be acquired.
The calling thread will be blocked until there are no more writers which hold the lock. There may be other readers currently inside the lock when this method returns. This method does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Returns a guard which will release the shared access when dropped.
Errors
This method will return an error if the lock is poisoned. A lock gets poisoned when a write operation panics.
Panics
This method might panic when called if the lock is already held by the current thread.
Examples
use crossbeam_utils::sync::ShardedLock;
use std::sync::Arc;
use std::thread;
let lock = Arc::new(ShardedLock::new(1));
let c_lock = lock.clone();
let n = lock.read().unwrap();
assert_eq!(*n, 1);
thread::spawn(move || {
let r = c_lock.read();
assert!(r.is_ok());
}).join().unwrap();Sourcepub fn try_write(
&self,
) -> Result<ShardedLockWriteGuard<'_, T>, TryLockError<ShardedLockWriteGuard<'_, T>>>
pub fn try_write( &self, ) -> Result<ShardedLockWriteGuard<'_, T>, TryLockError<ShardedLockWriteGuard<'_, T>>>
Attempts to acquire this lock with exclusive write access.
If the access could not be granted at this time, an error is returned. Otherwise, a guard is returned which will release the exclusive access when it is dropped. This method does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Errors
This method will return an error if the lock is poisoned. A lock gets poisoned when a write operation panics.
Examples
use crossbeam_utils::sync::ShardedLock;
let lock = ShardedLock::new(1);
let n = lock.read().unwrap();
assert_eq!(*n, 1);
assert!(lock.try_write().is_err());Sourcepub fn write(
&self,
) -> Result<ShardedLockWriteGuard<'_, T>, PoisonError<ShardedLockWriteGuard<'_, T>>>
pub fn write( &self, ) -> Result<ShardedLockWriteGuard<'_, T>, PoisonError<ShardedLockWriteGuard<'_, T>>>
Locks with exclusive write access, blocking the current thread until it can be acquired.
The calling thread will be blocked until there are no more writers which hold the lock. There may be other readers currently inside the lock when this method returns. This method does not provide any guarantees with respect to the ordering of whether contentious readers or writers will acquire the lock first.
Returns a guard which will release the exclusive access when dropped.
Errors
This method will return an error if the lock is poisoned. A lock gets poisoned when a write operation panics.
Panics
This method might panic when called if the lock is already held by the current thread.
Examples
use crossbeam_utils::sync::ShardedLock;
let lock = ShardedLock::new(1);
let mut n = lock.write().unwrap();
*n = 2;
assert!(lock.try_read().is_err());Trait Implementations
Sourceimpl<T> Debug for ShardedLock<T>
impl<T> Debug for ShardedLock<T>
Sourceimpl<T> Default for ShardedLock<T>where
T: Default,
impl<T> Default for ShardedLock<T>where
T: Default,
Sourcefn default() -> ShardedLock<T>
fn default() -> ShardedLock<T>
Sourceimpl<T> From<T> for ShardedLock<T>
impl<T> From<T> for ShardedLock<T>
Sourcefn from(t: T) -> ShardedLock<T>
fn from(t: T) -> ShardedLock<T>
impl<T> RefUnwindSafe for ShardedLock<T>where
T: ?Sized,
impl<T> Send for ShardedLock<T>
impl<T> Sync for ShardedLock<T>
impl<T> UnwindSafe for ShardedLock<T>where
T: ?Sized,