pub struct Button<'a> { /* private fields */ }Expand description
Clickable button with text.
See also Ui::button.
if ui.add(egui::Button::new("Click me")).clicked() {
do_stuff();
}
// A greyed-out and non-interactive button:
if ui.add_enabled(false, egui::Button::new("Can't click this")).clicked() {
unreachable!();
}Implementations
Sourceimpl<'a> Button<'a>
impl<'a> Button<'a>
pub fn new(atoms: impl IntoAtoms<'a>) -> Button<'a>
Sourcepub fn selectable(selected: bool, atoms: impl IntoAtoms<'a>) -> Button<'a>
pub fn selectable(selected: bool, atoms: impl IntoAtoms<'a>) -> Button<'a>
Show a selectable button.
Equivalent to:
let selected = true;
ui.add(Button::new("toggle me").selected(selected).frame_when_inactive(!selected).frame(true));See also:
Sourcepub fn image(image: impl Into<Image<'a>>) -> Button<'a>
pub fn image(image: impl Into<Image<'a>>) -> Button<'a>
Creates a button with an image. The size of the image as displayed is defined by the provided size.
Note: In contrast to Button::new, this limits the image size to the default font height
(using crate::AtomExt::atom_max_height_font_size).
Sourcepub fn image_and_text(
image: impl Into<Image<'a>>,
text: impl Into<WidgetText>,
) -> Button<'a>
pub fn image_and_text( image: impl Into<Image<'a>>, text: impl Into<WidgetText>, ) -> Button<'a>
Creates a button with an image to the left of the text.
Note: In contrast to Button::new, this limits the image size to the default font height
(using crate::AtomExt::atom_max_height_font_size).
Sourcepub fn opt_image_and_text(
image: Option<Image<'a>>,
text: Option<WidgetText>,
) -> Button<'a>
pub fn opt_image_and_text( image: Option<Image<'a>>, text: Option<WidgetText>, ) -> Button<'a>
Create a button with an optional image and optional text.
Note: In contrast to Button::new, this limits the image size to the default font height
(using crate::AtomExt::atom_max_height_font_size).
Sourcepub fn wrap_mode(self, wrap_mode: TextWrapMode) -> Button<'a>
pub fn wrap_mode(self, wrap_mode: TextWrapMode) -> Button<'a>
Set the wrap mode for the text.
By default, crate::Ui::wrap_mode will be used, which can be overridden with crate::Style::wrap_mode.
Note that any \n in the text will always produce a new line.
Sourcepub fn wrap(self) -> Button<'a>
pub fn wrap(self) -> Button<'a>
Set Self::wrap_mode to TextWrapMode::Wrap.
Sourcepub fn fill(self, fill: impl Into<Color32>) -> Button<'a>
pub fn fill(self, fill: impl Into<Color32>) -> Button<'a>
Override background fill color. Note that this will override any on-hover effects. Calling this will also turn on the frame.
Sourcepub fn stroke(self, stroke: impl Into<Stroke>) -> Button<'a>
pub fn stroke(self, stroke: impl Into<Stroke>) -> Button<'a>
Override button stroke. Note that this will override any on-hover effects. Calling this will also turn on the frame.
Sourcepub fn frame_when_inactive(self, frame_when_inactive: bool) -> Button<'a>
pub fn frame_when_inactive(self, frame_when_inactive: bool) -> Button<'a>
If false, the button will not have a frame when inactive.
Default: true.
Note: When Self::frame (or ui.visuals().button_frame) is false, this setting
has no effect.
Sourcepub fn sense(self, sense: Sense) -> Button<'a>
pub fn sense(self, sense: Sense) -> Button<'a>
By default, buttons senses clicks.
Change this to a drag-button with Sense::drag().
Sourcepub fn corner_radius(self, corner_radius: impl Into<CornerRadius>) -> Button<'a>
pub fn corner_radius(self, corner_radius: impl Into<CornerRadius>) -> Button<'a>
Set the rounding of the button.
pub fn rounding(self, corner_radius: impl Into<CornerRadius>) -> Button<'a>
Renamed to corner_radius
Sourcepub fn image_tint_follows_text_color(
self,
image_tint_follows_text_color: bool,
) -> Button<'a>
pub fn image_tint_follows_text_color( self, image_tint_follows_text_color: bool, ) -> Button<'a>
If true, the tint of the image is multiplied by the widget text color.
This makes sense for images that are white, that should have the same color as the text color. This will also make the icon color depend on hover state.
Default: false.
Sourcepub fn shortcut_text(self, shortcut_text: impl IntoAtoms<'a>) -> Button<'a>
pub fn shortcut_text(self, shortcut_text: impl IntoAtoms<'a>) -> Button<'a>
Show some text on the right side of the button, in weak color.
Designed for menu buttons, for setting a keyboard shortcut text (e.g. Ctrl+S).
The text can be created with crate::Context::format_shortcut.
See also Self::right_text.
Sourcepub fn left_text(self, left_text: impl IntoAtoms<'a>) -> Button<'a>
pub fn left_text(self, left_text: impl IntoAtoms<'a>) -> Button<'a>
Show some text on the left side of the button.
Sourcepub fn right_text(self, right_text: impl IntoAtoms<'a>) -> Button<'a>
pub fn right_text(self, right_text: impl IntoAtoms<'a>) -> Button<'a>
Show some text on the right side of the button.
Sourcepub fn atom_ui(self, ui: &mut Ui) -> AtomLayoutResponse
pub fn atom_ui(self, ui: &mut Ui) -> AtomLayoutResponse
Show the button and return a AtomLayoutResponse for painting custom contents.