pub struct ComponentColumnDescriptor {
pub store_datatype: DataType,
pub component_type: Option<ComponentType>,
pub entity_path: EntityPath,
pub archetype: Option<ArchetypeName>,
pub component: ComponentIdentifier,
pub is_static: bool,
pub is_tombstone: bool,
pub is_semantically_empty: bool,
}Expand description
This is an ArrowField that contains specific meta-data.
Fields
store_datatype: DataTypeThe Arrow datatype of the stored column.
This is the log-time datatype corresponding to how this data is encoded
in a chunk. Currently this will always be an arrow::array::ListArray, but as
we introduce mono-type optimization, this might be a native type instead.
component_type: Option<ComponentType>Optional semantic name associated with this data.
This is fully implied by the component, but included for semantic convenience.
Example: rerun.components.Position3D.
entity_path: EntityPathThe path of the entity.
If this column is part of a chunk batch, this is the same for all columns in the batch, and will also be set in the schema for the whole chunk.
If this is missing from the metadata, it will be set to /.
archetype: Option<ArchetypeName>Optional name of the Archetype associated with this data.
None if the data wasn’t logged through an archetype.
Example: rerun.archetypes.Points3D.
component: ComponentIdentifierIdentifier of the field associated with this data.
None if the data wasn’t logged through an archetype.
Example: positions.
is_static: boolWhether this column represents static data.
IMPORTANT: this is not always accurate, see crate::ChunkBatch::chunk_schema.
is_tombstone: boolWhether this column represents a Clear-related components.
IMPORTANT: this is not always accurate, see crate::ChunkBatch::chunk_schema.
is_semantically_empty: boolWhether this column contains either no data or only contains null and/or empty values ([]).
IMPORTANT: this is not always accurate, see crate::ChunkBatch::chunk_schema.
Implementations
Sourceimpl ComponentColumnDescriptor
impl ComponentColumnDescriptor
Sourcepub fn sanity_check(&self)
pub fn sanity_check(&self)
Debug-only sanity check.
pub fn component_path(&self) -> ComponentPath
pub fn component_descriptor(&self) -> ComponentDescriptor
pub fn is_static(&self) -> bool
Sourcepub fn matches(&self, selector: &ComponentColumnSelector) -> bool
pub fn matches(&self, selector: &ComponentColumnSelector) -> bool
Checks if the current column descriptor matches a given ComponentColumnSelector.
pub fn returned_datatype(&self) -> DataType
Sourcepub fn inner_datatype(&self) -> DataType
pub fn inner_datatype(&self) -> DataType
Returns the child’s datatype of the outer list-array.
Logs a warning if the outer type is not a list-array, which should never happen in current Sorbet versions.
Sourcepub fn display_name(&self) -> &str
pub fn display_name(&self) -> &str
What we show in the UI
pub fn column_name(&self, batch_type: BatchType) -> String
pub fn to_arrow_field(&self, batch_type: BatchType) -> Field
Sourceimpl ComponentColumnDescriptor
impl ComponentColumnDescriptor
Sourcepub fn from_arrow_field(
chunk_entity_path: Option<&EntityPath>,
field: &Field,
) -> ComponentColumnDescriptor
pub fn from_arrow_field( chunk_entity_path: Option<&EntityPath>, field: &Field, ) -> ComponentColumnDescriptor
chunk_entity_path: if this column is part of a chunk batch,
what is its entity path (so we can set ComponentColumnDescriptor::entity_path)?