pub struct CpuWriteGpuReadBuffer<T>{ /* private fields */ }Expand description
A sub-allocated staging buffer that can be written to.
Behaves a bit like a fixed sized Vec in that far it keeps track of how many elements were written to it.
We do not allow reading from this buffer as it is typically write-combined memory. Reading would work, but it can be very slow. For details on why, see Write combining is not your friend, by Fabian Giesen Note that the “vec like behavior” further encourages
- not leaving holes
- keeping writes sequential
Must be dropped before calling CpuWriteGpuReadBelt::before_queue_submit (typically the end of a frame).
If this buffer is not dropped before calling CpuWriteGpuReadBelt::before_queue_submit, a validation error will occur.
Implementations
Sourceimpl<T> CpuWriteGpuReadBuffer<T>
impl<T> CpuWriteGpuReadBuffer<T>
Sourcepub fn extend_from_slice(
&mut self,
elements: &[T],
) -> Result<(), CpuWriteGpuReadError>
pub fn extend_from_slice( &mut self, elements: &[T], ) -> Result<(), CpuWriteGpuReadError>
Pushes a slice of elements into the buffer.
If the buffer is not big enough, only the first self.remaining_capacity() elements are pushed before returning an error.
Sourcepub fn extend(
&mut self,
elements: impl ExactSizeIterator<Item = T>,
) -> Result<usize, CpuWriteGpuReadError>
pub fn extend( &mut self, elements: impl ExactSizeIterator<Item = T>, ) -> Result<usize, CpuWriteGpuReadError>
Pushes several elements into the buffer.
If the buffer is not big enough, only the first CpuWriteGpuReadBuffer::remaining_capacity elements are pushed before returning an error.
Otherwise, returns the number of elements pushed for convenience.
Sourcepub fn add_n(
&mut self,
element: T,
num_elements: usize,
) -> Result<(), CpuWriteGpuReadError>
pub fn add_n( &mut self, element: T, num_elements: usize, ) -> Result<(), CpuWriteGpuReadError>
Fills the buffer with n instances of an element.
If the buffer is not big enough, only the first self.remaining_capacity() elements are pushed before returning an error.
Sourcepub fn push(&mut self, element: T) -> Result<(), CpuWriteGpuReadError>
pub fn push(&mut self, element: T) -> Result<(), CpuWriteGpuReadError>
Pushes a single element into the buffer and advances the write pointer.
Returns an error if the data no longer fits into the buffer.
Sourcepub fn num_written(&self) -> usize
pub fn num_written(&self) -> usize
The number of elements pushed into the buffer so far.
Sourcepub fn remaining_capacity(&self) -> usize
pub fn remaining_capacity(&self) -> usize
The number of elements that can still be pushed into the buffer.
Sourcepub fn copy_to_texture2d_entire_first_layer(
self,
encoder: &mut CommandEncoder,
destination: &Arc<DynamicResource<GpuTextureHandle, TextureDesc, GpuTextureInternal>>,
) -> Result<(), CpuWriteGpuReadError>
pub fn copy_to_texture2d_entire_first_layer( self, encoder: &mut CommandEncoder, destination: &Arc<DynamicResource<GpuTextureHandle, TextureDesc, GpuTextureInternal>>, ) -> Result<(), CpuWriteGpuReadError>
Copies all so far written data to the first layer of a 2D texture.
Assumes that the buffer consists of as-tightly-packed-as-possible rows of data.
(taking into account required padding as specified by wgpu::COPY_BYTES_PER_ROW_ALIGNMENT)
Fails if the buffer size is not sufficient to fill the entire texture.
Sourcepub fn copy_to_texture2d(
self,
encoder: &mut CommandEncoder,
destination: TexelCopyTextureInfo<&Texture>,
copy_size: Extent3d,
) -> Result<(), CpuWriteGpuReadError>
pub fn copy_to_texture2d( self, encoder: &mut CommandEncoder, destination: TexelCopyTextureInfo<&Texture>, copy_size: Extent3d, ) -> Result<(), CpuWriteGpuReadError>
Copies all so far written data to a rectangle on a single 2D texture layer.
Assumes that the buffer consists of as-tightly-packed-as-possible rows of data.
(taking into account required padding as specified by wgpu::COPY_BYTES_PER_ROW_ALIGNMENT)
Implementation note: Does 2D-only entirely for convenience as it greatly simplifies the input parameters.
Sourcepub fn copy_to_buffer(
self,
encoder: &mut CommandEncoder,
destination: &Arc<DynamicResource<GpuBufferHandle, BufferDesc, Buffer>>,
destination_offset: u64,
) -> Result<(), CpuWriteGpuReadError>
pub fn copy_to_buffer( self, encoder: &mut CommandEncoder, destination: &Arc<DynamicResource<GpuBufferHandle, BufferDesc, Buffer>>, destination_offset: u64, ) -> Result<(), CpuWriteGpuReadError>
Copies the entire buffer to another buffer and drops it.