Programmatic access to the .rrd/.rbl manipulations offered by the rerun rrd CLI.
Only optimization is available so far.
Structs
- Encode
Stats - What
optimizewrote. - Optimization
Profile - Named optimization profile combining chunk-size thresholds with post-processing knobs (extra passes, GoP rebatching, thick/thin split).
Functions
- optimize
- Optimize an
.rrd/.rblstream by reshaping its chunks, and write the result torrd_out. - optimize_
file - Optimize the contents of an existing
.rrd/.rblfile by reshaping its chunks, and write the result topath_to_output_rrd.