pub struct VoxelGridMap {
pub voxel_indices: Option<SerializedComponentBatch>,
pub voxel_size: Option<SerializedComponentBatch>,
pub values: Option<SerializedComponentBatch>,
pub colors: Option<SerializedComponentBatch>,
pub translation: Option<SerializedComponentBatch>,
pub rotation_axis_angle: Option<SerializedComponentBatch>,
pub quaternion: Option<SerializedComponentBatch>,
pub opacity: Option<SerializedComponentBatch>,
pub value_range: Option<SerializedComponentBatch>,
pub colormap: Option<SerializedComponentBatch>,
}Expand description
Archetype: A sparse 3D voxel grid map with grid indices and voxel dimensions.
This archetype is intended for 3D occupancy maps and other volumetric data represented as a sparse grid of voxels with scene-unit dimensions along the local X/Y/Z axes.
The minimum corner of the voxel with [0, 0, 0] index is located at the origin of the entity’s coordinate frame
and can have an additional offset from there through the optional translation and rotation fields.
A voxel center is at (index + 0.5) * voxel_size in local grid coordinates (i.e. relative to the minimum corner).
⚠️ This type is unstable and may change significantly in a way that the data won’t be backwards compatible.
Example
Simple sparse voxel grid map
fn main() -> Result<(), Box<dyn std::error::Error>> {
let rec = rerun::RecordingStreamBuilder::new(
"rerun_example_voxel_grid_map_simple",
)
.spawn()?;
let voxel_indices = [
(-1, 0, 0),
(1, 0, 0),
(1, 1, 0),
(3, 0, 0),
(3, 0, 1),
(4, 0, 1),
];
let values = [0.0_f32, 0.2, 0.4, 0.6, 0.8, 1.0];
rec.log(
"world/voxels",
&rerun::VoxelGridMap::new(voxel_indices, [0.25, 0.25, 0.25])
.with_values(values)
.with_value_range([0.0, 1.0])
.with_colormap(rerun::components::Colormap::Turbo)
.with_translation([-0.5, -0.5, 0.0]),
)?;
Ok(())
}Fields
voxel_indices: Option<SerializedComponentBatch>Indices of the voxels within the grid volume.
voxel_size: Option<SerializedComponentBatch>The scene-unit dimensions of a single voxel cell.
This defines the voxel size along the local grid X/Y/Z axes. Each dimension must be finite and positive.
values: Option<SerializedComponentBatch>Optional scalar occupancy or value data for each voxel.
If explicit colors are not provided, values are mapped through colormap and value_range.
colors: Option<SerializedComponentBatch>Optional colors for each voxel.
If set, these colors take precedence over color-mapped scalar values.
translation: Option<SerializedComponentBatch>Translation of the minimum corner of voxel [0, 0, 0].
Together with components::RotationAxisAngle or components::RotationQuat, this defines the pose of the
grid relative to the map’s parent coordinate frame.
If not set, the minimum corner is placed at the origin of the map’s parent coordinate frame.
rotation_axis_angle: Option<SerializedComponentBatch>Rotation of the grid via axis + angle.
Together with components::Translation3D, this defines the pose of the grid relative to the
map’s parent coordinate frame.
Note: either this or components::RotationQuat can be set to specify the grid’s rotation, but not both.
If both this and components::RotationQuat are set, this is ignored in favor of the quaternion.
quaternion: Option<SerializedComponentBatch>Rotation of the grid via quaternion.
Together with components::Translation3D, this defines the pose of the grid relative to the
map’s parent coordinate frame.
opacity: Option<SerializedComponentBatch>Opacity of the voxels after color or colormap application.
Defaults to 1.0 (fully opaque).
value_range: Option<SerializedComponentBatch>Scalar value range for color-mapping.
Defaults to [0.0, 1.0].
colormap: Option<SerializedComponentBatch>Colormap to use when values are present and explicit colors are not provided.
Defaults to Turbo.
Implementations
Sourceimpl VoxelGridMap
impl VoxelGridMap
Sourcepub fn descriptor_voxel_indices() -> ComponentDescriptor
pub fn descriptor_voxel_indices() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::voxel_indices.
The corresponding component is crate::components::VoxelIndex.
Sourcepub fn descriptor_voxel_size() -> ComponentDescriptor
pub fn descriptor_voxel_size() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::voxel_size.
The corresponding component is crate::components::VoxelSize.
Sourcepub fn descriptor_values() -> ComponentDescriptor
pub fn descriptor_values() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::values.
The corresponding component is crate::components::VoxelValue.
Sourcepub fn descriptor_colors() -> ComponentDescriptor
pub fn descriptor_colors() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::colors.
The corresponding component is crate::components::Color.
Sourcepub fn descriptor_translation() -> ComponentDescriptor
pub fn descriptor_translation() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::translation.
The corresponding component is crate::components::Translation3D.
Sourcepub fn descriptor_rotation_axis_angle() -> ComponentDescriptor
pub fn descriptor_rotation_axis_angle() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::rotation_axis_angle.
The corresponding component is crate::components::RotationAxisAngle.
Sourcepub fn descriptor_quaternion() -> ComponentDescriptor
pub fn descriptor_quaternion() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::quaternion.
The corresponding component is crate::components::RotationQuat.
Sourcepub fn descriptor_opacity() -> ComponentDescriptor
pub fn descriptor_opacity() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::opacity.
The corresponding component is crate::components::Opacity.
Sourcepub fn descriptor_value_range() -> ComponentDescriptor
pub fn descriptor_value_range() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::value_range.
The corresponding component is crate::components::ValueRange.
Sourcepub fn descriptor_colormap() -> ComponentDescriptor
pub fn descriptor_colormap() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::colormap.
The corresponding component is crate::components::Colormap.
Sourceimpl VoxelGridMap
impl VoxelGridMap
Sourcepub const NUM_COMPONENTS: usize = 10usize
pub const NUM_COMPONENTS: usize = 10usize
The total number of components in the archetype: 2 required, 0 recommended, 8 optional
Sourceimpl VoxelGridMap
impl VoxelGridMap
Sourcepub fn new(
voxel_indices: impl IntoIterator<Item = impl Into<VoxelIndex>>,
voxel_size: impl Into<VoxelSize>,
) -> VoxelGridMap
pub fn new( voxel_indices: impl IntoIterator<Item = impl Into<VoxelIndex>>, voxel_size: impl Into<VoxelSize>, ) -> VoxelGridMap
Create a new VoxelGridMap.
Sourcepub fn update_fields() -> VoxelGridMap
pub fn update_fields() -> VoxelGridMap
Update only some specific fields of a VoxelGridMap.
Sourcepub fn clear_fields() -> VoxelGridMap
pub fn clear_fields() -> VoxelGridMap
Clear all the fields of a VoxelGridMap.
Sourcepub fn columns<I>(
self,
_lengths: I,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns<I>( self, _lengths: I, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Partitions the component data into multiple sub-batches.
Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns
instead, via SerializedComponentBatch::partitioned.
This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.
The specified lengths must sum to the total length of the component batch.
Sourcepub fn columns_of_unit_batches(
self,
) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
pub fn columns_of_unit_batches( self, ) -> Result<impl Iterator<Item = SerializedComponentColumn>, SerializationError>
Helper to partition the component data into unit-length sub-batches.
This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n),
where n is automatically guessed.
Sourcepub fn with_voxel_indices(
self,
voxel_indices: impl IntoIterator<Item = impl Into<VoxelIndex>>,
) -> VoxelGridMap
pub fn with_voxel_indices( self, voxel_indices: impl IntoIterator<Item = impl Into<VoxelIndex>>, ) -> VoxelGridMap
Indices of the voxels within the grid volume.
Sourcepub fn with_voxel_size(self, voxel_size: impl Into<VoxelSize>) -> VoxelGridMap
pub fn with_voxel_size(self, voxel_size: impl Into<VoxelSize>) -> VoxelGridMap
The scene-unit dimensions of a single voxel cell.
This defines the voxel size along the local grid X/Y/Z axes. Each dimension must be finite and positive.
Sourcepub fn with_many_voxel_size(
self,
voxel_size: impl IntoIterator<Item = impl Into<VoxelSize>>,
) -> VoxelGridMap
pub fn with_many_voxel_size( self, voxel_size: impl IntoIterator<Item = impl Into<VoxelSize>>, ) -> VoxelGridMap
This method makes it possible to pack multiple crate::components::VoxelSize in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_voxel_size should
be used when logging a single row’s worth of data.
Sourcepub fn with_values(
self,
values: impl IntoIterator<Item = impl Into<VoxelValue>>,
) -> VoxelGridMap
pub fn with_values( self, values: impl IntoIterator<Item = impl Into<VoxelValue>>, ) -> VoxelGridMap
Optional scalar occupancy or value data for each voxel.
If explicit colors are not provided, values are mapped through colormap and value_range.
Sourcepub fn with_colors(
self,
colors: impl IntoIterator<Item = impl Into<Color>>,
) -> VoxelGridMap
pub fn with_colors( self, colors: impl IntoIterator<Item = impl Into<Color>>, ) -> VoxelGridMap
Optional colors for each voxel.
If set, these colors take precedence over color-mapped scalar values.
Sourcepub fn with_translation(
self,
translation: impl Into<Translation3D>,
) -> VoxelGridMap
pub fn with_translation( self, translation: impl Into<Translation3D>, ) -> VoxelGridMap
Translation of the minimum corner of voxel [0, 0, 0].
Together with components::RotationAxisAngle or components::RotationQuat, this defines the pose of the
grid relative to the map’s parent coordinate frame.
If not set, the minimum corner is placed at the origin of the map’s parent coordinate frame.
Sourcepub fn with_many_translation(
self,
translation: impl IntoIterator<Item = impl Into<Translation3D>>,
) -> VoxelGridMap
pub fn with_many_translation( self, translation: impl IntoIterator<Item = impl Into<Translation3D>>, ) -> VoxelGridMap
This method makes it possible to pack multiple crate::components::Translation3D in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_translation should
be used when logging a single row’s worth of data.
Sourcepub fn with_rotation_axis_angle(
self,
rotation_axis_angle: impl Into<RotationAxisAngle>,
) -> VoxelGridMap
pub fn with_rotation_axis_angle( self, rotation_axis_angle: impl Into<RotationAxisAngle>, ) -> VoxelGridMap
Rotation of the grid via axis + angle.
Together with components::Translation3D, this defines the pose of the grid relative to the
map’s parent coordinate frame.
Note: either this or components::RotationQuat can be set to specify the grid’s rotation, but not both.
If both this and components::RotationQuat are set, this is ignored in favor of the quaternion.
Sourcepub fn with_many_rotation_axis_angle(
self,
rotation_axis_angle: impl IntoIterator<Item = impl Into<RotationAxisAngle>>,
) -> VoxelGridMap
pub fn with_many_rotation_axis_angle( self, rotation_axis_angle: impl IntoIterator<Item = impl Into<RotationAxisAngle>>, ) -> VoxelGridMap
This method makes it possible to pack multiple crate::components::RotationAxisAngle in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_rotation_axis_angle should
be used when logging a single row’s worth of data.
Sourcepub fn with_quaternion(
self,
quaternion: impl Into<RotationQuat>,
) -> VoxelGridMap
pub fn with_quaternion( self, quaternion: impl Into<RotationQuat>, ) -> VoxelGridMap
Rotation of the grid via quaternion.
Together with components::Translation3D, this defines the pose of the grid relative to the
map’s parent coordinate frame.
Sourcepub fn with_many_quaternion(
self,
quaternion: impl IntoIterator<Item = impl Into<RotationQuat>>,
) -> VoxelGridMap
pub fn with_many_quaternion( self, quaternion: impl IntoIterator<Item = impl Into<RotationQuat>>, ) -> VoxelGridMap
This method makes it possible to pack multiple crate::components::RotationQuat in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_quaternion should
be used when logging a single row’s worth of data.
Sourcepub fn with_opacity(self, opacity: impl Into<Opacity>) -> VoxelGridMap
pub fn with_opacity(self, opacity: impl Into<Opacity>) -> VoxelGridMap
Opacity of the voxels after color or colormap application.
Defaults to 1.0 (fully opaque).
Sourcepub fn with_many_opacity(
self,
opacity: impl IntoIterator<Item = impl Into<Opacity>>,
) -> VoxelGridMap
pub fn with_many_opacity( self, opacity: impl IntoIterator<Item = impl Into<Opacity>>, ) -> VoxelGridMap
This method makes it possible to pack multiple crate::components::Opacity in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_opacity should
be used when logging a single row’s worth of data.
Sourcepub fn with_value_range(
self,
value_range: impl Into<ValueRange>,
) -> VoxelGridMap
pub fn with_value_range( self, value_range: impl Into<ValueRange>, ) -> VoxelGridMap
Scalar value range for color-mapping.
Defaults to [0.0, 1.0].
Sourcepub fn with_many_value_range(
self,
value_range: impl IntoIterator<Item = impl Into<ValueRange>>,
) -> VoxelGridMap
pub fn with_many_value_range( self, value_range: impl IntoIterator<Item = impl Into<ValueRange>>, ) -> VoxelGridMap
This method makes it possible to pack multiple crate::components::ValueRange in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_value_range should
be used when logging a single row’s worth of data.
Sourcepub fn with_colormap(self, colormap: impl Into<Colormap>) -> VoxelGridMap
pub fn with_colormap(self, colormap: impl Into<Colormap>) -> VoxelGridMap
Colormap to use when values are present and explicit colors are not provided.
Defaults to Turbo.
Sourcepub fn with_many_colormap(
self,
colormap: impl IntoIterator<Item = impl Into<Colormap>>,
) -> VoxelGridMap
pub fn with_many_colormap( self, colormap: impl IntoIterator<Item = impl Into<Colormap>>, ) -> VoxelGridMap
This method makes it possible to pack multiple crate::components::Colormap in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_colormap should
be used when logging a single row’s worth of data.