SizeBytes

Trait SizeBytes 

pub trait SizeBytes {
    // Required method
    fn heap_size_bytes(&self) -> u64;

    // Provided methods
    fn total_size_bytes(&self) -> u64 { ... }
    fn stack_size_bytes(&self) -> u64 { ... }
    fn is_pod() -> bool { ... }
}
Approximations of stack and heap size for both internal and external types.

Motly used for statistics and triggering events such as garbage collection.

Required Methods

fn heap_size_bytes(&self) -> u64

Returns how many bytes self uses on the heap.

In some cases self may be just a slice of a larger buffer. This will in that case only return the memory used by that smaller slice.

If we however are the sole owner of the memory (e.g. a Vec), then we return the heap size of all children plus the capacity of the buffer.

Provided Methods

fn total_size_bytes(&self) -> u64

Returns the total size of self in bytes, accounting for both stack and heap space.

fn stack_size_bytes(&self) -> u64

Returns the total size of self on the stack, in bytes.

Defaults to std::mem::size_of_val(self).

fn is_pod() -> bool

Is Self just plain old data?

If true, this will make most blanket implementations of SizeBytes much faster (e.g. Vec<T>).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl SizeBytes for Msg

Source

impl SizeBytes for bool

Source

impl SizeBytes for f32

Source

impl SizeBytes for f64

Source

impl SizeBytes for i8

Source

impl SizeBytes for i16

Source

impl SizeBytes for i32

Source

impl SizeBytes for i64

Source

impl SizeBytes for i128

Source

impl SizeBytes for u8

Source

impl SizeBytes for u16

Source

impl SizeBytes for u32

Source

impl SizeBytes for u64

Source

impl SizeBytes for u128

Source

impl SizeBytes for ()

Source

impl SizeBytes for usize

Source

impl SizeBytes for String

Source

impl SizeBytes for f16

Source

impl SizeBytes for Int64Histogram

Source

impl SizeBytes for ApplicationId

Source

impl SizeBytes for DataframePart

Source

impl SizeBytes for StoreId

Source

impl SizeBytes for TableId

Source

impl SizeBytes for Tuid

Source

impl SizeBytes for ArrowMsg

Source

impl SizeBytes for BlueprintActivationCommand

Source

impl SizeBytes for LogMsg

Source

impl SizeBytes for SetStoreInfo

Source

impl SizeBytes for StoreInfo

Source

impl SizeBytes for StoreSource

Source

impl SizeBytes for StoreSourceExtra

Source

impl SizeBytes for StoreVersion

Source

impl SizeBytes for FrameIdRegistry

Source

impl SizeBytes for PinholeTreeRoot

Source

impl SizeBytes for TransformForest

Source

impl SizeBytes for TreeTransform

Source

impl SizeBytes for TransformResolutionCache

Source

impl SizeBytes for CachedTransformsForTimeline

Source

impl SizeBytes for ResolvedPinholeProjection

Source

impl<K, S> SizeBytes for HashSet<K, S>
where K: SizeBytes,

Source

impl<K, V, S> SizeBytes for HashMap<K, V, S>
where K: SizeBytes, V: SizeBytes,

Source

impl<T> SizeBytes for &T
where T: Array,

Source

impl<T> SizeBytes for Vec<T>
where T: SizeBytes,

Source

impl<T> SizeBytes for Vec1<T>
where T: SizeBytes,

Source

impl<T, U> SizeBytes for (T, U)
where T: SizeBytes, U: SizeBytes,

Source

impl<T, U, V> SizeBytes for (T, U, V)
where T: SizeBytes, U: SizeBytes, V: SizeBytes,

Source

impl<T, U, V, W> SizeBytes for (T, U, V, W)
where T: SizeBytes, U: SizeBytes, V: SizeBytes, W: SizeBytes,

Source

impl<T, const N: usize> SizeBytes for [T; N]
where T: SizeBytes,

Implementors

Source

impl SizeBytes for BackgroundKind

Source

impl SizeBytes for ContainerKind

Source

impl SizeBytes for Corner2D

Source

impl SizeBytes for Eye3DKind

Source

impl SizeBytes for LinkAxis

Source

impl SizeBytes for LoopMode

Source

impl SizeBytes for MapProvider

Source

impl SizeBytes for PanelState

Source

impl SizeBytes for PlayState

Source

impl SizeBytes for ViewFit

Source

impl SizeBytes for TextLogColumnKind

Source

impl SizeBytes for ComponentSourceKind

Source

impl SizeBytes for AggregationPolicy

Source

impl SizeBytes for Colormap

Source

impl SizeBytes for GraphType

Source

impl SizeBytes for InterpolationMode

Source

impl SizeBytes for MagnificationFilter

Source

impl SizeBytes for MarkerShape

Source

impl SizeBytes for VideoCodec

Source

impl SizeBytes for TimeRangeBoundary

Source

impl SizeBytes for ChannelDatatype

Source

impl SizeBytes for ColorModel

Source

impl SizeBytes for FillMode

Source

impl SizeBytes for PixelFormat

Source

impl SizeBytes for TensorBuffer

Source

impl SizeBytes for TransformRelation

Source

impl SizeBytes for DataType

Source

impl SizeBytes for ChunkDirectLineage

Source

impl SizeBytes for DataSourceMessage

Source

impl SizeBytes for DataSourceUiCommand

Source

impl SizeBytes for FileSource

Source

impl SizeBytes for rerun::external::re_log_types::StoreSource

Source

impl SizeBytes for DecodeError

Source

impl SizeBytes for SampleMetadataState

Source

impl SizeBytes for VideoLoadError

Source

impl SizeBytes for ImageKind

Source

impl SizeBytes for VisualizerTypeReport

Source

impl SizeBytes for rerun::log::LogMsg

Source

impl SizeBytes for TimeType

Source

impl SizeBytes for rerun::blueprint::components::AbsoluteTimeRange

Source

impl SizeBytes for ActiveTab

Source

impl SizeBytes for AngularSpeed

Source

impl SizeBytes for ApplyLatestAt

Source

impl SizeBytes for AutoLayout

Source

impl SizeBytes for AutoScroll

Source

impl SizeBytes for AutoViews

Source

impl SizeBytes for ColumnOrder

Source

impl SizeBytes for ColumnShare

Source

impl SizeBytes for rerun::blueprint::components::ComponentColumnSelector

Source

impl SizeBytes for Enabled

Source

impl SizeBytes for rerun::blueprint::components::FilterByRange

Source

impl SizeBytes for rerun::blueprint::components::FilterIsNotNull

Source

impl SizeBytes for ForceDistance

Source

impl SizeBytes for ForceIterations

Source

impl SizeBytes for ForceStrength

Source

impl SizeBytes for Fps

Source

impl SizeBytes for GridColumns

Source

impl SizeBytes for GridSpacing

Source

impl SizeBytes for IncludedContent

Source

impl SizeBytes for LockRangeDuringZoom

Source

impl SizeBytes for rerun::blueprint::components::NearClipPlane

Source

impl SizeBytes for PlaybackSpeed

Source

impl SizeBytes for QueryExpression

Source

impl SizeBytes for RootContainer

Source

impl SizeBytes for RowShare

Source

impl SizeBytes for rerun::blueprint::components::SelectedColumns

Source

impl SizeBytes for rerun::blueprint::components::TensorDimensionIndexSlider

Source

impl SizeBytes for rerun::blueprint::components::TextLogColumn

Source

impl SizeBytes for rerun::blueprint::components::TimeInt

Source

impl SizeBytes for rerun::blueprint::components::TimeRange

Source

impl SizeBytes for rerun::blueprint::components::TimelineColumn

Source

impl SizeBytes for rerun::blueprint::components::TimelineName

Source

impl SizeBytes for ViewClass

Source

impl SizeBytes for ViewMaximized

Source

impl SizeBytes for ViewOrigin

Source

impl SizeBytes for ViewerRecommendationHash

Source

impl SizeBytes for rerun::blueprint::components::VisibleTimeRange

Source

impl SizeBytes for rerun::blueprint::components::VisualBounds2D

Source

impl SizeBytes for rerun::blueprint::components::VisualizerComponentMapping

Source

impl SizeBytes for VisualizerInstructionId

Source

impl SizeBytes for VisualizerType

Source

impl SizeBytes for ZoomLevel

Source

impl SizeBytes for rerun::blueprint::datatypes::ComponentColumnSelector

Source

impl SizeBytes for rerun::blueprint::datatypes::FilterByRange

Source

impl SizeBytes for rerun::blueprint::datatypes::FilterIsNotNull

Source

impl SizeBytes for rerun::blueprint::datatypes::SelectedColumns

Source

impl SizeBytes for rerun::blueprint::datatypes::TensorDimensionIndexSlider

Source

impl SizeBytes for rerun::blueprint::datatypes::TextLogColumn

Source

impl SizeBytes for rerun::blueprint::datatypes::TimelineColumn

Source

impl SizeBytes for rerun::blueprint::VisualizerComponentMapping

Source

impl SizeBytes for rerun::components::AnnotationContext

Source

impl SizeBytes for AxisLength

Source

impl SizeBytes for rerun::components::Blob

Source

impl SizeBytes for ChannelId

Source

impl SizeBytes for ChannelMessageCounts

Source

impl SizeBytes for rerun::components::ClassId

Source

impl SizeBytes for ClearIsRecursive

Source

impl SizeBytes for Count

Source

impl SizeBytes for DepthMeter

Source

impl SizeBytes for DrawOrder

Source

impl SizeBytes for rerun::components::EntityPath

Source

impl SizeBytes for FillRatio

Source

impl SizeBytes for GammaCorrection

Source

impl SizeBytes for GeoLineString

Source

impl SizeBytes for GraphEdge

Source

impl SizeBytes for GraphNode

Source

impl SizeBytes for ImageBuffer

Source

impl SizeBytes for ImagePlaneDistance

Source

impl SizeBytes for Interactive

Source

impl SizeBytes for KeyValuePairs

Source

impl SizeBytes for rerun::components::KeypointId

Source

impl SizeBytes for LatLon

Source

impl SizeBytes for Length

Source

impl SizeBytes for LinearSpeed

Source

impl SizeBytes for MarkerSize

Source

impl SizeBytes for Name

Source

impl SizeBytes for Opacity

Source

impl SizeBytes for PinholeProjection

Source

impl SizeBytes for rerun::components::Plane3D

Source

impl SizeBytes for rerun::components::Range1D

Source

impl SizeBytes for Resolution

Source

impl SizeBytes for rerun::components::RotationAxisAngle

Source

impl SizeBytes for RotationQuat

Source

impl SizeBytes for Scalar

Source

impl SizeBytes for SchemaId

Source

impl SizeBytes for ShowLabels

Source

impl SizeBytes for StrokeWidth

Source

impl SizeBytes for rerun::components::TensorData

Source

impl SizeBytes for rerun::components::TensorDimensionIndexSelection

Source

impl SizeBytes for TensorHeightDimension

Source

impl SizeBytes for TensorWidthDimension

Source

impl SizeBytes for Texcoord2D

Source

impl SizeBytes for Timestamp

Source

impl SizeBytes for TransformFrameId

Source

impl SizeBytes for TransformMat3x3

Source

impl SizeBytes for Translation3D

Source

impl SizeBytes for ValueRange

Source

impl SizeBytes for VideoSample

Source

impl SizeBytes for rerun::components::VideoTimestamp

Source

impl SizeBytes for rerun::components::ViewCoordinates

Source

impl SizeBytes for Visible

Source

impl SizeBytes for rerun::dataframe::AbsoluteTimeRange

Source

impl SizeBytes for QueryCache

Source

impl SizeBytes for rerun::dataframe::TimeInt

Source

impl SizeBytes for rerun::dataframe::TimelineName

Source

impl SizeBytes for rerun::datatypes::AbsoluteTimeRange

Source

impl SizeBytes for rerun::datatypes::Blob

Source

impl SizeBytes for Bool

Source

impl SizeBytes for ChannelCountPair

Source

impl SizeBytes for ClassDescriptionMapElem

Source

impl SizeBytes for rerun::datatypes::ClassId

Source

impl SizeBytes for DVec2D

Source

impl SizeBytes for rerun::datatypes::EntityPath

Source

impl SizeBytes for Float64

Source

impl SizeBytes for rerun::datatypes::ImageFormat

Source

impl SizeBytes for rerun::datatypes::KeypointId

Source

impl SizeBytes for Mat4x4

Source

impl SizeBytes for rerun::datatypes::Plane3D

Source

impl SizeBytes for rerun::datatypes::Range1D

Source

impl SizeBytes for Range2D

Source

impl SizeBytes for rerun::datatypes::TensorDimensionIndexSelection

Source

impl SizeBytes for TensorDimensionSelection

Source

impl SizeBytes for rerun::datatypes::TimeInt

Source

impl SizeBytes for rerun::datatypes::TimeRange

Source

impl SizeBytes for UInt16

Source

impl SizeBytes for UInt32

Source

impl SizeBytes for UInt64

Source

impl SizeBytes for UVec2D

Source

impl SizeBytes for UVec3D

Source

impl SizeBytes for UVec4D

Source

impl SizeBytes for Utf8

Source

impl SizeBytes for Utf8Pair

Source

impl SizeBytes for Uuid

Source

impl SizeBytes for rerun::datatypes::VideoTimestamp

Source

impl SizeBytes for rerun::datatypes::ViewCoordinates

Source

impl SizeBytes for rerun::datatypes::VisibleTimeRange

Source

impl SizeBytes for GenericListArray<i32>

Source

impl SizeBytes for RecordBatch

Source

impl SizeBytes for Field

Source

impl SizeBytes for Fields

Source

impl SizeBytes for Schema

Source

impl SizeBytes for UnionFields

Source

impl SizeBytes for DAffine3

Source

impl SizeBytes for ChunkStoreChunkStats

Source

impl SizeBytes for LatestAtQuery

Source

impl SizeBytes for QueriedChunkIdTracker

Source

impl SizeBytes for UnitChunkShared

Source

impl SizeBytes for EntityDb

Source

impl SizeBytes for EntityTree

Source

impl SizeBytes for RrdManifestIndex

Source

impl SizeBytes for TimeHistogram

Source

impl SizeBytes for TimeHistogramPerTimeline

Source

impl SizeBytes for VersionedInstancePathHash

Source

impl SizeBytes for SmartMessage

Source

impl SizeBytes for CrateVersion

Source

impl SizeBytes for RawRrdManifest

Source

impl SizeBytes for RrdManifest

Source

impl SizeBytes for RrdManifestTemporalMapEntry

Source

impl SizeBytes for MyColor

Source

impl SizeBytes for MyIndex

Source

impl SizeBytes for MyLabel

Source

impl SizeBytes for MyPoint64

Source

impl SizeBytes for MyPoint

Source

impl SizeBytes for rerun::external::re_log_types::external::re_tuid::Tuid

Source

impl SizeBytes for Hash64

Source

impl SizeBytes for rerun::external::re_log_types::ArrowMsg

Source

impl SizeBytes for rerun::external::re_log_types::BlueprintActivationCommand

Source

impl SizeBytes for EntityPathHash

Source

impl SizeBytes for PythonVersion

Source

impl SizeBytes for RecordingId

Source

impl SizeBytes for rerun::external::re_log_types::SetStoreInfo

Source

impl SizeBytes for rerun::external::re_log_types::StoreInfo

Source

impl SizeBytes for TableMsg

Source

impl SizeBytes for QueryCacheKey

Source

impl SizeBytes for StorageEngineReadGuard<'_>

Source

impl SizeBytes for VideoPlayerStreamId

Source

impl SizeBytes for VideoSampleDecoder

Source

impl SizeBytes for rerun::external::re_renderer::external::re_video::Chunk

Source

impl SizeBytes for Frame

Source

impl SizeBytes for FrameContent

Available on non-WebAssembly only.
Source

impl SizeBytes for SampleMetadata

Source

impl SizeBytes for SamplesStatistics

Source

impl SizeBytes for Time

Source

impl SizeBytes for VideoDataDescription

Source

impl SizeBytes for Arc<dyn Array>

Source

impl SizeBytes for Video

Source

impl SizeBytes for ActiveVisualizers

Source

impl SizeBytes for Background

Source

impl SizeBytes for ContainerBlueprint

Source

impl SizeBytes for DataframeQuery

Source

impl SizeBytes for EntityBehavior

Source

impl SizeBytes for EyeControls3D

Source

impl SizeBytes for ForceCenter

Source

impl SizeBytes for ForceCollisionRadius

Source

impl SizeBytes for ForceManyBody

Source

impl SizeBytes for ForcePosition

Source

impl SizeBytes for GraphBackground

Source

impl SizeBytes for LineGrid3D

Source

impl SizeBytes for MapBackground

Source

impl SizeBytes for MapZoom

Source

impl SizeBytes for rerun::external::re_sdk_types::blueprint::archetypes::NearClipPlane

Source

impl SizeBytes for PanelBlueprint

Source

impl SizeBytes for PlotBackground

Source

impl SizeBytes for PlotLegend

Source

impl SizeBytes for ScalarAxis

Source

impl SizeBytes for SpatialInformation

Source

impl SizeBytes for TensorScalarMapping

Source

impl SizeBytes for TensorSliceSelection

Source

impl SizeBytes for TensorViewFit

Source

impl SizeBytes for TextLogColumns

Source

impl SizeBytes for TextLogFormat

Source

impl SizeBytes for TextLogRows

Source

impl SizeBytes for TimeAxis

Source

impl SizeBytes for TimePanelBlueprint

Source

impl SizeBytes for ViewBlueprint

Source

impl SizeBytes for ViewContents

Source

impl SizeBytes for ViewportBlueprint

Source

impl SizeBytes for VisibleTimeRanges

Source

impl SizeBytes for rerun::external::re_sdk_types::blueprint::archetypes::VisualBounds2D

Source

impl SizeBytes for VisualizerInstruction

Source

impl SizeBytes for BarChartView

Source

impl SizeBytes for DataframeView

Source

impl SizeBytes for GraphView

Source

impl SizeBytes for MapView

Source

impl SizeBytes for Spatial2DView

Source

impl SizeBytes for Spatial3DView

Source

impl SizeBytes for TensorView

Source

impl SizeBytes for TextDocumentView

Source

impl SizeBytes for TextLogView

Source

impl SizeBytes for TimeSeriesView

Source

impl SizeBytes for TransformFrameIdHash

Source

impl SizeBytes for ArrowString

Source

impl SizeBytes for ViewClassIdentifier

Source

impl SizeBytes for BlueprintUndoState

Source

impl SizeBytes for ImageStats

Source

impl SizeBytes for StoredBlobCacheKey

Source

impl SizeBytes for TensorStats

Source

impl SizeBytes for TransformDatabaseStoreCache

Source

impl SizeBytes for VariantName

Source

impl SizeBytes for ViewStates

Source

impl SizeBytes for ViewSystemIdentifier

Source

impl SizeBytes for VisualizerInstructionReport

Source

impl SizeBytes for VisualizerReportContext

Source

impl SizeBytes for rerun::log::Chunk

Source

impl SizeBytes for ChunkId

Source

impl SizeBytes for PendingRow

Source

impl SizeBytes for RowId

Source

impl SizeBytes for AlbedoFactor

Source

impl SizeBytes for Angle

Source

impl SizeBytes for rerun::AnnotationContext

Source

impl SizeBytes for AnnotationInfo

Source

impl SizeBytes for rerun::ApplicationId

Source

impl SizeBytes for ArchetypeName

Source

impl SizeBytes for Arrows2D

Source

impl SizeBytes for Arrows3D

Source

impl SizeBytes for Asset3D

Source

impl SizeBytes for AssetVideo

Source

impl SizeBytes for BarChart

Source

impl SizeBytes for Boxes2D

Source

impl SizeBytes for Boxes3D

Source

impl SizeBytes for Capsules3D

Source

impl SizeBytes for ChunkStore

Source

impl SizeBytes for ChunkStoreConfig

Source

impl SizeBytes for ClassDescription

Source

impl SizeBytes for Clear

Source

impl SizeBytes for Color

Source

impl SizeBytes for ComponentDescriptor

Source

impl SizeBytes for ComponentIdentifier

Source

impl SizeBytes for ComponentType

Source

impl SizeBytes for CoordinateFrame

Source

impl SizeBytes for Cylinders3D

Source

impl SizeBytes for DatatypeName

Source

impl SizeBytes for DepthImage

Source

impl SizeBytes for Ellipsoids3D

Source

impl SizeBytes for EncodedDepthImage

Source

impl SizeBytes for EncodedImage

Source

impl SizeBytes for rerun::EntityPath

Source

impl SizeBytes for EntityPathPart

Source

impl SizeBytes for Float32

Source

impl SizeBytes for GeoLineStrings

Source

impl SizeBytes for GeoPoints

Source

impl SizeBytes for GraphEdges

Source

impl SizeBytes for GraphNodes

Source

impl SizeBytes for HalfSize2D

Source

impl SizeBytes for HalfSize3D

Source

impl SizeBytes for Image

Source

impl SizeBytes for rerun::ImageFormat

Source

impl SizeBytes for InstancePoses3D

Source

impl SizeBytes for KeypointPair

Source

impl SizeBytes for LineStrip2D

Source

impl SizeBytes for LineStrip3D

Source

impl SizeBytes for LineStrips2D

Source

impl SizeBytes for LineStrips3D

Source

impl SizeBytes for Mat3x3

Source

impl SizeBytes for McapChannel

Source

impl SizeBytes for McapMessage

Source

impl SizeBytes for McapSchema

Source

impl SizeBytes for McapStatistics

Source

impl SizeBytes for MediaType

Source

impl SizeBytes for Mesh3D

Source

impl SizeBytes for Pinhole

Source

impl SizeBytes for Points2D

Source

impl SizeBytes for Points3D

Source

impl SizeBytes for Position2D

Source

impl SizeBytes for Position3D

Source

impl SizeBytes for Quaternion

Source

impl SizeBytes for Radius

Source

impl SizeBytes for RecordingInfo

Source

impl SizeBytes for Rgba32

Source

impl SizeBytes for rerun::RotationAxisAngle

Source

impl SizeBytes for Scalars

Source

impl SizeBytes for Scale3D

Source

impl SizeBytes for SegmentationImage

Source

impl SizeBytes for SerializedComponentBatch

Source

impl SizeBytes for SerializedComponentColumn

Source

impl SizeBytes for SeriesLines

Source

impl SizeBytes for SeriesPoints

Source

impl SizeBytes for rerun::StoreId

Source

impl SizeBytes for Tensor

Source

impl SizeBytes for rerun::TensorData

Source

impl SizeBytes for Text

Source

impl SizeBytes for TextDocument

Source

impl SizeBytes for TextLog

Source

impl SizeBytes for TextLogLevel

Source

impl SizeBytes for TimeCell

Source

impl SizeBytes for TimeColumn

Source

impl SizeBytes for TimePoint

Source

impl SizeBytes for Timeline

Source

impl SizeBytes for Transform3D

Source

impl SizeBytes for TransformAxes3D

Source

impl SizeBytes for TriangleIndices

Source

impl SizeBytes for Vec2D

Source

impl SizeBytes for Vec3D

Source

impl SizeBytes for Vec4D

Source

impl SizeBytes for Vector2D

Source

impl SizeBytes for Vector3D

Source

impl SizeBytes for VideoFrameReference

Source

impl SizeBytes for VideoStream

Source

impl SizeBytes for rerun::ViewCoordinates

Source

impl SizeBytes for dyn Array

Source

impl<K> SizeBytes for BTreeSet<K>
where K: SizeBytes,

Source

impl<K, V> SizeBytes for BookkeepingBTreeMap<K, V>
where K: Ord + SizeBytes, V: SizeBytes,

Source

impl<K, V> SizeBytes for BTreeMap<K, V>
where K: SizeBytes, V: SizeBytes,

Source

impl<T> SizeBytes for Option<T>
where T: SizeBytes,

Source

impl<T> SizeBytes for ScalarBuffer<T>
where T: ArrowNativeType,

Source

impl<T> SizeBytes for Mutex<RawMutex, T>
where T: SizeBytes,

Source

impl<T> SizeBytes for RwLock<RawRwLock, T>
where T: SizeBytes,

Source

impl<T> SizeBytes for RangeInclusive<T>
where T: SizeBytes,

Source

impl<T> SizeBytes for VideoPlayer<T>
where T: Default,

Source

impl<T> SizeBytes for StableIndexDeque<T>
where T: SizeBytes,

Source

impl<T> SizeBytes for Box<T>
where T: SizeBytes,

Source

impl<T> SizeBytes for VecDeque<T>
where T: SizeBytes,

Source

impl<T> SizeBytes for Arc<T>
where T: SizeBytes,

Source

impl<T> SizeBytes for BlueprintId<T>

Source

impl<T> SizeBytes for PerVisualizerInstruction<T>
where T: SizeBytes,

Source

impl<T> SizeBytes for PerVisualizerType<T>
where T: SizeBytes,

Source

impl<T, E> SizeBytes for Result<T, E>
where T: SizeBytes, E: SizeBytes,

Source

impl<T, const N: usize> SizeBytes for SmallVec<[T; N]>
where T: SizeBytes,